#! /bin/sh
#
# Name: prepare_admin_chroot.sh  
# Date: 2011-06-09
# Author: Marjan Jemec
# Copyright 2011 Iskratel
#
### BEGIN INIT INFO
# Required-Start: 
# Required-Stop:
# Should-Start:
# Should-Stop:
# Default-Start: 1 2 3 4 5
# Default-Stop: 0 6
# Short-Description: chroot environment for CLI user 
# Description: start and stop chroot environment for CLI user
### END INIT INFO 
# chkconfig: 2345 90 10
#
PATH=/bin:/usr/bin:/sbin:/usr/sbin

PROFILE_FILE=/etc/init.d/it_functions
PRODUCT_DIR=/opt/si?000/neroot
USER_NAME=admin
HOME_DIR=`awk -F: -v v="${USER_NAME}" '{if ($1==v) print $6}' /etc/passwd`

if [ -e ${PROFILE_FILE} ]
then
	. ${PROFILE_FILE}
	it_set_var_ACTIVE_DIR
else
	echo "Error: missing profile ${PROFILE_FILE}"
	exit 1
fi

function do_prepare_directories()
{
	# Prepare mountpoints for chrooted environment
	mkdir -p ${HOME_DIR}/bin
	mkdir -p ${HOME_DIR}/lib

	# Prepare user's mountpoints
	mkdir -p ${HOME_DIR}/config
	mkdir -p ${HOME_DIR}/log
}

function do_mount()
{
	# Prepare chrooted environment
	mount -o bind,ro /bin ${HOME_DIR}/bin
	mount -o bind,ro /lib ${HOME_DIR}/lib

	# Mount directories needed by user
	CURRENT_DIR=`readlink --canonicalize-existing ${PRODUCT_DIR}/current`
        # cmil: REQ01107234 Make directory before mount
        mkdir -p ${CURRENT_DIR}/etc/config
        # end cmil
	# cmil: REQ01132640 Make aditional directories
	mkdir -p ${CURRENT_DIR}/etc/config/onu-default --mode=775
	mkdir -p ${CURRENT_DIR}/etc/config/license --mode=775
	# end cmil
	mount -o bind ${CURRENT_DIR}/etc/config ${HOME_DIR}/config
	mount -o bind /var/log ${HOME_DIR}/log
}

function do_umount()
{
	for mount_point in `mount | grep ${HOME_DIR} | awk '{print $3}'`
	do
		# Kill attached processes to user's mountpoint
		fuser -k ${mount_point}

		# umount filesystem
		umount ${mount_point}
	done
}

case "$1" in
	start)
		echo -n "Mounting directories needed by user ${USER_NAME}"
		# umount any existing user mounts to avoid duplicated mounts
		do_umount
		do_prepare_directories
		do_mount
		echo "."
		;;
	stop)
		echo -n "Umounting directories needed by user ${USER_NAME}"
		do_umount
		echo "."
		;;
	*)
		echo "Usage: /etc/init.d/${0##*/} {start|stop}"
		exit 1
		;;
esac

exit 0
