#!/bin/sh

###########################################################################
#                                                                         #
#                                                                         #
#              Copyright (c) 2009 IskraTEL                                #
#                                                                         #
#                                                                         #
#                                                                         #
#   Name        : DRAMErrRep.sh		                                      #
#                                                                         #
#   Description : Script for sending diagnostic error reports to          #
#                 extModRepSend program                                   #
#                                                                         #
#   Position    : /opt/iskratel/sbin                                      #
#                                                                         #
#   Date        : Apr 2009                                                #
#                                                                         #
#   Author      : Gorazd Kovacic ITRDD2	                                  #
#                                                                         #
#   Translation : * None                                                  #
#                                                                         #
#   Remarks     : * None                                                  #
#                                                                         #
#   Revisions   : * None                                                  #
#                                                                         #
###########################################################################

#. /etc/init.d/it_functions
#it_set_it_profile

declare -rx TMP="/tmp/DRAMtemp"	#DRAM error log temporary file
declare -r NEW_FILE="/tmp/DRAMtemp"
declare -rx DRAM_ERR_LOG="/tmp/DRAMErrLog"	#DRAM error log file
TIME_LIMIT=2592001
DRAM_ERROR_LIMIT=10

case "$1" in
        help)
		echo "Usage: DRAMErrRep.sh <mes_type> <errcod> <obj_ident> "
		echo "       mes_type - message type"
		echo "       errCode - error code"
		echo "       obj_ident - object identification string"
		echo " "
		echo "Example 1: DRAMErrRep.sh announce 400100 1.1/79.1/end/"
		;;
        announce)

		while read LINE; do

		LAST_TIMESTAMP=$(date +%s)
		if test -f "$TMP" ; then

        echo "$LAST_TIMESTAMP" >> $TMP
		echo "$LAST_TIMESTAMP" >> $DRAM_ERR_LOG

        #Count the number of lines in file
        number_of_lines=`sed -n '$=' $TMP`

        #Remember timestamp data of the first line in file
        first_row=`sed q $TMP`

        #Remember timestamp data of the last line in file
        last_row=`sed -n '$p' $TMP`

		#Make substract between last in first timestamp
		substract=$[last_row-first_row]

                if [ $number_of_lines -ge $DRAM_ERROR_LIMIT ]; then
                n=3
                fi
                if [ $number_of_lines -lt $DRAM_ERROR_LIMIT ]; then
                n=2
                fi
                if [ $substract -ge $TIME_LIMIT ] && [ $n -eq 2 ]; then
                echo "30 days time limit is over" >> /tmp/DRAMErrLog
                echo "Delete DRAMtemp log timestamp file - less than 10 logs" >> /tmp/DRAMErrLog
                rm "$TMP"
                fi
                if [ $substract -ge $TIME_LIMIT ] && [ $n -eq 3 ]; then
                echo "Delete DRAMtemp log timestamp file - 10 logs, 30 days time limit is over " >> /tmp/DRAMErrLog
                rm "$TMP"
                fi
                if [ $substract -lt $TIME_LIMIT ] && [ $n -eq 3 ]; then
                echo "DRAM error alarm announce" >> /tmp/DRAMErrLog
                echo "Delete DRAMtemp log timestamp file" >> /tmp/DRAMErrLog
                rm "$TMP"
				/opt/iskratel/sbin/extModRepSend $@
				echo $LINE >> /var/log/announce.log
                fi
		else
        touch "$DRAM_ERR_LOG"
		chmod 755 $DRAM_ERR_LOG
        echo "DRAM error log file does not exist yet. Create it." >> $DRAM_ERR_LOG
        touch "$NEW_FILE"
        chmod 755 $NEW_FILE
        echo "$LAST_TIMESTAMP" >> $TMP
        echo "$LAST_TIMESTAMP" >> $DRAM_ERR_LOG
		fi

			done
        ;;
        retreate)
                while read LINE; do
                        /opt/iskratel/sbin/extModRepSend $@
			echo $LINE >> /var/log/retreate.log
                done
        ;;
        *)
	echo "Usage: DRAMErrRep.sh <mes_type> <errcod> <obj_ident> "
	echo "       mes_type - message type"
	echo "       errCode - error code"
	echo "       obj_ident - object identification string"
	echo " "
	echo "Example 1: DRAMErrRep.sh announce 400100 1.1/79.1/end/"
	exit 1

;;
esac
