#!/bin/sh
#This file will generate system information of our board
#Information will be in /var/log/it_system_state.log,
#/etc/sysconfig/motherboard and /etc/sysconfig/mcu_board

LOGGER="logger -p user.alert -u /var/run/it_system -t it_system_state --"

echo "Get system state after reboot" | ${LOGGER}
echo "System SW packages:" | ${LOGGER}
echo "    iniparser:        $(rpm -q --whatprovides iniparser | tail -1)" | ${LOGGER}
echo "    ham:              $(rpm -q ham)" | ${LOGGER}
echo "    snmp ext:         $(rpm -q niesubag)" | ${LOGGER}
echo "    it_config_linux:  $(rpm -q --whatprovides it_config_linux)" | ${LOGGER}
echo "    kernel:           $(rpm -qa | grep lsp)" | ${LOGGER}

info_board_file=/etc/sysconfig/info-board
if [ -e ${info_board_file} ]
then
	. ${info_board_file}
	board_name_suffix_underscore="_$BOARD_NAME"
	board_name_suffix_dash="-$BOARD_NAME"
fi

echo "    solid:            $(rpm -q Solid)" | ${LOGGER}
echo "    snmp:             $(rpm -q net-snmp)" | ${LOGGER}
echo "    ipmitool:         $(rpm -q ipmitool${board_name_suffix_dash})" | ${LOGGER}
echo "    it_utils:         $(rpm -q --whatprovides it_utils${board_name_suffix_underscore})" | ${LOGGER}
echo "    syslog-ng:        $(rpm -q syslog-ng)" | ${LOGGER}
echo "    sysstat:          $(rpm -q sysstat)" | ${LOGGER}
echo "    bash:             $(rpm -q bash)" | ${LOGGER}
echo "    diag:             $(rpm -q diagnostics)" | ${LOGGER}
echo "" | ${LOGGER}
LINK=$(readlink --canonicalize /opt/si2000/neroot/active/etc/init.d/it_init | xargs rpm -qf)
echo "network element: $LINK"  | ${LOGGER}
echo "LINK=$LINK" > /tmp/link
PRODUCT=$(grep LINK /tmp/link | cut -c 6- | cut -c -8)
if [ "$PRODUCT" = "ce6111ax" ]
then
	echo "    CS:                 $(rpm -qa cs_appl*)" | ${LOGGER}
	echo "    MG_CVA:             $(rpm -qa mg_applcva*)" | ${LOGGER}
	echo "    MG_PCU:             $(rpm -qa mg_applpcu*)" | ${LOGGER}
	echo "    VOICEMAIL:          $(rpm -q voicemail)" | ${LOGGER}
	echo "    AP:                 $(rpm -q AP)" | ${LOGGER}
	echo "    DB:                 $(rpm -qa ce6111ax_db-*)" | ${LOGGER}
	echo "    DB_DATA:            $(rpm -qa ce6111ax_db-data_*)" | ${LOGGER}
fi

if [ "$PRODUCT" = "li6141ax" ]
then
	 echo "    LI:                 $(rpm -qa | grep li6141ax-kvm)" | ${LOGGER}
	 echo "    LI_WEB:             $(rpm -qa | grep li6141ax_web)" | ${LOGGER}
	 echo "    LI_DB_DATA:         $(rpm -qa | grep li6141ax_db-data*)" | ${LOGGER}
	 echo "    LI_FW:              $(rpm -qa | grep li_fw)" | ${LOGGER}
	 echo "    LI_APPL_STD:        $(rpm -qa | grep li_appl_std)" | ${LOGGER}
	 echo "    DPI:                $(rpm -qa | grep dpi_*)" | ${LOGGER}
	 echo "    IP_SORM:            $(rpm -qa | grep ip_sorm)" | ${LOGGER}
fi

if [ "$PRODUCT" = "cs6116ax" ]
then
	echo "    DB_DATA:            $(rpm -qa | grep cs6116ax_db-data_*)" | ${LOGGER}
fi

if [ "$PRODUCT" = "mg6211ax" ]
then
        echo "    MG_MCU:             $(rpm -qa mg6211axmcu*)" | ${LOGGER}
        echo "    MG_PCU:             $(rpm -qa mg6211axpcu*)" | ${LOGGER}
        echo "    DB:                 $(rpm -qa mg6211ax_db-*)" | ${LOGGER}
        echo "    DB_DATA:            $(rpm -qa mg6211ax_db-data_*)" | ${LOGGER}
fi

if [ "$PRODUCT" = "la6521ax" ]
then
        echo "    MG_MCU:             $(rpm -qa la6521axmcu*)" | ${LOGGER}
        echo "    MG_PCU:             $(rpm -qa la6521axpcu*)" | ${LOGGER}
        echo "    DB:                 $(rpm -qa la6521ax_db-*)" | ${LOGGER}
        echo "    DB_DATA:            $(rpm -qa la6521ax_db-data_*)" | ${LOGGER}
fi


rm -f /tmp/link

if [ "$board_name_suffix_dash" != "-kvm" ]
then
	echo "------------------" | ${LOGGER}
	echo "Product state - PS" | ${LOGGER}
	echo "------------------" | ${LOGGER}
	ipmitool fru > /tmp/board
	cat /tmp/board | ${LOGGER}
	echo "" | ${LOGGER}

	DSP_BOARD=$(grep "Board Part Number" /tmp/board | grep -o -m 1 "ETN[0-9]*")
	if [ "$DSP_BOARD" = "ETN6106" ]
	then
		DSP_PS=$(grep -m 2 ETN6106 /tmp/board | cut -c 37- | cut -c -2)
		echo "$DSP_PS" > /tmp/dsp_ps
		DSP_PS=$(cat /tmp/dsp_ps | tail -n 1)

		if [ "$DSP_PS" = "AA" ]
		then
			echo "$DSP_BOARD$DSP_PS | 4 x DSP" > /etc/sysconfig/dsp_board
		elif [ "$DSP_PS" = "AB" ]
		then
			echo "$DSP_BOARD$DSP_PS | 2 x DSP" > /etc/sysconfig/dsp_board
		else
			echo "$DSP_BOARD$DSP_PS | NEW OR UNKNOWN DSP BOARD" > /etc/sysconfig/dsp_board
		fi
	else
		#IPMI does not work
		echo "IPMI ERROR!" > /etc/sysconfig/dsp_board
	fi

	rm -f /tmp/board
	rm -f /tmp/dsp_ps

	echo "-------------------------------------" | ${LOGGER}
	echo "Product temperatures and electricity " | ${LOGGER}
	echo "-------------------------------------" | ${LOGGER}
	ipmitool sdr | ${LOGGER}
	echo "" | ${LOGGER}

	echo "-----------------------" | ${LOGGER}
	echo " System statistic data " | ${LOGGER}
	echo "-----------------------" | ${LOGGER}
	ipmitool get stats | ${LOGGER}
	echo "" | ${LOGGER}
else
        echo "" | ${LOGGER}
        echo "------------------" | ${LOGGER}
        echo " Virtual platform " | ${LOGGER}
        echo "------------------" | ${LOGGER}
        DMIDECODE=$(dmidecode | grep -m1 Manufacturer)
        echo $DMIDECODE | ${LOGGER}
        echo "" | ${LOGGER}
fi

echo "-----------" | ${LOGGER}
echo "File System" | ${LOGGER}
echo "-----------" | ${LOGGER}
while IFS= read -r line
do
  echo "${line}" | ${LOGGER}
done < /etc/fs-version
echo "" | ${LOGGER}

echo "----------" | ${LOGGER}
echo "Disk model" | ${LOGGER}
echo "----------" | ${LOGGER}

cat /proc/ide/[hs]d[a-z]/model &>/dev/null
if [ $? -eq 0 ]
then
	# IDE disk
	MODEL=$(cat /proc/ide/[hs]d[a-z]/model)
	echo ${MODEL} | ${LOGGER}
else
	cat /sys/block/[hs]d[a-z]/device/vendor &>/dev/null
	if [ $? -eq 0 ]
	then
		# SATA disk
		VENDOR=$(cat /sys/block/[hs]d[a-z]/device/vendor)
		MODEL=$(cat /sys/block/[hs]d[a-z]/device/model)
		echo ${VENDOR} ${MODEL} | ${LOGGER}
	else
		echo "NO physical disk on this platform" | ${LOGGER}
	fi
fi
echo "" | ${LOGGER}

echo "-------------" | ${LOGGER}
echo "Disk capacity" | ${LOGGER}
echo "-------------" | ${LOGGER}
file_tmp=/tmp/df.$$
df > ${file_tmp}
while IFS= read -r line
do
  echo "${line}" | ${LOGGER}
done < ${file_tmp}
rm -f ${file_tmp}
echo "-------------------------------------------------------------------------" | ${LOGGER}
echo "" | ${LOGGER}
echo "" | ${LOGGER}
