#!/bin/bash
# Crude address database

########################################################################
#                                                                      #
#                                                                      #
#               Copyright (c) 2011 Iskratel                            #
#                                                                      #
#                                                                      #
# Name:         logAnalyzer.sh                                         #
#                                                                      #
# Description:  analyzes log files and presents their content          #
#                                                                      #
# Code:         RBFS  XAL2495                                          #
#                                                                      #
# Date:         Sep 2011                                               #
#                                                                      #
# Author:       Bor Debelak, ITP RD AS1                                #
#                                                                      #
# Remarks:      /                                                      #
#                                                                      #
########################################################################

#help file
function f_help() {

echo;
echo "##LOG ANALYZER version 2.0.5 HELP##";
echo;
echo "Tool logAnalayzer can do different operations to make log analysing more user friendly.";
echo "";
echo "Firstly you have to set a product - option #a#.";
echo "";
echo "After that you choose how many nodes you want to analyse (1 or 2) - option #b#.";
echo "";
echo "Then you have to type the source location (2x in case of 2 nodes) - option #c#.";
echo "Valid sources are <full-tar-file-name> with exact path and .tar.gz. ending which includes log files (messages,...) or folder path, e.g. </var/log> which should also include log files inside.";
echo "";
echo "You can later change your product type and/or nodes number and/or source or continue with main functionalities (Generate reset info, Separate files according to nodes or grep a file).";
echo "";
echo "\"Generate reset info\" analyzes log files and writes results in the file resets, the exact location is listed right after operation finishes with the work.";
echo "In case of 2 nodes, results are written in the same file, according to date. For the first node there is a \"n1\" tag and for the second one there is a \"n2\" tag.";
echo "Resets in the file are organised by the date. When you close the script and open it again, resets file is overwritten.";
echo "";
echo "\"Separate files according to nodes\" separates all files according to different nodes. Output file locations are listed right after operation finishes with the work.";
echo "";
echo "\"Grep log file\" searches for words in the specifed log files - e.g. when you choose this option, you see a menu where you have to choose a file (e.g. messages), then you have to specify one or more words to search and hit enter. Output file location is listed right after operation finishes with the work.";
echo "";
echo "\"Parse files\" joins meassages and MsgStat files from node 1 and node 2 into 1 file, according to date. Messages files need to be younger than 1 year.";
echo "";
}

#main menu for products bigMG and AN
function mainMenu() {

echo "Choose an option:";

echo "a) Change product (current: ${productType})"
echo "b) Change number of nodes (current: ${nodeNr})"
if [ $nodeNr == 2 ]
then
   echo "c) Change source files (current node 1: ${targetPath1}, current node 2: ${targetPath2})"
else
   echo "c) Change source file (current: ${targetPath1})"
fi

echo "1) Generate reset info"
echo "2) Separate files according to nodes"
echo "3) Grep log file (messages, MsgStat, MsgErr, sc_print, sc_print_c, sc_print_e or sc_print_db)"
if [ $nodeNr == 2 ]
then
   echo "4) Parse files"
else
   echo "4) Parse files (currently only one node is chosen - please choose 2 nodes for this option)"
fi
echo "x) Exit"

read option

case "$option" in
  
   "a" | "A" )
   flagProductType=0;
   flagMainMenu=1;
   ;;
   
   "b" | "B" )
   flagChangeNodes=0;
   flagMainMenu=1;
   ;;
   
   "c" | "C" )
   flagChangeSource=0;
   flagMainMenu=1;
   ;;
   
   "1" )
   logSearchMain; 
   exit;
   ;;

   "2" )
   separateNodesMain;
   exit;
   ;;
   
   "3" )
   f_grepMain;
   exit;
   ;;

   "4" )
   parseMain;
   exit; 
   ;;

   "x" | "X" )
   exit;
   ;;

   * )
   echo "Invalid selection.";
   ;;

esac

}

#change source file
function changeSource() {

if [ $nodeNr == 2 ]
then
   #node 1
   printf "Enter source file 1 {/var/log | <full-tar-file-name>} [${targetPath1}]:";   
   read Path
   case $Path in
      "")   
      ;;
   
      *)
      targetPath1=$Path;
      #delimiter in the next line is ";", because of "/" characters in given source
      sed '/Source path 1:/s;.*;Source path 1: '${targetPath1}';g' ${confPath}/logAnalyzer.conf > ${tempPath}/logAnalyzerTmp.conf;  
      mv ${tempPath}/logAnalyzerTmp.conf ${confPath}/logAnalyzer.conf;
      ;;   
   esac
   #node 2
   printf "Enter source file 2 {/var/log | <full-tar-file-name>} [${targetPath2}]:";   
   read Path
   case $Path in
      "")   
      ;;
   
      *)
      targetPath2=$Path;
      #delimiter in the next line is ";", because of "/" characters in given source
      sed '/Source path 2:/s;.*;Source path 2: '${targetPath2}';g' ${confPath}/logAnalyzer.conf > ${tempPath}/logAnalyzerTmp.conf;  
      mv ${tempPath}/logAnalyzerTmp.conf ${confPath}/logAnalyzer.conf;
      ;;   
   esac
else
   printf "Enter source file {/var/log | <full-tar-file-name>} [${targetPath1}]:";  
   read Path
   case $Path in
      "")   
      ;;
   
      *)
      targetPath1=$Path;
      #delimiter in the next line is ";", because of "/" characters in given source
      sed '/Source path 1:/s;.*;Source path 1: '${targetPath1}';g' ${confPath}/logAnalyzer.conf > ${tempPath}/logAnalyzerTmp.conf;  
      mv ${tempPath}/logAnalyzerTmp.conf ${confPath}/logAnalyzer.conf;
      ;;   
   esac
fi
         
flagMainMenu=0;
flagChangeSource=1;
         
return;  
   
}

#product type menu
function productTypeMenu(){
   
echo "Choose a product:";

echo "1)  bigMG"
echo "2)  standaloneMG"
echo "3)  CS"
echo "4)  LI"
echo "5)  AS"
echo "6)  CE"
echo "7)  EV"
echo "8)  EF"
echo "9)  AN"
echo "10) CG"
echo "11) MS"

read option

case "$option" in

   "1" )
   productType="bigMG"; 
   flagProductType=1;
   flagMainMenu=0;
   ;;

   "2" )
   productType="standaloneMG";
   flagProductType=1;
   flagMainMenu=0;

   ;;

   "3" )
   productType="CS";
   flagProductType=1;
   flagMainMenu=0;
   ;;

   "4" )
   productType="LI";
   flagProductType=1;
   flagMainMenu=0;
   ;;

   "5" )
   productType="AS";
   flagProductType=1;
   flagMainMenu=0;
   ;;

   "6" )
   productType="CE";
   flagProductType=1;
   flagMainMenu=0;
   ;;

   "7" )
   productType="EV";
   flagProductType=1;
   flagMainMenu=0;
   ;;

   "8" )
   productType="EF";
   flagProductType=1;
   flagMainMenu=0;
   ;;
   
   "9" )
   productType="AN";
   flagProductType=1;
   flagMainMenu=0;
   ;;

   "10" )
   productType="CG";
   flagProductType=1;
   flagMainMenu=0;
   ;;

   "11" )
   productType="MS";
   flagProductType=1;
   flagMainMenu=0;
   ;;

   * )
   echo "Invalid selection.";
   ;;

esac

sed '/Product:/s;.*;Product: '${productType}';g' ${confPath}/logAnalyzer.conf > ${tempPath}/logAnalyzerTmp.conf;  
mv ${tempPath}/logAnalyzerTmp.conf ${confPath}/logAnalyzer.conf;

return;

}

#change number of nodes (1 or 2)
function changeNodes() {

echo "How many nodes do you want to analyse?";

echo "1) One node"
echo "2) Two nodes"

read option

case "$option" in

   "1" )
   nodeNr=1;   
   flagChangeNodes=1;
   flagMainMenu=0;
   ;;

   "2" )
   nodeNr=2;
   flagChangeNodes=1;
   flagMainMenu=0;
   ;; 

   * )
   echo "Invalid selection.";
   ;;

esac

sed '/nodeNr:/s;.*;nodeNr: '${nodeNr}';g' ${confPath}/logAnalyzer.conf > ${tempPath}/logAnalyzerTmp.conf;   
mv ${tempPath}/logAnalyzerTmp.conf ${confPath}/logAnalyzer.conf;

return;

}

#grep file menu
function grepMenu(){
   
echo "Choose a file to grep:";

echo "1) messages"
echo "2) MsgStat"
echo "3) MsgErr"
echo "4) sc_print"
echo "5) sc_print_c"
echo "6) sc_print_e"
echo "7) sc_print_db"

read option

case "$option" in

   "1" )
   grepName="messages";
   flagGrep=0;
   flagCheckSizeForGrep=1;
   ;;

   "2" )
   grepName="MsgStat";
   flagGrep=0;
   flagCheckSizeForGrep=0;
   ;;

   "3" )
   grepName="MsgErr";
   flagGrep=0;
   flagCheckSizeForGrep=0;
   ;;

   "4" )
   grepName="sc_print";
   flagGrep=0;
   flagCheckSizeForGrep=0;
   ;;

   "5" )
   grepName="sc_print_c";
   flagGrep=0;
   flagCheckSizeForGrep=0;
   ;;

   "6" )
   grepName="sc_print_e";
   flagGrep=0;
   flagCheckSizeForGrep=0;
   ;;
   
   "7" )
   grepName="sc_print_db";
   flagGrep=0;
   flagCheckSizeForGrep=0;
   ;;

   * )
   echo "Invalid selection.";
   flagGrep=1;
   ;;

esac

return;

}

#checking existance of selected path and files
function checkExistance() {

if [[ $targetPath1 == *".tar.gz" ]]
then
   if [[ -f ${targetPath1} ]]
   then     
      flagFileExistance=0; 
   else
      echo;
      echo "Archive .tar.gz does not exist!";
      flagFileExistance=1;
      return;
   fi
elif [[ -f ${targetPath1}"/messages" ]]
then
   flagFileExistance=0; 
else
   echo;
   echo "Missing files!";
   flagFileExistance=1;
   return;
fi

if [ $nodeNr == 2 ]
then
   if [[ $targetPath2 == *".tar.gz" ]]
   then
      if [[ -f ${targetPath2} ]]
      then     
         flagFileExistance=0; 
      else
         echo;
         echo "Archive .tar.gz does not exist!";
         flagFileExistance=1;
         return;
      fi
   elif [[ -f ${targetPath2}"/messages" ]]
   then
      flagFileExistance=0; 
   else
      echo;
      echo "Missing files!";
      flagFileExistance=1;
      return;
   fi
fi

}

#.tar.gz extract function
function extractFiles() {

if [[ $targetPath1 == *".tar.gz" ]]
then  
   #create folder for file extraction
   if [ -d "${tempPath}/extracted1" ]
   then 
      rm -rf "${tempPath}/extracted1";
   fi
   mkdir "${tempPath}/extracted1";
   
   tar -zxf "$targetPath1" -C "${tempPath}/extracted1";
   targetPath1="${tempPath}/extracted1";
   
   #check file existance
   if [[ -f ${targetPath1}"/messages" ]]
   then
      flagFileExistance=0;    
   elif [[ -f ${targetPath1}"/var/log/messages" ]]
   then
      flagFileExistance=0;
      targetPath1="${tempPath}/extracted1/var/log";
   else
      echo;
      echo "Missing files in archive .tar.gz!";
      flagFileExistance=1;
      return;    
   fi
fi

if [ $nodeNr == 2 ]
then
   if [[ $targetPath2 == *".tar.gz" ]]
   then
      #create folder for file extraction
      if [ -d "${tempPath}/extracted2" ]
      then 
         rm -rf "${tempPath}/extracted2";
      fi
      mkdir "${tempPath}/extracted2";
      
      tar -zxf "$targetPath2" -C "${tempPath}/extracted2";
      targetPath2="${tempPath}/extracted2";
      
      #check file existance
      if [[ -f ${targetPath2}"/messages" ]]
      then
         flagFileExistance=0;    
      elif [[ -f ${targetPath2}"/var/log/messages" ]]
      then
         flagFileExistance=0;
         targetPath2="${tempPath}/extracted2/var/log";
      else
         echo;
         echo "Missing files in archive .tar.gz!";
         flagFileExistance=1;
         return;    
      fi
   fi
fi

}

#checking allowed size of messages files
function checkSize() {  
  
targetPath=$1;
  
#appending current path to the variables
location_messages=${targetPath}"/messages";
fileSize_tmp=$(ls -l "$location_messages");
fileSize=$(echo "${fileSize_tmp}" | awk '{print $5}');

if [[ $fileSize -gt 15728640 ]]
then
   echo;
   echo "File ${location_messages} is too big (more than 15MB)!";
   flagOversize=1;
fi

location_messages1=${targetPath}"/messages.1";
if [ -f "$location_messages1" ]
then
fileSize_tmp=$(ls -l "$location_messages1");
fileSize=$(echo "${fileSize_tmp}" | awk '{print $5}');

if [[ $fileSize -gt 15728640 ]]
then
   echo;
   echo "File ${location_messages1} is too big (more than 15MB)!";
   flagOversize=1;
fi
fi

if [ -f "$location_messages2" ]
then
location_messages2=${targetPath}"/messages.2";
fileSize_tmp=$(ls -l "$location_messages2");
fileSize=$(echo "${fileSize_tmp}" | awk '{print $5}');

if [[ $fileSize -gt 15728640 ]]
then
   echo;
   echo "File ${location_messages2} is too big (more than 15MB)!";
   flagOversize=1;
fi
fi

if [ -f "$location_messages3" ]
then
location_messages3=${targetPath}"/messages.3";
fileSize_tmp=$(ls -l "$location_messages3");
fileSize=$(echo "${fileSize_tmp}" | awk '{print $5}');

if [[ $fileSize -gt 15728640 ]]
then
   echo;
   echo "File ${location_messages3} is too big (more than 15MB)!";
   flagOversize=1;
fi
fi

if [ -f "$location_messages4" ]
then
location_messages4=${targetPath}"/messages.4";
fileSize_tmp=$(ls -l "$location_messages4");
fileSize=$(echo "${fileSize_tmp}" | awk '{print $5}');

if [[ $fileSize -gt 15728640 ]]
then
   echo;
   echo "File ${location_messages4} is too big (more than 15MB)!";
   flagOversize=1;
fi
fi

}

#join sysup.#
function joinSysup() {

if [ -f $location_sysup1 ]
then 
   cat $location_sysup1 "${location_sysup}" > "${location_sysup_all}"
else 
   if [ -f $location_sysup ]
   then
      cp "${location_sysup}" "${location_sysup_all}";
   fi
fi 

}
 
#join MsgStatOrSimilar.#
function joinMsgStatOrSimilar() {

if [ -f $2 ]
then 
   cat $2 $1 > $6;
else
   if [ -f $1 ]
   then  
      cp $1 $6;
   fi
fi 

if [ -f $3 ]
then 
   cat $3 $6 > $7;
   mv $7 $6;
fi

if [ -f $4 ]
then 
   cat $4 $6 > $7;
   mv $7 $6;
fi

if [ -f $5 ]
then 
   cat $5 $6 > $7;
   mv $7 $6;
fi
  
}

#creates array with month names according to last month number
function monthArray() {

case "$lastMonth" in
   "12" )
      monthNr=0;
   ;;
   "11" )
      monthNr=1;
   ;;
   "10" )
      monthNr=2;
   ;;
   "09" )
      monthNr=3;
   ;;
   "08" )
      monthNr=4;
   ;;
   "07" )
      monthNr=5;
   ;;
   "06" )
      monthNr=6;
   ;;
   "05" )
      monthNr=7;
   ;;
   "04" )
      monthNr=8;
   ;;
   "03" )
      monthNr=9;
   ;;
   "02" )
      monthNr=10;
   ;;
   "01" )
      monthNr=11;
   ;;
   * )
   return;
   ;;
esac

Month[0]="Dec";
Month[1]="Nov";
Month[2]="Oct";
Month[3]="Sep";
Month[4]="Aug";
Month[5]="Jul";
Month[6]="Jun";
Month[7]="May";
Month[8]="Apr";
Month[9]="Mar";
Month[10]="Feb";
Month[11]="Jan";

for (( j = 0 ; j < 12 ; j++ ))
do
   if [[ $j -lt $monthNr ]]
   then
      Month[j+12]="${Month[$j]}";
   fi
done

for (( j = 0 ; j < 12 ; j++ ))
do 
   Month[j]="${Month[$((j+$monthNr))]}";
done

month0="${Month[0]}";
month1="${Month[1]}";
month2="${Month[2]}";
month3="${Month[3]}";
month4="${Month[4]}";
month5="${Month[5]}";
month6="${Month[6]}";
month7="${Month[7]}";
month8="${Month[8]}";
month9="${Month[9]}";
month10="${Month[10]}";
month11="${Month[11]}";

}

#finds and changes month index - calles from function extractLastYearLog
function monthChange() {
case $month in
   "${month0}" )
      #check if we already came around and be sure that it is not just one month older than last row in MsgStat
      if [[ $monthCounter -gt 1 ]]
      then
         monthCounter=12;
      fi
   ;;
   "${month1}" )
      if [[ $monthCounter -lt 1 ]]
      then
         monthCounter=1;
         echo "$line" >> "${location_last_year_tmp2}";
      else
         monthCounter=12;
      fi
   ;;
   "${month2}" )
      if [[ $monthCounter -lt 2 ]]
      then
         monthCounter=2;
         echo "$line" >> "${location_last_year_tmp2}";
      else
         monthCounter=12;
      fi
   ;;
   "${month3}" )
      if [[ $monthCounter -lt 3 ]]
      then
         monthCounter=3;
         echo "$line" >> "${location_last_year_tmp2}";
      else
         monthCounter=12;
      fi
   ;;
   "${month4}" )
      if [[ $monthCounter -lt 4 ]]
      then
         monthCounter=4;
         echo "$line" >> "${location_last_year_tmp2}";
      else
         monthCounter=12;
      fi
   ;;
   "${month5}" )
      if [[ $monthCounter -lt 5 ]]
      then
         monthCounter=5;
         echo "$line" >> "${location_last_year_tmp2}";
      else
         monthCounter=12;
      fi
   ;;
   "${month6}" )
      if [[ $monthCounter -lt 6 ]]
      then
         monthCounter=6;
         echo "$line" >> "${location_last_year_tmp2}";
      else
         monthCounter=12;
      fi
   ;;
   "${month7}" )
      if [[ $monthCounter -lt 7 ]]
      then
         monthCounter=7;
         echo "$line" >> "${location_last_year_tmp2}";
      else
         monthCounter=12;
      fi
   ;;
   "${month8}" )
      if [[ $monthCounter -lt 8 ]]
      then
         monthCounter=8;
         echo "$line" >> "${location_last_year_tmp2}";
      else
         monthCounter=12;
      fi
   ;;
   "${month9}" )
      if [[ $monthCounter -lt 9 ]]
      then
         monthCounter=9;
         echo "$line" >> "${location_last_year_tmp2}";
      else
         monthCounter=12;
      fi
   ;;
   "${month10}" )
      if [[ $monthCounter -lt 10 ]]
      then
         monthCounter=10;
         echo "$line" >> "${location_last_year_tmp2}";
      else
         monthCounter=12;
      fi
   ;;
   "${month11}" )
      if [[ $monthCounter -lt 11 ]]
      then
         monthCounter=11;
         echo "$line" >> "${location_last_year_tmp2}";
      else
         monthCounter=12;
      fi
   ;;
   * )
   return;
   ;;
esac
}

#busybox specific date format converter
function dateShapeToBusybox() {

months=$(echo $1 | awk -F" " '{print $1}' );
case "$months" in
   "Jan" )
      months=01;
   ;;
   "Feb" )
      months=02;
   ;;
   "Mar" )
      months=03;
   ;;
   "Apr" )
      months=04;
   ;;
   "May" )
      months=05;
   ;;
   "Jun" )
      months=06;
   ;;
   "Jul" )
      months=07;
   ;;
   "Aug" )
      months=08;
   ;;
   "Sep" )
      months=09;
   ;;
   "Oct" )
      months=10;
   ;;
   "Nov" )
      months=11;
   ;;
   "Dec" )
      months=12;
   ;;
   * )
   return;
   ;;
esac

days=$(echo $2);
if [[ $days -lt 10 ]]
then
   days="0"$(echo $2);
fi

hours=$(echo $3 | awk -F":" '{print $1}' );

minutes=$(echo $3 | awk -F":" '{print $2}' );

seconds=$(echo $3 | awk -F":" '{print $3}' );

date_busybox=${months}${days}${hours}${minutes}"."${seconds};

}

#appends number to month name
function f_monthNr() {
   case "$CURRENT_month" in
      "${month11}" )
         monthNr=1;
      ;;
      "${month10}" )
         monthNr=2;
      ;;
      "${month9}" )
         monthNr=3;
      ;;
      "${month8}" )
         monthNr=4;
      ;;
      "${month7}" )
         monthNr=5;
      ;;
      "${month6}" )
         monthNr=6;
      ;;
      "${month5}" )
         monthNr=7;
      ;;
      "${month4}" )
         monthNr=8;
      ;;
      "${month3}" )
         monthNr=9;
      ;;
      "${month2}" )
         monthNr=10;
      ;;
      "${month1}" )
         monthNr=11;
      ;;
      "${month0}" )
         monthNr=12;
      ;;
      * )
      return;
      ;;
   esac
}

#joins files from different nodes
function joinResets() {

location1=$1;
location2=$2;
location3=$3;

monthNr=0;
month_1=0;
month_2=0;
i=0;
j=0;
unset FIRST;
unset SECOND;
CURRENT1="";
CURRENT2="";
CURRENT_compare_1="";
CURRENT_compare_2="";
CURRENT_month="";

while read line   
do
   FIRST[$i]=$(echo "${line}");
   i=$((i+1));
done < "${location1}"

while read line   
do
   SECOND[$j]=$(echo "${line}");
   j=$((j+1));
done < "${location2}"

i=0;
j=0;

while  [[ $i -lt ${#FIRST[@]} ]] && [[ $j -lt ${#SECOND[@]} ]]
do
   if [[ $i -eq 0 ]]
   then
      if [[ ${FIRST[$i]} == "Reset: "* ]]
      then                 
         CURRENT1=$(echo "${FIRST[$i]}" | awk -F" " '{print $2" "$3" "$4}');
         CURRENT_month=$(echo "${FIRST[$i]}" | awk -F" " '{print $2}'); 
         f_monthNr;
         month_1=$monthNr; 
      fi
      if [[ ${FIRST[$i]} == "Change of state: "* ]]
      then                 
         CURRENT1=$(echo "${FIRST[$i]}" | awk -F" " '{print $4" "$5" "$6}');
         CURRENT_month=$(echo "${FIRST[$i]}" | awk -F" " '{print $4}'); 
         f_monthNr;
         month_1=$monthNr; 
      fi
   fi

   if [[ $j -eq 0 ]]
   then
      if [[ ${SECOND[$j]} == "Reset: "* ]]
      then                 
         CURRENT2=$(echo "${SECOND[$j]}" | awk -F" " '{print $2" "$3" "$4}');
         CURRENT_month=$(echo "${SECOND[$j]}" | awk -F" " '{print $2}');
         f_monthNr;
         month_2=$monthNr;
      fi
      if [[ ${SECOND[$j]} == "Change of state: "* ]]
      then                 
         CURRENT2=$(echo "${SECOND[$j]}" | awk -F" " '{print $4" "$5" "$6}');
         CURRENT_month=$(echo "${SECOND[$j]}" | awk -F" " '{print $4}');
         f_monthNr;
         month_2=$monthNr; 
      fi
   fi
   
   if [[ $i -gt 0 ]]
   then
      if [[ ${FIRST[$i]} == "Reset: "* ]] && [[ ${FIRST[$((i-1))]} == "-------"* ]]
      then                 
         CURRENT1=$(echo "${FIRST[$i]}" | awk -F" " '{print $2" "$3" "$4}');
         CURRENT_month=$(echo "${FIRST[$i]}" | awk -F" " '{print $2}'); 
         f_monthNr;
         month_1=$monthNr; 
      fi
      if [[ ${FIRST[$i]} == "Change of state: "* ]] && [[ ${FIRST[$((i-1))]} == "-------"* ]]
      then                 
         CURRENT1=$(echo "${FIRST[$i]}" | awk -F" " '{print $4" "$5" "$6}');
         CURRENT_month=$(echo "${FIRST[$i]}" | awk -F" " '{print $4}'); 
         f_monthNr;
         month_1=$monthNr; 
      fi
   fi

   if [[ $j -gt 0 ]]
   then
      if [[ ${SECOND[$j]} == "Reset: "* ]] && [[ ${SECOND[$((j-1))]} == "-------"* ]]
      then                 
         CURRENT2=$(echo "${SECOND[$j]}" | awk -F" " '{print $2" "$3" "$4}');
         CURRENT_month=$(echo "${SECOND[$j]}" | awk -F" " '{print $2}');
         f_monthNr;
         month_2=$monthNr;
      fi
      if [[ ${SECOND[$j]} == "Change of state: "* ]] && [[ ${SECOND[$((j-1))]} == "-------"* ]]
      then                 
         CURRENT2=$(echo "${SECOND[$j]}" | awk -F" " '{print $4" "$5" "$6}');
         CURRENT_month=$(echo "${SECOND[$j]}" | awk -F" " '{print $4}');
         f_monthNr;
         month_2=$monthNr;
      fi
   fi
   
   if [[ $month_1 -eq $month_2 ]]
   then
      if [[ $busybox_flag -eq 1 ]]
      then
         dateShapeToBusybox ${CURRENT1};
         CURRENT_compare_1="${date_busybox}";
         dateShapeToBusybox ${CURRENT2};
         CURRENT_compare_2="${date_busybox}";
      else
         CURRENT_compare_1="${CURRENT1}";
         CURRENT_compare_2="${CURRENT2}";
      fi

      if [[ $(( $(date -u -d "$CURRENT_compare_1" +%s) - $(date -u -d "$CURRENT_compare_2" +%s) )) -gt 0 ]] 
      then
         echo "${SECOND[$j]}" >> "${location3}";
         j=$((j+1));
      else
         echo "${FIRST[$i]}" >> "${location3}";
         i=$((i+1));
      fi    
      
   elif [[ $month_1 -gt $month_2 ]]
   then
      echo "${SECOND[$j]}" >> "${location3}";
      j=$((j+1));
   else
      echo "${FIRST[$i]}" >> "${location3}";
      i=$((i+1));
   fi 
done  

for (( i ; i < ${#FIRST[@]} ; i++ ))
do
   echo "${FIRST[$i]}" >> "${location3}";
done
      
for (( j ; j < ${#SECOND[@]} ; j++ ))
do
   echo "${SECOND[$j]}" >> "${location3}";
done

}
      
#extract from log file lines that are not older than one year - do not ignore that month names are on different places in files
function extractLastYearLog() {

location_last_year=$1;
location_last_year_tmp1=${tempPath}"/last_year_tmp_1";
location_last_year_tmp2=${tempPath}"/last_year_tmp_2";

monthCounter=0;

#print file in opposite order
sed '1!G;h;$!d' "${location_last_year}" > "${location_last_year_tmp1}";  

if [ -f $location_last_year_tmp2 ]
then 
   rm -rf $location_last_year_tmp2;
fi

#extracts lines from last year
while read line   
do 
   #look for month name in the exact line 
   #location_messages_all_tmp, location_sysup_all and location_secure_tmp have month names on different places
   if [[ $1 == "${location_sysup_all}" ]]
   then
      month=$(echo "${line}" | awk -F" " '{print $2}');
   else
      month=$(echo "${line}" | awk -F" " '{print $1}');  
   fi
      
   case "$monthCounter" in
      "0" )
         if [[ $month == "${month0}" ]]
         then
            echo "$line" >> "${location_last_year_tmp2}";
         else
            monthChange;         
         fi 
      ;;
      
      "1" )
         if [[ $month == "${month1}" ]]
         then
            echo "$line" >> "${location_last_year_tmp2}";
         else
            monthChange;         
         fi
      ;;
      
      "2" )
         if [[ $month == "${month2}" ]]
         then
            echo "$line" >> "${location_last_year_tmp2}";
         else
            monthChange;      
         fi
      ;;

      "3" )
         if [[ $month == "${month3}" ]]
         then
            echo "$line" >> "${location_last_year_tmp2}";
         else
            monthChange;         
         fi
      ;;

      "4" )
         if [[ $month == "${month4}" ]]
         then
            echo "$line" >> "${location_last_year_tmp2}";
         else
            monthChange;         
         fi
      ;;

      "5" )
         if [[ $month == "${month5}" ]]
         then
            echo "$line" >> "${location_last_year_tmp2}";
         else
            monthChange;      
         fi
      ;;
      
      "6" )
         if [[ $month == "${month6}" ]]
         then
            echo "$line" >> "${location_last_year_tmp2}";
         else
            monthChange;         
         fi
      ;;
      
      "7" )
         if [[ $month == "${month7}" ]]
         then
            echo "$line" >> "${location_last_year_tmp2}";
         else
            monthChange;         
         fi
      ;;
      
      "8" )
         if [[ $month == "${month8}" ]]
         then
            echo "$line" >> "${location_last_year_tmp2}";
         else
            monthChange;         
         fi
      ;;
      
      "9" )
         if [[ $month == "${month9}" ]]
         then
            echo "$line" >> "${location_last_year_tmp2}";
         else
            monthChange;         
         fi
      ;;
      
      "10" )
         if [[ $month == "${month10}" ]]
         then
            echo "$line" >> "${location_last_year_tmp2}";
         else
            monthChange;         
         fi
      ;;
      
      "11" )
         if [[ $month == "${month11}" ]]
         then
            echo "$line" >> "${location_last_year_tmp2}";
         else
            monthChange;         
         fi
      ;;

      * )
      #print file in opposite order
      sed '1!G;h;$!d' "${location_last_year_tmp2}" > $1;
      return;
      ;;
   esac

done < "${location_last_year_tmp1}"

#if there was no output with return, print file in opposite order here
sed '1!G;h;$!d' "${location_last_year_tmp2}" > $1;

}

#find different nodes (resets)
function findNodesResets(){

unset Domena;
while read line    
do
   if [[ $line == *" kernel: Linux version "* ]]
   then
      tmp1=$(echo "${line}" | awk -F" " '{print $4}' | cut -d "@" -f2 | cut -d "/" -f1);
      for (( l = 0 ; l < ${#Domena[@]} ; l++ ))
      do
         if [[ ${Domena[$l]} == ${tmp1} ]] 
         then     
            break;
         fi
      done    
      if [[ $l == ${#Domena[@]} ]]      
      then 
         Domena[$l]=${tmp1};
      fi            
   fi
done < $1  

}

#separate files according to nodes (resets)
function separateMgResets() { 

for (( l = 0 ; l < ${#Domena[@]} ; l++ ))
do    
   if [ -f "${tempPath}/"$2"_${Domena[$l]}_"$3 ]
   then 
      rm -rf "${tempPath}/"$2"_${Domena[$l]}_"$3;
   fi
   sed -n '/'${Domena[$l]}'/p' $1 >> "${tempPath}/"$2"_${Domena[$l]}_"$3;
   
done
  
} 

#separate MessagesAll to nodes
function seperateNodeMessages() {

tmpFile="${tempPath}/"$2"_wobe_tmp";
tmpFile2="${tempPath}/"$2"_wobe_tmp2";

sed -e '/@be/d' -e '/none/d' $1 > "${tmpFile}";
sed '$!d' "${tmpFile}" > "${tmpFile2}";

while read line
do
   messagesHwWithoutBe=$(echo "${line}" | awk -F" " '{print $4}' | cut -d "@" -f2);

   LEN=$(echo ${#messagesHwWithoutBe});
   if [ $LEN -gt 0 ]
   then
      if [ -d "${tempPath}/${messagesHwWithoutBe}" ]
      then 
         rm -rf "${tempPath}/${messagesHwWithoutBe}";
      fi
      mkdir "${tempPath}/${messagesHwWithoutBe}";
      break;
   else
      #echo "Info: Found only messages rows with be## names.";
      messagesHwWithoutBe="unknown";
   fi 
done < "${tmpFile2}"   

if [[ $messagesHwWithoutBe == "unknown" ]]
then
    if [ -d "${tempPath}/${messagesHwWithoutBe}" ]
   then 
      rm -rf "${tempPath}/${messagesHwWithoutBe}";
   fi
    mkdir "${tempPath}/${messagesHwWithoutBe}";
fi 

if [[ $messagesHwWithoutBe != "unknown" ]]
then
   fileName="${tempPath}/${messagesHwWithoutBe}/"$2"_${messagesHwWithoutBe}";
   if [ -f "$fileName" ]
   then 
      rm -rf "$fileName";
   fi
   sed -n '/'${messagesHwWithoutBe}'/p' "${tmpFile}" >> "$fileName";
   if [ -f "$tmpFile" ]
   then 
      rm -rf "$tmpFile";
      rm -rf "$tmpFile2";
   fi

   fileSize_tmp=$(ls -l "$fileName");
   fileSize=$(echo "${fileSize_tmp}" | awk '{print $5}');
   
   if [[ $fileSize -lt 1 ]]
   then
      rm -rf "$fileName";
   else 
      echo "$fileName";
   fi
fi 

for (( l = 1 ; l < 21 ; l++ ))
do 
   fileName="${tempPath}/${messagesHwWithoutBe}/"$2"_be${l}";
      
   if [ -f "$fileName" ]
   then 
      rm -rf "$fileName";
   fi
   if [ -f "$tmpFile" ]
   then 
      rm -rf "$tmpFile";
   fi

   sed -n '/@be'${l}'/p' $1 >> "$tmpFile";
   if [ -f "$tmpFile" ]
   then     
      sed '/@be'${l}'[0-9]/d' "$tmpFile" > "$fileName";
   fi
   
   if [ -f "$fileName" ]
   then
      fileSize_tmp=$(ls -l "$fileName");
      fileSize=$(echo "${fileSize_tmp}" | awk '{print $5}');
      
      if [[ $fileSize -ge 1 ]]
      then
         echo "$fileName";
      else
         rm -rf "$fileName";
      fi
   fi
done
  
}

#separate MessagesAll to nodes (CMI SPECIFIC)
function seperateNodeMessages_CMI_specific() {

for (( l = 1 ; l < 21 ; l++ ))
do 
   fileName="${tempPath}/${messagesHwWithoutBe}/"$2"_CMI_be${l}";
   tmpFile="${tempPath}/${messagesHwWithoutBe}/"$2"_CMI_be${l}_tmp";
   
   if [ -f "$fileName" ]
   then 
      rm -rf "$fileName";
   fi
   if [ -f "$tmpFile" ]
   then 
      rm -rf "$tmpFile";
   fi
   
   sed -n '/@be'${l}'/p' $1 >> "$tmpFile";
   if [ -f "$tmpFile" ]
   then     
      sed '/@be'${l}'[0-9]/d' "$tmpFile" > "$fileName";
   fi
   
   if [ -f "$fileName" ]
   then
      fileSize_tmp=$(ls -l "$fileName");
      fileSize=$(echo "${fileSize_tmp}" | awk '{print $5}');   
      if [[ $fileSize -ge 1 ]]
      then
         echo "$fileName";
      else
         rm -rf "$fileName";
      fi
   fi
   
done
  
}

#separate one file (e.g. MsgStatAll) to nodes
function seperateNodeFile() {

for (( l = 0 ; l < ${#hwNames[@]} ; l++ ))
do 
   for (( m = 1 ; m < 21 ; m++ ))
    do 
      if [[ m -lt 10 ]]
      then
         fileName="${tempPath}/${messagesHwWithoutBe}/"$2"_${productType}_${hwNames[l]}0${m}";
      else
         fileName="${tempPath}/${messagesHwWithoutBe}/"$2"_${productType}_${hwNames[l]}${m}";
      fi
      if [ -f "$fileName" ]
      then 
         rm -rf "$fileName";
      fi
      if [[ m -lt 10 ]]
      then
         sed -n '/'${hwNames[l]}'0'${m}'/p' $1 >> "$fileName";
      else
         sed -n '/'${hwNames[l]}${m}'/p' $1 >> "$fileName";
      fi 
      fileSize_tmp=$(ls -l "$fileName");
      fileSize=$(echo "${fileSize_tmp}" | awk '{print $5}');      
      if [[ $fileSize -lt 1 ]]
      then
         rm -rf "$fileName";
      else 
         echo "$fileName";
      fi 
   done
done
  
}

#separateNodes function
function separateNodes() {
 
targetPath=$1;

#appending current path to the variables
location_messages=${targetPath}"/messages";
location_messages1=${targetPath}"/messages.1";
location_messages2=${targetPath}"/messages.2";
location_messages3=${targetPath}"/messages.3";
location_messages4=${targetPath}"/messages.4";

location_MsgStat=${targetPath}"/MsgStat";
location_MsgStat1=${targetPath}"/MsgStat.1";
location_MsgStat2=${targetPath}"/MsgStat.2";
location_MsgStat3=${targetPath}"/MsgStat.3";
location_MsgStat4=${targetPath}"/MsgStat.4";

location_MsgErr=${targetPath}"/MsgErr";
location_MsgErr1=${targetPath}"/MsgErr.1";
location_MsgErr2=${targetPath}"/MsgErr.2";
location_MsgErr3=${targetPath}"/MsgErr.3";
location_MsgErr4=${targetPath}"/MsgErr.4";

location_sc_print=${targetPath}"/sc_print";
location_sc_print1=${targetPath}"/sc_print.1";
location_sc_print2=${targetPath}"/sc_print.2";
location_sc_print3=${targetPath}"/sc_print.3";
location_sc_print4=${targetPath}"/sc_print.4";

location_sc_print_c=${targetPath}"/sc_print_c";
location_sc_print_c1=${targetPath}"/sc_print_c.1";
location_sc_print_c2=${targetPath}"/sc_print_c.2";
location_sc_print_c3=${targetPath}"/sc_print_c.3";
location_sc_print_c4=${targetPath}"/sc_print_c.4";

location_sc_print_e=${targetPath}"/sc_print_e";
location_sc_print_e1=${targetPath}"/sc_print_e.1";
location_sc_print_e2=${targetPath}"/sc_print_e.2";
location_sc_print_e3=${targetPath}"/sc_print_e.3";
location_sc_print_e4=${targetPath}"/sc_print_e.4";

location_sc_print_db=${targetPath}"/sc_print_db";
location_sc_print_db1=${targetPath}"/sc_print_db.1";
location_sc_print_db2=${targetPath}"/sc_print_db.2";
location_sc_print_db3=${targetPath}"/sc_print_db.3";
location_sc_print_db4=${targetPath}"/sc_print_db.4";

location_messages_all=${tempPath}"/messages_all";
location_messages_all_tmp=${tempPath}"/messages_all_tmp";

location_MsgStat_all=${tempPath}"/MsgStat_all";
location_MsgStat_all_tmp=${tempPath}"/MsgStat_all_tmp";

location_MsgErr_all=${tempPath}"/MsgErr_all";
location_MsgErr_all_tmp=${tempPath}"/MsgErr_all_tmp";

location_sc_print_all=${tempPath}"/sc_print_all";
location_sc_print_all_tmp=${tempPath}"/sc_print_all_tmp";

location_sc_print_c_all=${tempPath}"/sc_print_c_all";
location_sc_print_c_all_tmp=${tempPath}"/sc_print_c_all_tmp";

location_sc_print_e_all=${tempPath}"/sc_print_e_all";
location_sc_print_e_all_tmp=${tempPath}"/sc_print_e_all_tmp";

location_sc_print_db_all=${tempPath}"/sc_print_db_all";
location_sc_print_db_all_tmp=${tempPath}"/sc_print_db_all_tmp";

#join messages.#
joinMsgStatOrSimilar ${location_messages} ${location_messages1} ${location_messages2} ${location_messages3} ${location_messages4} ${location_messages_all} ${location_messages_all_tmp};

#join MsgStat.#
joinMsgStatOrSimilar ${location_MsgStat} ${location_MsgStat1} ${location_MsgStat2} ${location_MsgStat3} ${location_MsgStat4} ${location_MsgStat_all} ${location_MsgStat_all_tmp};

#join MsgErr.#
joinMsgStatOrSimilar ${location_MsgErr} ${location_MsgErr1} ${location_MsgErr2} ${location_MsgErr3} ${location_MsgErr4} ${location_MsgErr_all} ${location_MsgErr_all_tmp};

#join sc_print.#
joinMsgStatOrSimilar ${location_sc_print} ${location_sc_print1} ${location_sc_print2} ${location_sc_print3} ${location_sc_print4} ${location_sc_print_all} ${location_sc_print_all_tmp};

#join sc_print_c.#
joinMsgStatOrSimilar ${location_sc_print_c} ${location_sc_print_c1} ${location_sc_print_c2} ${location_sc_print_c3} ${location_sc_print_c4} ${location_sc_print_c_all} ${location_sc_print_c_all_tmp};

#join sc_print_e.#
joinMsgStatOrSimilar ${location_sc_print_e} ${location_sc_print_e1} ${location_sc_print_e2} ${location_sc_print_e3} ${location_sc_print_e4} ${location_sc_print_e_all} ${location_sc_print_e_all_tmp};

#join sc_print_db.#
joinMsgStatOrSimilar ${location_sc_print_db} ${location_sc_print_db1} ${location_sc_print_db2} ${location_sc_print_db3} ${location_sc_print_db4} ${location_sc_print_db_all} ${location_sc_print_db_all_tmp};

targetPath_tmp=$(grep ${productType}';' ${confPath}/logAnalyzer.conf | awk -F";" '{print $2}');
OIFS=$IFS 
IFS=',' 
productCounter=0;
for x in $targetPath_tmp
do
   hwNames[productCounter]="$x";
   productCounter=$((productCounter+1));
done  
IFS=$OIFS

if [ -f $location_messages_all ]
then
   seperateNodeMessages "${location_messages_all}" messages;
fi
if [ -f $location_MsgStat_all ]
then
   seperateNodeFile "${location_MsgStat_all}" MsgStat;
fi
if [ -f $location_MsgErr_all ]
then
   seperateNodeFile "${location_MsgErr_all}" MsgErr;
fi
if [ -f $location_sc_print_all ]
then
   seperateNodeFile "${location_sc_print_all}" sc_print;
fi
if [ -f $location_sc_print_c_all ]
then
   seperateNodeFile "${location_sc_print_c_all}" sc_print_c;
fi
if [ -f $location_sc_print_e_all ]
then
   seperateNodeFile "${location_sc_print_e_all}" sc_print_e;
fi
if [ -f $location_sc_print_db_all ]
then
   seperateNodeFile "${location_sc_print_db_all}" sc_print_db;
fi

#CMI specific
location_CMI=${targetPath}"/CMI.log";
if [ -f $location_CMI ]
then
   location_CMI1=${targetPath}"/CMI.log.1";
   location_CMI2=${targetPath}"/CMI.log.2";
   location_CMI3=${targetPath}"/CMI.log.3";
   location_CMI4=${targetPath}"/CMI.log.4";
   
   location_CMI_all=${tempPath}"/CMI_all";
   location_CMI_all_tmp=${tempPath}"/CMI_all_tmp";

   joinMsgStatOrSimilar ${location_CMI} ${location_CMI1} ${location_CMI2} ${location_CMI3} ${location_CMI4} ${location_CMI_all} ${location_CMI_all_tmp};
      
   if [ -f $location_CMI_all ]
   then
      seperateNodeMessages_CMI_specific "${location_CMI_all}" messages;
   fi
   
fi
#end CMI specific

unset hwNames;

}

#separateNodes function
function separateNodesMain() {

#checking existance of current target files
checkExistance;
if [ $flagFileExistance == 1 ]
then
   return;  
fi

#extracting tar file 
extractFiles;

#checking existance of new target files
if [ $flagFileExistance == 1 ]
then
   return;  
fi
  
flagOversize=0;
#checking size of messages files - node 1
checkSize ${targetPath1};
#checking size of messages files - node 2
if [ $nodeNr == 2 ]
then
   checkSize ${targetPath2};
fi
if [ $flagOversize == 1 ]
then
   return;  
fi
  
echo;
echo "Separating files...";
echo;

echo "Results in files: ";

#node 1
nodeName="node1";
separateNodes ${targetPath1};
#node 2
nodeName="node2";
if [ $nodeNr == 2 ]
then
   separateNodes ${targetPath2};
fi

targetPath1=$(grep 'Source path 1:' ${confPath}/logAnalyzer.conf | awk -F": " '{print $2}');
targetPath2=$(grep 'Source path 2:' ${confPath}/logAnalyzer.conf | awk -F": " '{print $2}');

}

#read data from files to Array - called from logSearch
function readToArray() {

i=0;
j=0;
flagDTRC=0;
flagResetType=0;
flagRecognized=0;
sysupFound=0;
secureFound=0; 
CURRENT="";
CURRENT_compare="";
TARGET_compare="";
while read line    
do  
   
   #read Oops (flagResetType 1)
   #Oops lines (Oops reset)
   if [[ $line == *" kernel: Oops: "* ]]
   then  
      if [[ $flagResetType != 0 ]]
      then
         value[i]="No further info for this reset.";
         name[i]="ERROR: ";
         i=$((i+1));
         value[i]="------------------";
         name[i]="-------------------";
         i=$((i+1));
         j=0;
         flagResetType=0;
         flagRecognized=1;
      fi
      value[i]=$(echo "${line}" | awk -F" kernel: " '{print $1}')" [n${currentNode}]";
      name[i]="Reset: ";
      i=$((i+1));
      j=$((j+1));
      value[i]=$(echo "${line}" | awk -F" kernel: " '{print $2}' | cut -d ":" -f1);
      name[i]="Reason: ";
      i=$((i+1));
      j=$((j+1));
      flagResetType=1;     
   fi
   #LR lines (Oops reset)
   if  [[ $flagResetType == 1 ]] && [[ $j == 2 ]] && [[ $line == *" NIP: "* ]] && [[ $line == *" LR: "* ]] && [[ $line == *" SP: "* ]]
   then  
      value[i]=$(echo "${line}" | awk -F" NIP: " '{print $2}' | cut -d " " -f1);
      name[i]="NIP: ";
      i=$((i+1));
      j=$((j+1));
      value[i]=$(echo "${line}" | awk -F" LR: " '{print $2}' | cut -d " " -f1);
      name[i]="LR: ";
      i=$((i+1));
      j=$((j+1));
      value[i]=$(echo "${line}" | awk -F" SP: " '{print $2}' | cut -d " " -f1);
      name[i]="SP: ";
      i=$((i+1));
      j=$((j+1));
   fi
   #DAR lines (Oops reset)
   if [[ $flagResetType == 1 ]] && [[ $j == 5 ]] && [[ $line == *" kernel: DAR: "* ]]
   then  
      value[i]=$(echo "${line}" | awk -F" DAR: " '{print $2}' | cut -d "," -f1);
      name[i]="DAR: ";
      i=$((i+1));
      j=$((j+1));
   fi
   #"TASK" lines (Oops reset)
   if [[ $flagResetType == 1 ]] && [[ $j == 6 ]] && [[ $line == *" kernel: TASK = "* ]]
   then  
      value[i]=$(echo "${line}" | awk -F" kernel: TASK = " '{print $2}' | cut -d " " -f2);
      name[i]="Proces: ";
      i=$((i+1));
      j=$((j+1));
   fi
   #"Call trace" lines (Oops reset)
   if [[ $flagResetType == 1 ]] && [[ $j == 7 ]] && [[ $line == *" kernel: Call trace:"* ]]
   then  
      value[i]="";
      name[i]="Call trace: ";
      i=$((i+1));
      j=$((j+1));
   fi
   #10 lines after call trace
   if [[ $flagResetType == 1 ]] && [[ $line != *" kernel: Call trace:"* ]] && [[ $j == 8 ]] || [[ $j == 9 ]] || [[ $j == 10 ]] || [[ $j == 11 ]] || [[ $j == 12 ]] || [[ $j == 13 ]] || [[ $j == 14 ]] || [[ $j == 15 ]] || [[ $j == 16 ]] || [[ $j == 17 ]]
   then
      value[i]=$(echo "${line}" | awk -F" kernel: " '{print $2}');
      name[i]="            ";
      i=$((i+1));
      j=$((j+1)); 
   fi    
   #"DTRC" lines (Oops reset)
   if [[ $flagResetType == 1 ]] && [[ $j == 18 ]]
   then  
      flagDTRC=1;
      j=$((j+1));
   fi 

   #read overload (flagResetType 2)
   #overload lines (overload reset)
   if [[ $line == *" usage of physical memory ("* ]] && [[ $line == *" is over the limit ("* ]]
   then  
      if [[ $flagResetType != 0 ]]
      then
         value[i]="No further info for this reset.";
         name[i]="ERROR: ";
         i=$((i+1));
         value[i]="------------------";
         name[i]="-------------------";
         i=$((i+1));
         j=0;
         flagResetType=0;
         flagRecognized=1;
      fi    
      value[i]=$(echo "${line}" | awk -F" overload" '{print $1}')" [n${currentNode}]";    
      name[i]="Reset: ";
      i=$((i+1));
      j=$((j+1));
      value[i]=$(echo "${line}" | awk -F": " '{print $3}');
      name[i]="Reason: ";
      i=$((i+1));
      j=$((j+1));
      flagResetType=2;
   fi 
   #"DTRC" lines (overload reset)
   if [[ $flagResetType == 2 ]] && [[ $j == 2 ]]
   then  
      flagDTRC=1;
      j=$((j+1));
   fi 

   #read watchdog (flagResetType 3)
   #WDT lines (watchdog reset)   
   if [[ $line == *" WDT expiried"* ]]
   then  
      if [[ $flagResetType != 0 ]]
      then
         value[i]="No further info for this reset.";
         name[i]="ERROR: ";
         i=$((i+1));
         value[i]="------------------";
         name[i]="-------------------";
         i=$((i+1));
         j=0;
         flagResetType=0;
         flagRecognized=0;
      fi       
      if [[ $i -gt 2 ]]
      then
         tmpWDT="${name[i-2]}";
         if [[ $tmpWDT == "ERROR: " ]]
         then
            value_tmp=$(echo "${line}" | awk -F" " '{print $4}');     
            value[i]="${CURRENT} ${value_tmp} [n${currentNode}]"; # that is just for consistency, because of unknown reset time should be: value[i]="[unknown time] ${value_tmp}";  
            name[i]="Reset: ";
            i=$((i+1));
            value[i]=$(echo "${line}" | awk -F" dtrc: " '{print $2}');
            name[i]="Reason: ";
            i=$((i+1));
            value[i]="";
            name[i]="";
            i=$((i+1));
            value[i]="${CURRENT}";
            name[i]="System startup at: ";
            i=$((i+1));
            value[i]="------------------";
            name[i]="-------------------";
            i=$((i+1));
            flagResetType=3;
            flagRecognized=0;    
         fi
         tmpWDT="${value[i-3]}";
         if [[ $tmpWDT == "Unknown"* ]]
         then
            value_tmp=$(echo "${line}" | awk -F" " '{print $4}');     
            value[i-4]="${CURRENT} ${value_tmp} [n${currentNode}]";           
            value[i-3]=$(echo "${line}" | awk -F" dtrc: " '{print $2}');         
            value[i-2]="";
            name[i-2]="";     
            value[i-1]="${CURRENT}";
            name[i-1]="System startup at: ";
            value[i]="------------------";
            name[i]="-------------------";
            i=$((i+1));
            flagResetType=3;
            flagRecognized=0; 
         fi
      else
         value[i]=$(echo "${line}" | awk -F" dtrc: " '{print $1}')" [n${currentNode}]";
         name[i]="Reset: ";
         i=$((i+1));
         value[i]=$(echo "${line}" | awk -F" dtrc: " '{print $2}');
         name[i]="Reason: ";
         i=$((i+1));
         value[i]="";
         name[i]="";
         i=$((i+1));
         value[i]=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3}');
         name[i]="System startup at: ";
         i=$((i+1));
         value[i]="------------------";
         name[i]="-------------------";
         i=$((i+1));
         flagResetType=3;
         flagRecognized=0;
      fi    
   fi 
   #"DTRC" lines (watchdog reset)
   if [[ $flagResetType == 3 ]] && [[ $line == *" ERR_DTRC_"* ]]
   then  
      value_tmp=$(echo "${line}" | awk -F" ERR_DTRC_" '{print $2}' | cut -d " " -f1);
      if [[ ${value_tmp} == "SAV_DTRC" ]]
      then
         value_tmp=$(echo "${line}" | awk -F" ERR_DTRC_SAV_DTRC " '{print $2}' | cut -d "," -f1);
         if [[ ${#value_tmp} == 1 ]]
         then
            value[i-3]="dtrc.00"${value_tmp};
         elif [[ ${#value_tmp} == 2 ]]
         then
            value[i-3]="dtrc.0"${value_tmp};
         elif [[ ${#value_tmp} == 3 ]]
         then
            value[i-3]="dtrc."${value_tmp};    
         fi 
      else
         value[i-3]="DOES NOT EXIST!";
      fi          
   name[i-3]="DTRC#: ";
   flagResetType=0;
   fi 

   #read internal reboot request (flagResetType 4)
   #SYSUP Reboot request lines (SYSUP REQ EXT reset)
   if [[ $line == *" SYSUP Reboot request ("* ]]
   then  
      if [[ $flagResetType != 0 ]]
      then
         value[i]="No further info for this reset.";
         name[i]="ERROR: ";
         i=$((i+1));
         value[i]="------------------";
         name[i]="-------------------";
         i=$((i+1));
         j=0;
         flagResetType=0;
         flagRecognized=1;
      fi
      value[i]=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3" "$4}')" [n${currentNode}]";
      name[i]="Reset: ";
      i=$((i+1));
      j=$((j+1));
      value[i]="Internal reboot request (SYSUP)."
      name[i]="Reason: ";
      i=$((i+1));
      j=0;
      flagResetType=0;
      flagRecognized=1;
   fi    

   #read external reboot request (flagResetType 5)
   #SYSUP Reboot request external lines (SYSUP REQ EXT reset)
   if [[ $line == *" SYSUP Reboot request external ("* ]]
   then  
      if [[ $flagResetType != 0 ]]
      then
         value[i]="No further info for this reset.";
         name[i]="ERROR: ";
         i=$((i+1));
         value[i]="------------------";
         name[i]="-------------------";
         i=$((i+1));
         j=0;
         flagResetType=0;
         flagRecognized=1;
      fi
      value[i]=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3" "$4}')" [n${currentNode}]";   
      name[i]="Reset: ";
      i=$((i+1));
      j=$((j+1));
      value[i]="External reboot request (SYSUP)."  
      name[i]="Reason: ";
      i=$((i+1));
      j=$((j+1));
      flagResetType=5;
   fi 
   if [[ $flagResetType == 5 ]] && [[ $j == 2 ]] && [[ $line == *"mwd"* ]] && [[ $line != *" SYSUP Reboot request external ("* ]]
   then      
      value[i]=$(echo "${line}");
      name[i]="Next line: ";
      i=$((i+1));
      j=0;
      flagResetType=0;
      flagRecognized=1;
   fi    

   #read direct reboot request (flagResetType 6)
   #direct Reboot request! lines (SYSUP REQ EXT reset)
   if [[ $line == *" DIRECT Reboot request!"* ]]
   then  
      if [[ $flagResetType != 0 ]]
      then
         value[i]="No further info for this reset.";
         name[i]="ERROR: ";
         i=$((i+1));
         value[i]="------------------";
         name[i]="-------------------";
         i=$((i+1));
         j=0;
         flagResetType=0;
         flagRecognized=1;
      fi
      value[i]=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3" "$4}')" [n${currentNode}]";      
      name[i]="Reset: ";
      i=$((i+1));
      j=$((j+1));
      value[i]="Internal reboot request (no core available)."
      name[i]="Reason: ";
      i=$((i+1));
      j=0;
      flagResetType=0;
      flagRecognized=1;
   fi    

   #read UPRPD (flagResetType 7)
   #Reboot caused by setting... line (UPRPD reset)
   if [[ $line == *"Reboot caused by setting "* ]]
   then  
      if [[ $flagResetType != 0 ]]
      then
         value[i]="No further info for this reset.";
         name[i]="ERROR: ";
         i=$((i+1));
         value[i]="------------------";
         name[i]="-------------------";
         i=$((i+1));
         j=0;
         flagResetType=0;
         flagRecognized=1;
      fi
      value[i]=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3" "$4}')" [n${currentNode}]";      
      name[i]="Reset: ";
      i=$((i+1));
      j=$((j+1));
      value[i]=$(echo "${line}" | awk -F" Reboot caused by " '{print $2}' | awk -F" " '{print $1" "$2" "$3" "$4" "$5" "$6}');
      name[i]="Reason: ";
      i=$((i+1));
      j=0;
      flagResetType=0;
      flagRecognized=1;
   fi 

   #read NOT REGISTERED (flagResetType 8)
   if [[ $line == *" NOT REGISTERED !!!"* ]]
   then  
      if [[ $flagResetType != 0 ]]
      then
         value[i]="No further info for this reset.";
         name[i]="ERROR: ";
         i=$((i+1));
         value[i]="------------------";
         name[i]="-------------------";
         i=$((i+1));
         j=0;
         flagResetType=0;
         flagRecognized=1;
      fi
      value[i]=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3" "$4}')" [n${currentNode}]";      
      name[i]="Reset: ";
      i=$((i+1));
      j=$((j+1));
      value[i]=$(echo "${line}" | awk -F"]: " '{print $3}');
      name[i]="Reason: ";
      i=$((i+1));
      j=0;
      flagResetType=0;
      flagRecognized=1;
   fi 
   
   #read NOT IN REQUIRED STATE (flagResetType 9)
   if [[ $line == *" not in required state (ACT)"* ]]
   then  
      if [[ $flagResetType != 0 ]]
      then
         value[i]="No further info for this reset.";
         name[i]="ERROR: ";
         i=$((i+1));
         value[i]="------------------";
         name[i]="-------------------";
         i=$((i+1));
         j=0;
         flagResetType=0;
         flagRecognized=1;
      fi
      value[i]=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3" "$4}')" [n${currentNode}]";   
      name[i]="Reset: ";
      i=$((i+1));
      j=$((j+1));
      value[i]=$(echo "${line}" | awk -F"]: " '{print $3}');
      name[i]="Reason: ";
      i=$((i+1));
      j=0;
      flagResetType=0;
      flagRecognized=1;
   fi
   
   #read MN reboot (flagResetType 10)
   if [[ $line == *" MN reboot require "* ]]
   then  
      if [[ $flagResetType != 0 ]]
      then
         value[i]="No further info for this reset.";
         name[i]="ERROR: ";
         i=$((i+1));
         value[i]="------------------";
         name[i]="-------------------";
         i=$((i+1));
         j=0;
         flagResetType=0;
         flagRecognized=1;
      fi
      value[i]=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3" "$4}')" [n${currentNode}]";      
      name[i]="Reset: ";
      i=$((i+1));
      j=$((j+1));
      value[i]="MN reboot";
      name[i]="Reason: ";
      i=$((i+1));
      j=0;
      flagResetType=0;
      flagRecognized=1;
   fi
   
   #read blade removed reboot (flagResetType 11)
   if [[ $line == *": Switching to runlevel: 8"* ]]
   then  
      if [[ $flagResetType != 0 ]]
      then
         value[i]="No further info for this reset.";
         name[i]="ERROR: ";
         i=$((i+1));
         value[i]="------------------";
         name[i]="-------------------";
         i=$((i+1));
         j=0;
         flagResetType=0;
         flagRecognized=1;
      fi
      value[i]=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3" "$4}')" [n${currentNode}]";   
      name[i]="Reset: ";
      i=$((i+1));
      j=$((j+1));
      value[i]="Blade physically removed.";
      name[i]="Reason: ";
      i=$((i+1));
      j=0;
      flagResetType=0;
      flagRecognized=1;
   fi
   
   #read power off reboot (flagResetType 12)
   if [[ $line == *": Switching to runlevel: 0"* ]]
   then  
      if [[ $flagResetType != 0 ]]
      then
         value[i]="No further info for this reset.";
         name[i]="ERROR: ";
         i=$((i+1));
         value[i]="------------------";
         name[i]="-------------------";
         i=$((i+1));
         j=0;
         flagResetType=0;
         flagRecognized=1;
      fi
      value[i]=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3" "$4}')" [n${currentNode}]";      
      name[i]="Reset: ";
      i=$((i+1));
      j=$((j+1));
      value[i]="Physical power off.";
      name[i]="Reason: ";
      i=$((i+1));
      j=0;
      flagResetType=0;
      flagRecognized=1;
   fi
   
   #look  to sysup for reset reason or make reset unknown      
   
   #DTRC for Oops and overload (DTRC line appears after linux version line)
   if [[ $flagDTRC == 2 ]] && [[ $flagResetType != 0 ]] && [[ $line == *" ERR_DTRC_"* ]]
   then
      value_tmp=$(echo "${line}" | awk -F" ERR_DTRC_" '{print $2}' | cut -d " " -f1);
      if [[ ${value_tmp} == "SAV_DTRC" ]]
      then
         value_tmp=$(echo "${line}" | awk -F" ERR_DTRC_SAV_DTRC " '{print $2}' | cut -d "," -f1);
         if [[ ${#value_tmp} == 1 ]]
         then
            value[i]="dtrc.00"${value_tmp};
         elif [[ ${#value_tmp} == 2 ]]
         then
            value[i]="dtrc.0"${value_tmp};
         elif [[ ${#value_tmp} == 3 ]]
         then
            value[i]="dtrc."${value_tmp};   
         fi 
      else
         value[i]="DOES NOT EXIST!";
      fi       
      name[i]="DTRC#: ";
      i=$((i+2));
      value[i]="------------------";
      name[i]="-------------------";
      i=$((i+1));
      j=0;
      flagDTRC=0;
      flagResetType=0;
      flagRecognized=0;
   fi
   
   #when resets before were finished
   if [[ $flagResetType == 0 ]] && [[ $line == *" kernel: Linux version "* ]]
   then 
      CURRENT=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3}');  
      if [[ $busybox_flag -eq 1 ]]
      then
         dateShapeToBusybox ${CURRENT};
         CURRENT_compare="${date_busybox}";
      else
         CURRENT_compare="${CURRENT}";
      fi       
      if [[ $flagRecognized == 1 ]] #we have found "Linux version" for the reset already recognized
      then
         flagRecognized=0; 
         value[i]="${CURRENT}";
         name[i]="System startup at: ";
         i=$((i+1));  
         value[i]="------------------";
         name[i]="-------------------";
         i=$((i+1));
      else #we have found "Linux version" for the reset that wasn't recognized                                                
         value_tmp=$(echo "${line}" | awk -F" " '{print $4}');       
         if [[ $Domena[m] == "be"* ]] #for this example doesn't exist any sysup or secure file
         then                         
            value[i]="${CURRENT} ${value_tmp} [n${currentNode}]"; # that is just for consistency, because of unknown reset time should be: value[i]="[unknown time] ${value_tmp}";
            name[i]="Reset: ";
            i=$((i+1));
            value[i]="Unknown, more details in ${location_messages_user}";
            name[i]="Reason: ";
            i=$((i+1));
            value[i]="${CURRENT}";
            name[i]="System startup at: ";
            i=$((i+1)); 
            value[i]="------------------";
            name[i]="-------------------";
            i=$((i+1));                   
         else                              
            a=$i;             
            if [[ $SysupFileSize -gt 1 ]] && [[ $l != "CMI" ]] #look to sysup for possible reset reason
            then                 
               while read line    
               do            
                  lineStart=$(echo "${line}" | awk -F" " '{print $1}');       
                  if [[ "${lineStart}" == "Mon" ]] || [[ "${lineStart}" == "Tue" ]] || [[ "${lineStart}" == "Wed" ]] || [[ "${lineStart}" == "Thu" ]] || [[ "${lineStart}" == "Fri" ]]
                  then                  
                     TARGET=$(echo "${line}" | awk -F" " '{print $2" "$3" "$4}' | awk -F":" '{print $1":"$2":"$3}');   
                     if [[ $busybox_flag -eq 1 ]]
                     then
                        dateShapeToBusybox ${TARGET};
                        TARGET_compare="${date_busybox}";
                     else
                        TARGET_compare="${TARGET}";
                     fi             
                     if [[ $(( $(date -u -d "$CURRENT_compare" +%s) - $(date -u -d "$TARGET_compare" +%s) )) -lt 600 ]] && [[ $(( $(date -u -d "$CURRENT_compare" +%s) - $(date -u -d "$TARGET_compare" +%s) )) -gt 0 ]]                                                
                     then              
                        if [[ $line == *"Missing process:"* ]]       
                        then                                         
                           value[i]="${TARGET} ${value_tmp} [n${currentNode}]";
                           name[i]="Reset: ";
                           i=$((i+1));
                           value[i]=$(echo "${line}" | awk -F"Missing process: " '{print $2}');
                           name[i]="Reason: Missing process: ";
                           i=$((i+1));
                           value[i]="${CURRENT}";
                           name[i]="System startup at: ";
                           i=$((i+1));
                           value[i]="------------------";
                           name[i]="-------------------";
                           i=$((i+1));
                           break;
                        fi
                     elif [[ $CURRENT == "Jan 1 00:0"* ]] && [[ $TARGET == "Dec 31 23:5"* ]] #check time around year change (format here is "Jan 1", not "Jan  1")
                     then
                        if [[ $line == *"Missing process:"* ]]       
                        then                                         
                           value[i]="${TARGET} ${value_tmp} [n${currentNode}]";
                           name[i]="Reset: ";
                           i=$((i+1));
                           value[i]=$(echo "${line}" | awk -F"Missing process: " '{print $2}');
                           name[i]="Reason: Missing process: ";
                           i=$((i+1));
                           value[i]="${CURRENT}";
                           name[i]="System startup at: ";
                           i=$((i+1));
                           value[i]="------------------";
                           name[i]="-------------------";
                           i=$((i+1));
                           break;
                        fi
                     fi             
                  fi  
               done < "${location_sysup_all}"
               if [[ $i == $a ]]
               then
                  sysupFound=1;                    
               fi
            else
               sysupFound=1;
            fi
            
            if [[ $SecureFileSize -gt 1 ]] && [[ $l != "CMI" ]] #look to secure for possible reset reason
            then
               while read line    
               do            
                  lineStart=$(echo "${line}" | awk -F" " '{print $1}');       
                  if [[ "${lineStart}" == "Jan" ]] || [[ "${lineStart}" == "Feb" ]] || [[ "${lineStart}" == "Mar" ]] || [[ "${lineStart}" == "Apr" ]] || [[ "${lineStart}" == "May" ]] || [[ "${lineStart}" == "Jun" ]] || [[ "${lineStart}" == "Jul" ]] || [[ "${lineStart}" == "Aug" ]] || [[ "${lineStart}" == "Sep" ]] || [[ "${lineStart}" == "Oct" ]] || [[ "${lineStart}" == "Nov" ]] || [[ "${lineStart}" == "Dec" ]]
                  then                  
                     TARGET=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3}' | awk -F":" '{print $1":"$2":"$3}');   
                     if [[ $busybox_flag -eq 1 ]]
                     then
                        dateShapeToBusybox ${TARGET};
                        TARGET_compare="${date_busybox}";
                     else
                        TARGET_compare="${TARGET}";
                     fi                      
                     if [[ $(( $(date -u -d "$CURRENT_compare" +%s) - $(date -u -d "$TARGET_compare" +%s) )) -lt 300 ]] && [[ $(( $(date -u -d "$CURRENT_compare" +%s) - $(date -u -d "$TARGET_compare" +%s) )) -gt 0 ]]            
                     then                                         
                        if [[ $line == *" reboot"* ]]       
                        then                
                           value[i]="${TARGET} ${value_tmp} [n${currentNode}]";
                           name[i]="Reset: ";
                           i=$((i+1));
                           value[i]="console reboot";
                           name[i]="Reason: ";
                           i=$((i+1));
                           value[i]="${CURRENT}";
                           name[i]="System startup at: ";
                           i=$((i+1));
                           value[i]="------------------";
                           name[i]="-------------------";
                           i=$((i+1));
                           break;
                        fi 
                     elif [[ $CURRENT == "Jan 1 00:0"* ]] && [[ $TARGET == "Dec 31 23:5"* ]] #check time around year change (format here is "Jan 1", not "Jan  1")
                     then
                        if [[ $line == *" reboot"* ]]       
                        then                
                           value[i]="${TARGET} ${value_tmp} [n${currentNode}]";
                           name[i]="Reset: ";
                           i=$((i+1));
                           value[i]="console reboot";
                           name[i]="Reason: ";
                           i=$((i+1));
                           value[i]="${CURRENT}";
                           name[i]="System startup at: ";
                           i=$((i+1));
                           value[i]="------------------";
                           name[i]="-------------------";
                           i=$((i+1));
                           break;
                        fi 
                     fi                                    
                  fi  
               done < "${location_secure_tmp}"
               if [[ $i == $a ]]
               then
                  secureFound=1;                   
               fi
            else
               secureFound=1;
            fi
            
            if [[ $sysupFound == 1 ]] && [[ $secureFound == 1 ]]
            then              
               value[i]="${CURRENT} ${value_tmp} [n${currentNode}]"; # that is just for consistency, because of unknown reset time should be: value[i]="[unknown time] ${value_tmp}";
               name[i]="Reset: ";
               i=$((i+1));
               value[i]="Unknown, more details in ${location_messages_user}";
               name[i]="Reason: ";
               i=$((i+1));
               value[i]="${CURRENT}";
               name[i]="System startup at: ";
               i=$((i+1));
               value[i]="------------------";
               name[i]="-------------------";
               i=$((i+1));
            fi             
            sysupFound=0;
            secureFound=0;          
         fi    
      fi     
   fi 
   
   #when resets before were not finished
   if [[ $flagResetType != 0 ]] && [[ $line == *" kernel: Linux version "* ]]
   then
      CURRENT=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3}');
      if [[ $busybox_flag -eq 1 ]]
      then
         dateShapeToBusybox ${CURRENT};
         CURRENT_compare="${date_busybox}";
      else
         CURRENT_compare="${CURRENT}";
      fi 
      if [[ $flagDTRC == 1 ]] #DTRC for Oops and overload (DTRC line appears after linux version line)
      then
         value[i]="";
         name[i]="";
         value[i+1]=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3}');
         name[i+1]="System startup at: ";
         flagDTRC=2;
      else         
         value[i]="No further info for this reset.";
         name[i]="ERROR: ";
         i=$((i+1));
         value[i]="------------------";
         name[i]="-------------------";
         i=$((i+1));                
         j=0;
         flagResetType=0;
         flagRecognized=0;             
         value_tmp=$(echo "${line}" | awk -F" " '{print $4}');       
         if [[ $Domena[m] == "be"* ]] #for this example doesn't exist any sysup or secure file
         then                         
            value[i]="${CURRENT} ${value_tmp} [n${currentNode}]"; # that is just for consistency, because of unknown reset time should be: value[i]="[unknown time] ${value_tmp}";
            name[i]="Reset: ";
            i=$((i+1));
            value[i]="Unknown, more details in ${location_messages_user}";
            name[i]="Reason: ";
            i=$((i+1));
            value[i]="${CURRENT}";
            name[i]="System startup at: ";
            i=$((i+1)); 
            value[i]="------------------";
            name[i]="-------------------";
            i=$((i+1));                   
         else                              
            a=$i;
            if [[ $SysupFileSize -gt 1 ]] && [[ $l != "CMI" ]] #look to sysup for possible reset reason
            then
               while read line    
               do            
                  lineStart=$(echo "${line}" | awk -F" " '{print $1}');       
                  if [[ "${lineStart}" == "Mon" ]] || [[ "${lineStart}" == "Tue" ]] || [[ "${lineStart}" == "Wed" ]] || [[ "${lineStart}" == "Thu" ]] || [[ "${lineStart}" == "Fri" ]]
                  then                  
                     TARGET=$(echo "${line}" | awk -F" " '{print $2" "$3" "$4}' | awk -F":" '{print $1":"$2":"$3}');   
                     if [[ $busybox_flag -eq 1 ]]
                     then
                        dateShapeToBusybox ${TARGET};
                        TARGET_compare="${date_busybox}";
                     else
                        TARGET_compare="${TARGET}";
                     fi 
                     if [[ $(( $(date -u -d "$CURRENT_compare" +%s) - $(date -u -d "$TARGET_compare" +%s) )) -lt 600 ]] && [[ $(( $(date -u -d "$CURRENT_compare" +%s) - $(date -u -d "$TARGET_compare" +%s) )) -gt 0 ]]      
                     then              
                        if [[ $line == *"Missing process:"* ]]       
                        then                
                           value[i]="${TARGET} ${value_tmp} [n${currentNode}]";
                           name[i]="Reset: ";
                           i=$((i+1));
                           value[i]=$(echo "${line}" | awk -F"Missing process: " '{print $2}');
                           name[i]="Reason: Missing process: ";
                           i=$((i+1));
                           value[i]="${CURRENT}";
                           name[i]="System startup at: ";
                           i=$((i+1));
                           value[i]="------------------";
                           name[i]="-------------------";
                           i=$((i+1));
                           break;
                        fi
                     elif [[ $CURRENT == "Jan 1 00:0"* ]] && [[ $TARGET == "Dec 31 23:5"* ]] #check time around year change (format here is "Jan 1", not "Jan  1")
                     then  
                        if [[ $line == *"Missing process:"* ]]       
                        then                
                           value[i]="${TARGET} ${value_tmp} [n${currentNode}]";
                           name[i]="Reset: ";
                           i=$((i+1));
                           value[i]=$(echo "${line}" | awk -F"Missing process: " '{print $2}');
                           name[i]="Reason: Missing process: ";
                           i=$((i+1));
                           value[i]="${CURRENT}";
                           name[i]="System startup at: ";
                           i=$((i+1));
                           value[i]="------------------";
                           name[i]="-------------------";
                           i=$((i+1));
                           break;
                        fi
                     fi                         
                  fi  
               done < "${location_sysup_all}"
               if [[ $i == $a ]]
               then
                  sysupFound=1;                    
               fi
            else
               sysupFound=1;
            fi
            
            if [[ $SecureFileSize -gt 1 ]] && [[ $l != "CMI" ]] #look to secure for possible reset reason
            then
               while read line    
               do            
                  lineStart=$(echo "${line}" | awk -F" " '{print $1}');       
                  if [[ "${lineStart}" == "Jan" ]] || [[ "${lineStart}" == "Feb" ]] || [[ "${lineStart}" == "Mar" ]] || [[ "${lineStart}" == "Apr" ]] || [[ "${lineStart}" == "May" ]] || [[ "${lineStart}" == "Jun" ]] || [[ "${lineStart}" == "Jul" ]] || [[ "${lineStart}" == "Aug" ]] || [[ "${lineStart}" == "Sep" ]] || [[ "${lineStart}" == "Oct" ]] || [[ "${lineStart}" == "Nov" ]] || [[ "${lineStart}" == "Dec" ]]
                  then                  
                     TARGET=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3}' | awk -F":" '{print $1":"$2":"$3}');   
                     if [[ $busybox_flag -eq 1 ]]
                     then
                        dateShapeToBusybox ${TARGET};
                        TARGET_compare="${date_busybox}";
                     else
                        TARGET_compare="${TARGET}";
                     fi 
                     if [[ $(( $(date -u -d "$CURRENT_compare" +%s) - $(date -u -d "$TARGET_compare" +%s) )) -lt 300 ]] && [[ $(( $(date -u -d "$CURRENT_compare" +%s) - $(date -u -d "$TARGET_compare" +%s) )) -gt 0 ]]            
                     then                                         
                        if [[ $line == *" reboot"* ]]       
                        then                
                           value[i]="${TARGET} ${value_tmp} [n${currentNode}]";
                           name[i]="Reset: ";
                           i=$((i+1));
                           value[i]="console reboot";
                           name[i]="Reason: ";
                           i=$((i+1));
                           value[i]="${CURRENT}";
                           name[i]="System startup at: ";
                           i=$((i+1));
                           value[i]="------------------";
                           name[i]="-------------------";
                           i=$((i+1));
                           break;
                        fi
                     elif [[ $CURRENT == "Jan 1 00:0"* ]] && [[ $TARGET == "Dec 31 23:5"* ]] #check time around year change (format here is "Jan 1", not "Jan  1")
                     then  
                        if [[ $line == *" reboot"* ]]       
                        then                
                           value[i]="${TARGET} ${value_tmp} [n${currentNode}]";
                           name[i]="Reset: ";
                           i=$((i+1));
                           value[i]="console reboot";
                           name[i]="Reason: ";
                           i=$((i+1));
                           value[i]="${CURRENT}";
                           name[i]="System startup at: ";
                           i=$((i+1));
                           value[i]="------------------";
                           name[i]="-------------------";
                           i=$((i+1));
                           break;
                        fi
                     fi               
                  fi
               done < "${location_secure_tmp}"
               if [[ $i == $a ]]
               then
                  secureFound=1;                   
               fi
            else
               secureFound=1;
            fi
            
            if [[ $sysupFound == 1 ]] && [[ $secureFound == 1 ]]
            then              
               value[i]="${CURRENT} ${value_tmp} [n${currentNode}]"; # that is just for consistency, because of unknown reset time should be: value[i]="[unknown time] ${value_tmp}";
               name[i]="Reset: ";
               i=$((i+1));
               value[i]="Unknown, more details in ${location_messages_user}";
               name[i]="Reason: ";
               i=$((i+1));
               value[i]="${CURRENT}";
               name[i]="System startup at: ";
               i=$((i+1));
               value[i]="------------------";
               name[i]="-------------------";
               i=$((i+1));
            fi          
            sysupFound=0;
            secureFound=0;             
         fi    
      fi       
   fi          
done < "${tempPath}/messages_${Domena[$m]}_"$1

if [[ $flagRecognized == 1 ]] #reset needs to be finished in case there is no linux version line after the reset (at the end of the file)
then
   value[i]="No further info for this reset.";
   name[i]="ERROR: ";
   i=$((i+1));
   value[i]="------------------";
   name[i]="-------------------";
   i=$((i+1));
fi

}

#analysing log files and extracting informations from them 
function logSearch() {  
  
targetPath=$1;
  
#appending current path to the variables
location_messages=${targetPath}"/messages";
location_messages1=${targetPath}"/messages.1";
location_messages2=${targetPath}"/messages.2";
location_messages3=${targetPath}"/messages.3";
location_messages4=${targetPath}"/messages.4";

location_sysup=${targetPath}"/sysup.log";
location_sysup1=${targetPath}"/sysup.log.old";

location_messages_all=${tempPath}"/messages_all";
location_messages_all_tmp=${tempPath}"/messages_all_tmp";
location_messages_user=${tempPath}"/messages_n"${currentNode};

location_sysup_all=${tempPath}"/sysup_all";
location_sysup_all_tmp=${tempPath}"/sysup_all_tmp";

location_secure=${targetPath}"/secure";
location_secure_tmp=${tempPath}"/secure_tmp";
location_secure_tmp_2=${tempPath}"/secure_tmp_2";

#location "domena..." in  function seperateMgMessages

#join messages.#
joinMsgStatOrSimilar ${location_messages} ${location_messages1} ${location_messages2} ${location_messages3} ${location_messages4} ${location_messages_all} ${location_messages_all_tmp};

#prepare messages file for user (in case user wants to see input messages file)
cp ${location_messages_all} ${location_messages_user};

#extract only needed lines from messages (faster operation)
sed -n -e '/ kernel: Oops: /p' -e '/ NIP: /p' -e '/ kernel: DAR: /p' -e '/ kernel: TASK = /p' -e '/ kernel: Call trace:/{N;N;N;N;N;N;N;N;N;N;p;}' -e '/ERR_DTRC_/p' -e '/ usage of physical memory (/p' -e '/ WDT expiried/p' -e '/ Reboot request/{N;p;}' -e '/Reboot caused by setting /p' -e '/ kernel: Linux version /p' -e '/ NOT REGISTERED !!!/p' -e '/ not in required state (ACT)/p' -e '/ MN reboot require /p' -e '/: Switching to runlevel: 0/p' -e '/: Switching to runlevel: 8/p' -e '/ Entering ST_HSB_MODE_/p' "${location_messages_all}" > "${location_messages_all_tmp}";
#we need only lines with date included
sed -n -e '/Jan *[0-9]/p' -e '/Feb *[0-9]/p' -e '/Mar *[0-9]/p' -e '/Apr *[0-9]/p' -e '/May *[0-9]/p' -e '/Jun *[0-9]/p' -e '/Jul *[0-9]/p' -e '/Aug *[0-9]/p' -e '/Sep *[0-9]/p' -e '/Oct *[0-9]/p' -e '/Nov *[0-9]/p' -e '/Dec *[0-9]/p' "${location_messages_all_tmp}" > "${location_messages_all}";
#remove duplicated lines
awk '!x[$0]++' "${location_messages_all}" > "${location_messages_all_tmp}";
   
location_messages_all_tmp_size_tmp=$(ls -l "$location_messages_all_tmp");
location_messages_all_tmp_size=$(echo "${location_messages_all_tmp_size_tmp}" | awk '{print $5}');
if [[ $location_messages_all_tmp_size -gt 1 ]]
then
extractLastYearLog "${location_messages_all_tmp}";
fi

if [ -f $location_sysup_all ]
then 
   rm -rf $location_sysup_all;
fi

#join sysup.#
joinSysup;

if [ -f $location_sysup_all ]
then  
   #extract only needed lines from sysup.log
   sed -n -e '/Missing process:/p' "${location_sysup_all}" > "${location_sysup_all_tmp}";
   #we need last row for proper operation when comparing times between massages and sysup.log
   sed '$!d' "${location_sysup_all}" >> "${location_sysup_all_tmp}"; #extracts and appends last row   
   #we need only lines with date included
   sed -n -e '/Jan *[0-9]/p' -e '/Feb *[0-9]/p' -e '/Mar *[0-9]/p' -e '/Apr *[0-9]/p' -e '/May *[0-9]/p' -e '/Jun *[0-9]/p' -e '/Jul *[0-9]/p' -e '/Aug *[0-9]/p' -e '/Sep *[0-9]/p' -e '/Oct *[0-9]/p' -e '/Nov *[0-9]/p' -e '/Dec *[0-9]/p' "${location_sysup_all_tmp}" > "${location_sysup_all}";
   #remove duplicated lines
   awk '!x[$0]++' "${location_sysup_all}" > "${location_sysup_all_tmp}";
   mv "${location_sysup_all_tmp}" "${location_sysup_all}";
   
   location_sysup_size_tmp=$(ls -l "$location_sysup_all");
   location_sysup_size=$(echo "${location_sysup_size_tmp}" | awk '{print $5}');
   if [[ $location_sysup_size -gt 1 ]]
   then
   extractLastYearLog "${location_sysup_all}";
   fi
   
   SysupFileSize_tmp=$(ls -l "$location_sysup_all");
   SysupFileSize=$(echo "${SysupFileSize_tmp}" | awk '{print $5}');
else
   SysupFileSize=0;
fi 

if [ -f $location_secure_tmp ]
then 
   rm -rf $location_secure_tmp;
fi

if [ -f $location_secure ]
then 
   #extract only needed lines from secure
   sed -n -e '/] reboot/p' -e '/] initsim start/p' -e '/] initsim stop/p' "${location_secure}" > "${location_secure_tmp}";
   #we need last row for proper operation when comparing times between massages and secure
   sed '$!d' "${location_secure}" >> "${location_secure_tmp}"; #extracts and appends last row
   #we need only lines with date included
   sed -n -e '/Jan *[0-9]/p' -e '/Feb *[0-9]/p' -e '/Mar *[0-9]/p' -e '/Apr *[0-9]/p' -e '/May *[0-9]/p' -e '/Jun *[0-9]/p' -e '/Jul *[0-9]/p' -e '/Aug *[0-9]/p' -e '/Sep *[0-9]/p' -e '/Oct *[0-9]/p' -e '/Nov *[0-9]/p' -e '/Dec *[0-9]/p' "${location_secure_tmp}" > "${location_secure_tmp_2}";
   #remove duplicated lines
   awk '!x[$0]++' "${location_secure_tmp_2}" > "${location_secure_tmp}";
      
   extractLastYearLog "${location_secure_tmp}";
      
   location_secure_size_tmp=$(ls -l "$location_secure_tmp");
   location_secure_size=$(echo "${location_secure_size_tmp}" | awk '{print $5}');
   if [[ $location_secure_size -gt 1 ]]
   then
      extractLastYearLog "${location_secure_tmp}";
   fi 
fi
      
if [ -f $location_secure_tmp ]
then 
   SecureFileSize_tmp=$(ls -l "$location_secure_tmp");
   SecureFileSize=$(echo "${SecureFileSize_tmp}" | awk '{print $5}');   
else
   SecureFileSize=0;
fi

#search for change of state
i=0;  
while read line    
do  
   if [[ $line == *"Entering ST_HSB_MODE_"* ]]
   then
      value[i]=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3" "$4}')" [n${currentNode}]";
      name[i]="Change of state: ";
      i=$((i+1));
      name[i]="New state: ";
      if [[ $line == *"Entering ST_HSB_MODE_A"* ]]
      then
         value[i]="active"
      else
         value[i]="standby"
      fi
      i=$((i+1));
      value[i]="------------------";
      name[i]="-------------------";
      i=$((i+1));
   fi
done < "${location_messages_all_tmp}"

#print all data from array to file
for (( l = 0 ; l < ${#value[@]} ; l++ ))
do    
   if [[ $currentNode == "1" ]]
   then
      echo "${name[$l]}${value[$l]}" >> ${locationChangeOfState1};
   else  
      echo "${name[$l]}${value[$l]}" >> ${locationChangeOfState2};
   fi
done

i=0;
l=0;
unset name;
unset value;   
#end search for change of state

#search for different hardware 
findNodesResets "${location_messages_all_tmp}";

#seperate messages from different hardware into files
separateMgResets "${location_messages_all_tmp}" messages general;

for (( m = 0 ; m < ${#Domena[@]} ; m++ ))  
do
   readToArray general; 
   
   domena_filename="${tempPath}/messages_out_${Domena[$m]}_general";
   
   if [ -f ${domena_filename} ]
   then 
      rm -rf ${domena_filename};
   fi
   
   #print all data from array to file
   for (( l = 0 ; l < ${#value[@]} ; l++ ))
   do    
      echo "${name[$l]}${value[$l]}" >> ${domena_filename}; 
   done
   unset name;
   unset value;
   
   if [ $m == 0 ]
   then
      if [[ $1 == $targetPath1 ]]
      then
         mv ${domena_filename} ${locationResets1}; 
      else
         mv ${domena_filename} ${locationResets2};
      fi
   else
      if [[ $1 == $targetPath1 ]]
      then
         joinResets ${domena_filename} ${locationResets1} ${locationResets};
         mv ${locationResets} ${locationResets1};
      else
         joinResets ${domena_filename} ${locationResets2} ${locationResets};
         mv ${locationResets} ${locationResets2};
      fi
   fi
done

#CMI specific
location_CMI=${targetPath}"/CMI.log";
if [ -f $location_CMI ]
then
   location_CMI1=${targetPath}"/CMI.log.1";
   location_CMI2=${targetPath}"/CMI.log.2";
   location_CMI3=${targetPath}"/CMI.log.3";
   location_CMI4=${targetPath}"/CMI.log.4";
   
   location_CMI_all=${tempPath}"/CMI_all";
   location_CMI_all_tmp=${tempPath}"/CMI_all_tmp";
   location_messages_user=${tempPath}"/messages_CMI_n"${currentNode};
   
   joinMsgStatOrSimilar ${location_CMI} ${location_CMI1} ${location_CMI2} ${location_CMI3} ${location_CMI4} ${location_CMI_all} ${location_CMI_all_tmp};
   
   #prepare messages file for user (in case user wants to see input messages file)
   cp ${location_CMI_all} ${location_messages_user};

   
   if [ -f $location_messages_all ]
   then
      rm -rf $location_messages_all;
   fi
   
   sed -n -e '/s_devlog@/p' -e '/s_sys@/p' "${location_CMI_all}" > "${location_messages_all}";
   
   #extract only needed lines from messages (faster operation)
   sed -n -e '/ kernel: Oops: /p' -e '/ NIP: /p' -e '/ kernel: DAR: /p' -e '/ kernel: TASK = /p' -e '/ kernel: Call trace:/{N;N;N;N;N;N;N;N;N;N;p;}' -e '/ERR_DTRC_/p' -e '/ usage of physical memory (/p' -e '/ WDT expiried/p' -e '/ Reboot request/{N;p;}' -e '/Reboot caused by setting /p' -e '/ kernel: Linux version /p' -e '/ NOT REGISTERED !!!/p' -e '/ not in required state (ACT)/p' -e '/ MN reboot require /p' -e '/: Switching to runlevel: 0/p' -e '/: Switching to runlevel: 8/p' -e '/ Entering ST_HSB_MODE_/p' "${location_messages_all}" > "${location_messages_all_tmp}";
   #we need only lines with date included
   sed -n -e '/Jan *[0-9]/p' -e '/Feb *[0-9]/p' -e '/Mar *[0-9]/p' -e '/Apr *[0-9]/p' -e '/May *[0-9]/p' -e '/Jun *[0-9]/p' -e '/Jul *[0-9]/p' -e '/Aug *[0-9]/p' -e '/Sep *[0-9]/p' -e '/Oct *[0-9]/p' -e '/Nov *[0-9]/p' -e '/Dec *[0-9]/p' "${location_messages_all_tmp}" > "${location_messages_all}";
   #remove duplicated lines
   awk '!x[$0]++' "${location_messages_all}" > "${location_messages_all_tmp}";
      
   location_messages_all_tmp_size_tmp=$(ls -l "$location_messages_all_tmp");
   location_messages_all_tmp_size=$(echo "${location_messages_all_tmp_size_tmp}" | awk '{print $5}');
   if [[ $location_messages_all_tmp_size -gt 1 ]]
   then
   extractLastYearLog "${location_messages_all_tmp}";
   fi
      
   SysupFileSize_tmp=$SysupFileSize;
   SecureFileSize_tmp=$SecureFileSize;
   SysupFileSize=0;
   SecureFileSize=0;       
   
   #search for change of state
   i=0;  
   while read line    
   do  
      if [[ $line == *"Entering ST_HSB_MODE_"* ]]
      then
         value[i]=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3" "$4}')" [n${currentNode}]";
         name[i]="Change of state: ";
         i=$((i+1));
         name[i]="New state: ";
         if [[ $line == *"Entering ST_HSB_MODE_A"* ]]
         then
            value[i]="active"
         else
            value[i]="standby"
         fi
         i=$((i+1));
         value[i]="------------------";
         name[i]="-------------------";
         i=$((i+1));
      fi
   done < "${location_messages_all_tmp}"

   #print all data from array to file
   for (( l = 0 ; l < ${#value[@]} ; l++ ))
   do    
      if [[ $currentNode == "1" ]]
      then
         echo "${name[$l]}${value[$l]}" >> ${locationChangeOfState1_2};
      else  
         echo "${name[$l]}${value[$l]}" >> ${locationChangeOfState2_2};
      fi
   done

   i=0;
   l=0;
   unset name;
   unset value;      
   #end search for change of state  
   
   #search for different hardware 
   findNodesResets "${location_messages_all_tmp}";

   #seperate messages from different hardware into files
   separateMgResets "${location_messages_all_tmp}" messages CMI;

   for (( m = 0 ; m < ${#Domena[@]} ; m++ ))  
   do
      readToArray CMI;
      
      domena_filename="${tempPath}/messages_out_${Domena[$m]}_CMI";
      
      if [ -f ${domena_filename} ]
      then 
         rm -rf ${domena_filename};
      fi
      
      #print all data from array to file
      for (( l = 0 ; l < ${#value[@]} ; l++ ))
      do    
         echo "${name[$l]}${value[$l]}" >> ${domena_filename}; 
      done
      unset name;
      unset value;
      
      if [ $m == 0 ]
      then
         if [[ $1 == $targetPath1 ]]
         then
            mv ${domena_filename} ${locationResetsCMI1}; 
         else
            mv ${domena_filename} ${locationResetsCMI2};
         fi
      else
         if [[ $1 == $targetPath1 ]]
         then
            joinResets ${domena_filename} ${locationResetsCMI1} ${locationResets};
            mv ${locationResets} ${locationResetsCMI1};
         else
            joinResets ${domena_filename} ${locationResetsCMI2} ${locationResets};
            mv ${locationResets} ${locationResetsCMI2};
         fi
      fi
   done
   
   SysupFileSize=$SysupFileSize_tmp;
   SecureFileSize=$SecureFileSize_tmp;
   
fi
#end CMI specific

#look to secure for initsim start/stop
if [[ $SecureFileSize -gt 1 ]]
then
   i=0;
   while read line   
   do
      if [[ $line == *" initsim start"* ]] || [[ $line == *" initsim stop"* ]]
      then
         TARGET=$(echo "${line}" | awk -F" " '{print $1" "$2" "$3}' | awk -F":" '{print $1":"$2":"$3}');
         value_tmp=$(echo "${line}" | awk -F" " '{print $4}');                                                    
         value[i]="${TARGET} ${value_tmp} [n${currentNode}]";
         name[i]="Reset: ";
         i=$((i+1));
         if [[ $line == *" initsim start"* ]]
         then
            value[i]="initsim start";
         else
            value[i]="initsim stop";
         fi
         name[i]="Reason: ";
         i=$((i+1));
         value[i]="------------------";
         name[i]="-------------------";      
         i=$((i+1));
      fi 
   done < "${location_secure_tmp}"     
   
   #print all data from array to file
   for (( m = 0 ; m < ${#value[@]} ; m++ ))
   do    
      if [[ $1 == $targetPath1 ]]
      then
         echo "${name[$m]}${value[$m]}" >> "${locationResetsSecure1}";
      else
         echo "${name[$m]}${value[$m]}" >> "${locationResetsSecure2}";     
      fi
   done 
   unset name;
   unset value;
fi

}

#analysing log files and extracting informations from them
function logSearchMain() {

#deleting output resets files
locationResets=${tempPath}"/resets";
if [ -f ${locationResets} ]
then 
   rm -rf ${locationResets};
fi
locationResets1=${tempPath}"/resets_node1";
if [ -f ${locationResets1} ]
then 
   rm -rf ${locationResets1};
fi
locationResets2=${tempPath}"/resets_node2";
if [ -f ${locationResets2} ]
then 
   rm -rf ${locationResets2};
fi
locationResetsCMI1=${tempPath}"/CMI_node1";
if [ -f ${locationResetsCMI1} ]
then 
   rm -rf ${locationResetsCMI1};
fi
locationResetsCMI2=${tempPath}"/CMI_node2";
if [ -f ${locationResetsCMI2} ]
then 
   rm -rf ${locationResetsCMI2};
fi
locationResetsSecure1=${tempPath}"/secure_node1";
if [ -f ${locationResetsSecure1} ]
then 
   rm -rf ${locationResetsSecure1};
fi
locationResetsSecure2=${tempPath}"/secure_node2";
if [ -f ${locationResetsSecure2} ]
then 
   rm -rf ${locationResetsSecure2};
fi
locationChangeOfState1=${tempPath}"/state_node1";
if [ -f ${locationChangeOfState1} ]
then 
   rm -rf ${locationChangeOfState1};
fi
locationChangeOfState2=${tempPath}"/state_node2";
if [ -f ${locationChangeOfState2} ]
then 
   rm -rf ${locationChangeOfState2};
fi
locationChangeOfState1_2=${tempPath}"/state_node1_2";
if [ -f ${locationChangeOfState1_2} ]
then 
   rm -rf ${locationChangeOfState1_2};
fi
locationChangeOfState2_2=${tempPath}"/state_node2_2";
if [ -f ${locationChangeOfState2_2} ]
then 
   rm -rf ${locationChangeOfState2_2};
fi
location_messages_user=${tempPath}"/messages_n1";
if [ -f ${location_messages_user} ]
then 
   rm -rf ${location_messages_user};
fi
location_messages_user=${tempPath}"/messages_n2";
if [ -f ${location_messages_user} ]
then 
   rm -rf ${location_messages_user};
fi


#checking existance of current target files
checkExistance;
if [ $flagFileExistance == 1 ]
then
   return;
fi

#extracting tar file 
extractFiles;

#checking existance of new target files
if [ $flagFileExistance == 1 ]
then
   return;  
fi

flagOversize=0;
#checking size of messages files - node 1
checkSize ${targetPath1};
#checking size of messages files - node 2
if [ $nodeNr == 2 ]
then
   checkSize ${targetPath2};
fi
if [ $flagOversize == 1 ]
then
   return;  
fi

echo;
echo "Generating reset info...";
echo;

#check if product is busybox
date_location=$(which date);
if ls -l ${date_location}|grep busybox>/dev/null
then 
   busybox_flag=1;
fi

#find last month (older from both nodes)
location_MsgStat_n1=${targetPath1}"/MsgStat";
location_MsgStat_n1_tmp=${tempPath}"/MsgStat_tmp";

sed '1!G;h;$!d' ${location_MsgStat_n1} > ${location_MsgStat_n1_tmp};

a=1;
while [[ $lastMonth_n1 != "01" ]] && [[ $lastMonth_n1 != "02" ]] && [[ $lastMonth_n1 != "03" ]] && [[ $lastMonth_n1 != "04" ]] && [[ $lastMonth_n1 != "05" ]] && [[ $lastMonth_n1 != "06" ]] && [[ $lastMonth_n1 != "07" ]] && [[ $lastMonth_n1 != "08" ]] && [[ $lastMonth_n1 != "09" ]] && [[ $lastMonth_n1 != "10" ]] && [[ $lastMonth_n1 != "11" ]] && [[ $lastMonth_n1 != "12" ]]
do
   lastMonth_n1=$(sed ${a}'!d' ${location_MsgStat_n1_tmp} | awk -F" " '{print $1}' | awk -F"-" '{print $2}');
   lastYear_n1=$(sed '2!d' ${location_MsgStat_n1_tmp} | awk -F" " '{print $1}' | awk -F"-" '{print $1}');
   a=$((a+1)); 
   if [ $a == 10 ]
   then
      lastMonth_n1=12;
      break;
   fi
done

if [ $nodeNr == 2 ]
then
   location_MsgStat_n2=${targetPath2}"/MsgStat";
   location_MsgStat_n2_tmp=${tempPath}"/MsgStat_tmp";

   sed '1!G;h;$!d' ${location_MsgStat_n2} > ${location_MsgStat_n2_tmp};

   a=1;
   while [[ $lastMonth_n2 != "01" ]] && [[ $lastMonth_n2 != "02" ]] && [[ $lastMonth_n2 != "03" ]] && [[ $lastMonth_n2 != "04" ]] && [[ $lastMonth_n2 != "05" ]] && [[ $lastMonth_n2 != "06" ]] && [[ $lastMonth_n2 != "07" ]] && [[ $lastMonth_n2 != "08" ]] && [[ $lastMonth_n2 != "09" ]] && [[ $lastMonth_n2 != "10" ]] && [[ $lastMonth_n2 != "11" ]] && [[ $lastMonth_n2 != "12" ]]
   do
      lastMonth_n2=$(sed ${a}'!d' ${location_MsgStat_n2_tmp} | awk -F" " '{print $1}' | awk -F"-" '{print $2}');
      lastYear_n2=$(sed '2!d' ${location_MsgStat_n2_tmp} | awk -F" " '{print $1}' | awk -F"-" '{print $1}');
      a=$((a+1)); 
      if [ $a == 10 ]
      then
         lastMonth_n2=12;
         break;
      fi
   done
   
   if  [[ $lastYear_n1 -gt $lastYear_n2 ]]
   then
      lastMonth="${lastMonth_n1}";
   elif  [[ $lastYear_n2 -gt $lastYear_n1 ]]
   then
      lastMonth="${lastMonth_n2}";
   else  
      if  [[ $((10#$lastMonth_n1)) -gt $((10#$lastMonth_n2)) ]]
      then
         lastMonth="${lastMonth_n1}";
      else
         lastMonth="${lastMonth_n2}";
      fi
   fi
else
   lastMonth="${lastMonth_n1}";
fi

if [ -f $location_MsgStat_n1_tmp ]
then 
   rm -rf $location_MsgStat_n1_tmp;
fi

if [ -f $location_MsgStat_n2_tmp ]
then 
   rm -rf $location_MsgStat_n2_tmp;
fi

month0="";
month1="";
month2="";
month3="";
month4="";
month5="";
month6="";
month7="";
month8="";
month9="";
month10="";
month11="";

#create monthArray (for finding resets in the time of last year)
monthArray;

#node 1
currentNode="1";
logSearch ${targetPath1} ${currentNode};
#node 2
if [ $nodeNr == 2 ]
then
   currentNode="2";
   logSearch ${targetPath2} ${currentNode};
fi

targetPath1=$(grep 'Source path 1:' ${confPath}/logAnalyzer.conf | awk -F": " '{print $2}');
targetPath2=$(grep 'Source path 2:' ${confPath}/logAnalyzer.conf | awk -F": " '{print $2}');

if [[ -f ${locationResets1} ]] && [[ -f ${locationResetsCMI1} ]]
then
   joinResets ${locationResets1} ${locationResetsCMI1} ${locationResets};  
   mv ${locationResets} ${locationResets1};  
fi

if [[ -f ${locationResets2} ]] && [[ -f ${locationResetsCMI2} ]]
then
   joinResets ${locationResets2} ${locationResetsCMI2} ${locationResets};
   mv ${locationResets} ${locationResets2};
fi

if [[ -f ${locationResets1} ]] && [[ -f ${locationResetsSecure1} ]]
then
   joinResets ${locationResets1} ${locationResetsSecure1} ${locationResets};
   mv ${locationResets} ${locationResets1};
fi

if [[ -f ${locationResets2} ]] && [[ -f ${locationResetsSecure2} ]]
then
   joinResets ${locationResets2} ${locationResetsSecure2} ${locationResets};
   mv ${locationResets} ${locationResets2};
fi

if [[ -f ${locationResets1} ]] && [[ -f ${locationChangeOfState1} ]]
then
   joinResets ${locationResets1} ${locationChangeOfState1} ${locationResets};
   mv ${locationResets} ${locationResets1};
fi

if [[ -f ${locationResets2} ]] && [[ -f ${locationChangeOfState2} ]]
then
   joinResets ${locationResets2} ${locationChangeOfState2} ${locationResets};
   mv ${locationResets} ${locationResets2};
fi


if [[ -f ${locationResets1} ]] && [[ -f ${locationChangeOfState1_2} ]]
then
   joinResets ${locationResets1} ${locationChangeOfState1_2} ${locationResets};
   mv ${locationResets} ${locationResets1};
fi

if [[ -f ${locationResets2} ]] && [[ -f ${locationChangeOfState2_2} ]]
then
   joinResets ${locationResets2} ${locationChangeOfState2_2} ${locationResets};
   mv ${locationResets} ${locationResets2};
fi

if [[ -f ${locationResets1} ]] && [[ -f ${locationResets2} ]]
then
   joinResets ${locationResets1} ${locationResets2} ${locationResets};
elif [[ -f ${locationResets1} ]]
then
   mv ${locationResets1} ${locationResets};
fi 

#change shape of output file
line_2="";
line_1="";
if [ -f ${locationResets1} ]
then 
   rm -rf ${locationResets1};
fi
if [ -f ${locationResets} ]
then 
while read line    
do    
   if [[ $line == "Reset: "* ]] && [[ $line_1 == *"------------"* ]] && [[ $line_2 == "New state: "* ]]
   then 
      echo "" >> ${locationResets1};
      echo "#####################################" >> ${locationResets1};
      echo "" >> ${locationResets1};
      echo "$line" >> ${locationResets1};
   else
      echo "$line" >> ${locationResets1};
   fi
   line_2="${line_1}";
   line_1="${line}"; 
done < "${locationResets}"
mv ${locationResets1} ${locationResets};
fi

if [[ -f ${locationResets} ]]
then
   #start print last resets on display
   echo "Last reset(s):";  
   echo "-------------------------------------";
   a=0;
   if [ -f ${locationResets2} ]
   then 
      rm -rf ${locationResets2};
   fi
   sed '1!G;h;$!d' "${locationResets}" > "${locationResets1}";
   while read line    
   do       
      echo "$line" >> ${locationResets2};
      if [[ $line == "Reset: "* ]]
      then 
         a=$((a+1));
      fi
      if [[ $a -gt 1 ]]
      then
         break;
      fi
   done < "${locationResets1}"
   sed '1!G;h;$!d' "${locationResets2}" > "${locationResets1}";
   while read line    
   do       
      echo "$line";
   done < "${locationResets1}"   
   #end print last 2 resets on display 
   echo;
   echo "All resets in file:";
   echo "${locationResets}";  
else
   echo;
   echo "No resets found in log files!";  
fi

}

#find specific word in files messages,...
function f_grep() {

targetPath=$1;

#appending current path to the variables
location_grep=${targetPath}"/"${grepName};
location_grep1=${targetPath}"/"${grepName}".1";
location_grep2=${targetPath}"/"${grepName}".2";
location_grep3=${targetPath}"/"${grepName}".3";
location_grep4=${targetPath}"/"${grepName}".4";

location_grep_all=${tempPath}"/"${grepName}"_all";
location_grep_all_tmp=${tempPath}"/"${grepName}"_all_tmp";

location_grep_result=${tempPath}"/"${nodeName}"_grep_"${grepName};

if [ -f ${location_grep} ]
then
   #join name.#
   joinMsgStatOrSimilar ${location_grep} ${location_grep1} ${location_grep2} ${location_grep3} ${location_grep4} ${location_grep_all} ${location_grep_all_tmp};
else  
   echo "Missing files!";
   return;  
fi

if [ -f ${location_grep_result} ]
then 
   rm -rf ${location_grep_result};
fi

sed -n -e '/'"${grepWord}"'/p' "${location_grep_all}" > "${location_grep_result}";

if [ -f ${location_grep_all} ]
then 
   rm -rf ${location_grep_all};
fi

if [ -f ${location_grep_result} ]
then  
   echo "Output file for ${nodeName}:";
   echo "${location_grep_result}";
else
   echo "Error! Output file for ${nodeName} wasn't created!";  
fi

} 

#find specific word in files messages,...
function f_grepMain() {

grepName="unknown";
flagGrep=1;

while  [ $flagGrep != 0 ]
do
   echo;
   grepMenu;
done

flagGrep=1;

#checking existance of current target files
checkExistance;
if [ $flagFileExistance == 1 ]
then
   return;  
fi

#extracting tar file 
extractFiles;

#checking existance of new target files
if [ $flagFileExistance == 1 ]
then
   return;  
fi

#read grep word from user
flagRead=1;
while  [ $flagRead != 0 ]
do
   printf "Enter words to grep:";
   
   read word

   case $word in

   "")
    flagRead=1;   
   ;;
  
   *)
   flagRead=0;
   grepWord=$word;
   ;; 
     
   esac
done
flagRead=1;

flagOversize=0;
if [ $flagCheckSizeForGrep == 1 ]
then
   #checking size of messages files - node 1
   checkSize ${targetPath1};
   #checking size of messages files - node 2
   if [ $nodeNr == 2 ]
   then
      checkSize ${targetPath2};
   fi
   if [ $flagOversize == 1 ]
   then
      return;  
   fi
fi

echo;
echo "Grep in process...";
echo;

#node 1
nodeName="node1";
f_grep ${targetPath1};
#node 2
nodeName="node2";
if [ $nodeNr == 2 ]
then
   f_grep ${targetPath2};
fi

targetPath1=$(grep 'Source path 1:' ${confPath}/logAnalyzer.conf | awk -F": " '{print $2}');
targetPath2=$(grep 'Source path 2:' ${confPath}/logAnalyzer.conf | awk -F": " '{print $2}');

}

#function for parsing all files (messages and MsgStat from n1 and n2) into one file
function parseMain() {

if [ $nodeNr == 1 ]
then
   echo;
   echo "Please choose 2 nodes for this option.";
   return;
fi

#checking existance of current target files
checkExistance;
if [ $flagFileExistance == 1 ]
then
   return;  
fi

#extracting tar file 
extractFiles;

#checking existance of new target files
if [ $flagFileExistance == 1 ]
then
   return;  
fi

flagOversize=0;
#checking size of messages files - node 1
checkSize ${targetPath1};
#checking size of messages files - node 2
if [ $nodeNr == 2 ]
then
   checkSize ${targetPath2};
fi
if [ $flagOversize == 1 ]
then
   return;  
fi

echo;
echo "Parsing files...";
echo;

#appending current path to the variables
location1_messages=${targetPath1}"/messages";
location1_messages1=${targetPath1}"/messages.1";
location1_messages2=${targetPath1}"/messages.2";
location1_messages3=${targetPath1}"/messages.3";
location1_messages4=${targetPath1}"/messages.4";
location1_messages_all=${tempPath}"/messages_all_1";
location1_messages_all_tmp=${tempPath}"/messages_all_tmp_1";

location2_messages=${targetPath2}"/messages";
location2_messages1=${targetPath2}"/messages.1";
location2_messages2=${targetPath2}"/messages.2";
location2_messages3=${targetPath2}"/messages.3";
location2_messages4=${targetPath2}"/messages.4";
location2_messages_all=${tempPath}"/messages_all_2";
location2_messages_all_tmp=${tempPath}"/messages_all_tmp_2";

location1_MsgStat=${targetPath1}"/MsgStat";
location1_MsgStat1=${targetPath1}"/MsgStat.1";
location1_MsgStat2=${targetPath1}"/MsgStat.2";
location1_MsgStat3=${targetPath1}"/MsgStat.3";
location1_MsgStat4=${targetPath1}"/MsgStat.4";
location1_MsgStat_all=${tempPath}"/MsgStat_all_1";
location1_MsgStat_all_tmp=${tempPath}"/MsgStat_all_tmp_1";

location2_MsgStat=${targetPath2}"/MsgStat";
location2_MsgStat1=${targetPath2}"/MsgStat.1";
location2_MsgStat2=${targetPath2}"/MsgStat.2";
location2_MsgStat3=${targetPath2}"/MsgStat.3";
location2_MsgStat4=${targetPath2}"/MsgStat.4";
location2_MsgStat_all=${tempPath}"/MsgStat_all_2";
location2_MsgStat_all_tmp=${tempPath}"/MsgStat_all_tmp_2";

#join messages.# 
joinMsgStatOrSimilar ${location1_messages} ${location1_messages1} ${location1_messages2} ${location1_messages3} ${location1_messages4} ${location1_messages_all} ${location1_messages_all_tmp};
joinMsgStatOrSimilar ${location2_messages} ${location2_messages1} ${location2_messages2} ${location2_messages3} ${location2_messages4} ${location2_messages_all} ${location2_messages_all_tmp};
#we need only lines with date included
sed -n -e '/Jan *[0-9]/p' -e '/Feb *[0-9]/p' -e '/Mar *[0-9]/p' -e '/Apr *[0-9]/p' -e '/May *[0-9]/p' -e '/Jun *[0-9]/p' -e '/Jul *[0-9]/p' -e '/Aug *[0-9]/p' -e '/Sep *[0-9]/p' -e '/Oct *[0-9]/p' -e '/Nov *[0-9]/p' -e '/Dec *[0-9]/p' "${location1_messages_all}" > "${location1_messages_all_tmp}";
sed -n -e '/Jan *[0-9]/p' -e '/Feb *[0-9]/p' -e '/Mar *[0-9]/p' -e '/Apr *[0-9]/p' -e '/May *[0-9]/p' -e '/Jun *[0-9]/p' -e '/Jul *[0-9]/p' -e '/Aug *[0-9]/p' -e '/Sep *[0-9]/p' -e '/Oct *[0-9]/p' -e '/Nov *[0-9]/p' -e '/Dec *[0-9]/p' "${location2_messages_all}" > "${location2_messages_all_tmp}";
#remove duplicated lines
awk '!x[$0]++' "${location1_messages_all_tmp}" > "${location1_messages_all}";
awk '!x[$0]++' "${location2_messages_all_tmp}" > "${location2_messages_all}";

#join MsgStat.#
joinMsgStatOrSimilar ${location1_MsgStat} ${location1_MsgStat1} ${location1_MsgStat2} ${location1_MsgStat3} ${location1_MsgStat4} ${location1_MsgStat_all} ${location1_MsgStat_all_tmp};
joinMsgStatOrSimilar ${location2_MsgStat} ${location2_MsgStat1} ${location2_MsgStat2} ${location2_MsgStat3} ${location2_MsgStat4} ${location2_MsgStat_all} ${location2_MsgStat_all_tmp};
#we need only lines with date included
sed -n -e '/-01-*[0-9]/p' -e '/-02-*[0-9]/p' -e '/-03-*[0-9]/p' -e '/-04-*[0-9]/p' -e '/-05-*[0-9]/p' -e '/-06-*[0-9]/p' -e '/-07-*[0-9]/p' -e '/-08-*[0-9]/p' -e '/-09-*[0-9]/p' -e '/-10-*[0-9]/p' -e '/-11-*[0-9]/p' -e '/-12-*[0-9]/p' "${location1_MsgStat_all}" > "${location1_MsgStat_all_tmp}";
sed -n -e '/-01-*[0-9]/p' -e '/-02-*[0-9]/p' -e '/-03-*[0-9]/p' -e '/-04-*[0-9]/p' -e '/-05-*[0-9]/p' -e '/-06-*[0-9]/p' -e '/-07-*[0-9]/p' -e '/-08-*[0-9]/p' -e '/-09-*[0-9]/p' -e '/-10-*[0-9]/p' -e '/-11-*[0-9]/p' -e '/-12-*[0-9]/p' "${location2_MsgStat_all}" > "${location2_MsgStat_all_tmp}";
#remove duplicated lines
awk '!x[$0]++' "${location1_MsgStat_all_tmp}" > "${location1_MsgStat_all}";
awk '!x[$0]++' "${location2_MsgStat_all_tmp}" > "${location2_MsgStat_all}";

#find last month and year
lastMonth_n1=$(sed '$!d' ${location1_MsgStat} | awk -F" " '{print $1}' | awk -F"-" '{print $2}');
lastYear_n1=$(sed '$!d' ${location1_MsgStat} | awk -F" " '{print $1}' | awk -F"-" '{print $1}');
lastMonth_n2=$(sed '$!d' ${location2_MsgStat} | awk -F" " '{print $1}' | awk -F"-" '{print $2}');
lastYear_n2=$(sed '$!d' ${location2_MsgStat} | awk -F" " '{print $1}' | awk -F"-" '{print $1}');
if  [[ $lastYear_n1 -gt $lastYear_n2 ]]
then
   lastMonth="${lastMonth_n1}";
   lastYear="${lastYear_n1}";
elif  [[ $lastYear_n2 -gt $lastYear_n1 ]]
then
   lastMonth="${lastMonth_n2}";
   lastYear="${lastYear_n2}";
else  
   lastYear="${lastYear_n1}";
   if  [[ $((10#$lastMonth_n1)) -gt $((10#$lastMonth_n2)) ]]
   then
      lastMonth="${lastMonth_n1}";  
   else
      lastMonth="${lastMonth_n2}";
   fi
fi

#define first month and year (11 months older than last month)
if [ $((10#$lastMonth)) -lt 12 ]
then
   firstMonth=$((10#$lastMonth+1));
   firstYear=$((lastYear-1));
   if [ $((10#$firstMonth)) -lt 10 ]
   then
      firstMonth="0${firstMonth}";
   fi
else
   firstMonth=01;
   firstYear="${lastYear}";
fi

#make sure MsgStat files are younger than 1 year (messages files should be younger than 1 year already by default)

#add date orientation lines - for proper operation in case that there is no log line for start or end date
printf "\n" >> "${location1_MsgStat_all}";
printf "\n" >> "${location2_MsgStat_all}";
printf "${firstYear}-${firstMonth}-01 00:00:00 orientation_line_added_for_proper_date_operation" >> "${location1_MsgStat_all}";
printf "${firstYear}-${firstMonth}-01 00:00:00 orientation_line_added_for_proper_date_operation" >> "${location2_MsgStat_all}";
printf "\n" >> "${location1_MsgStat_all}";
printf "\n" >> "${location2_MsgStat_all}";
printf "${lastYear}-${lastMonth}-31 23:59:59 orientation_line_added_for_proper_date_operation" >> "${location1_MsgStat_all}";
printf "${lastYear}-${lastMonth}-31 23:59:59 orientation_line_added_for_proper_date_operation" >> "${location2_MsgStat_all}";
printf "\n" >> "${location1_MsgStat_all}";
printf "\n" >> "${location2_MsgStat_all}";
printf "${firstYear}-12-31 23:59:59 orientation_line_added_for_proper_date_operation" >> "${location1_MsgStat_all}";
printf "${firstYear}-12-31 23:59:59 orientation_line_added_for_proper_date_operation" >> "${location2_MsgStat_all}";
printf "\n" >> "${location1_MsgStat_all}";
printf "\n" >> "${location2_MsgStat_all}";
printf "${lastYear}-01-01 00:00:00 orientation_line_added_for_proper_date_operation" >> "${location1_MsgStat_all}";
printf "${lastYear}-01-01 00:00:00 orientation_line_added_for_proper_date_operation" >> "${location2_MsgStat_all}";

#sort parse file
sort --k=1,1 --stable "${location1_MsgStat_all}" > "${location1_MsgStat_all_tmp}"
sort --k=1,1 --stable "${location2_MsgStat_all}" > "${location2_MsgStat_all_tmp}"

#extract info between startDate and endDate (MsgStat)
if [[ $((10#$lastMonth)) -lt $((10#$firstMonth)) ]]
then
   sed -n '/'${firstYear}'-'${firstMonth}'-01/,/'${firstYear}'-12-31/p' "${location1_MsgStat_all_tmp}" > "${location1_MsgStat_all}";
   sed -n '/'${lastYear}'-01-01/,/'${lastYear}'-'${lastMonth}'-31/p' "${location1_MsgStat_all_tmp}" >> "${location1_MsgStat_all}";
   sed -n '/'${firstYear}'-'${firstMonth}'-01/,/'${firstYear}'-12-31/p' "${location2_MsgStat_all_tmp}" > "${location2_MsgStat_all}";
   sed -n '/'${lastYear}'-01-01/,/'${lastYear}'-'${lastMonth}'-31/p' "${location2_MsgStat_all_tmp}" >> "${location2_MsgStat_all}";
else
   sed -n '/'${firstYear}'-'${firstMonth}'-01/,/'${lastYear}'-'${lastMonth}'-31/p' "${location1_MsgStat_all_tmp}" > "${location1_MsgStat_all}";
   sed -n '/'${firstYear}'-'${firstMonth}'-01/,/'${lastYear}'-'${lastMonth}'-31/p' "${location2_MsgStat_all_tmp}" > "${location2_MsgStat_all}";
fi

#parse messages and MsgStat files from n1 and n2

location_parse=${tempPath}"/parse";
location_parse_tmp=${tempPath}"/parse_tmp";

if [ -f ${location_parse} ]
then 
   rm -rf ${location_parse};
fi

if [ -f ${location_parse_tmp} ]
then
   rm -rf ${location_parse_tmp};
fi

#messages
sed -e 's/Jan  /01\_0/' -e 's/Jan /01\_/' -e 's/Feb  /02\_0/' -e 's/Feb /02\_/' -e 's/Mar  /03\_0/' -e 's/Mar /03\_/' -e 's/Apr  /04\_0/' -e 's/Apr /04\_/' -e 's/May  /05\_0/' -e 's/May /05\_/' -e 's/Jun  /06\_0/' -e 's/Jun /06\_/' -e 's/Jul  /07\_0/' -e 's/Jul /07\_/' -e 's/Aug  /08\_0/' -e 's/Aug /08\_/' -e 's/Sep  /09\_0/' -e 's/Sep /09\_/' -e 's/Oct  /10\_0/' -e 's/Oct /10\_/' -e 's/Nov  /11\_0/' -e 's/Nov /11\_/' -e 's/Dec  /12\_0/' -e 's/Dec /12\_/' -e 's/ /\_/' -e 's/ / n1    messages         /' "${location1_messages_all}" >> "${location_parse_tmp}";
sed -e 's/Jan  /01\_0/' -e 's/Jan /01\_/' -e 's/Feb  /02\_0/' -e 's/Feb /02\_/' -e 's/Mar  /03\_0/' -e 's/Mar /03\_/' -e 's/Apr  /04\_0/' -e 's/Apr /04\_/' -e 's/May  /05\_0/' -e 's/May /05\_/' -e 's/Jun  /06\_0/' -e 's/Jun /06\_/' -e 's/Jul  /07\_0/' -e 's/Jul /07\_/' -e 's/Aug  /08\_0/' -e 's/Aug /08\_/' -e 's/Sep  /09\_0/' -e 's/Sep /09\_/' -e 's/Oct  /10\_0/' -e 's/Oct /10\_/' -e 's/Nov  /11\_0/' -e 's/Nov /11\_/' -e 's/Dec  /12\_0/' -e 's/Dec /12\_/' -e 's/ /\_/' -e 's/ /    n2 messages         /' "${location2_messages_all}" >> "${location_parse_tmp}";

#MsgStat
sed -e 's/20[0-9][0-9]-01-/01\_/' -e 's/20[0-9][0-9]-02-/02\_/' -e 's/20[0-9][0-9]-03-/03\_/' -e 's/20[0-9][0-9]-04-/04\_/' -e 's/20[0-9][0-9]-05-/05\_/' -e 's/20[0-9][0-9]-06-/06\_/' -e 's/20[0-9][0-9]-07-/07\_/' -e 's/20[0-9][0-9]-08-/08\_/' -e 's/20[0-9][0-9]-09-/09\_/' -e 's/20[0-9][0-9]-10-/10\_/' -e 's/20[0-9][0-9]-11-/11\_/' -e 's/20[0-9][0-9]-12-/12\_/' -e 's/ /\_/' -e 's/ / n1             MsgStat /' "${location1_MsgStat_all}" >> "${location_parse_tmp}";
sed -e 's/20[0-9][0-9]-01-/01\_/' -e 's/20[0-9][0-9]-02-/02\_/' -e 's/20[0-9][0-9]-03-/03\_/' -e 's/20[0-9][0-9]-04-/04\_/' -e 's/20[0-9][0-9]-05-/05\_/' -e 's/20[0-9][0-9]-06-/06\_/' -e 's/20[0-9][0-9]-07-/07\_/' -e 's/20[0-9][0-9]-08-/08\_/' -e 's/20[0-9][0-9]-09-/09\_/' -e 's/20[0-9][0-9]-10-/10\_/' -e 's/20[0-9][0-9]-11-/11\_/' -e 's/20[0-9][0-9]-12-/12\_/' -e 's/ /\_/' -e 's/ /    n2          MsgStat /' "${location2_MsgStat_all}" >> "${location_parse_tmp}";

#sort parse file
sort --k=1,1 --stable "${location_parse_tmp}" > "${location_parse}"

#extract info between startDate and endDate
if [[ $((10#$lastMonth)) -lt $((10#$firstMonth)) ]]
then
   sed -n '/'${firstMonth}'_01_/,/12_31_/p' "${location_parse}" > "${location_parse_tmp}";
   sed -n '/01_01_/,/'${lastMonth}'_31_/p' "${location_parse}" >> "${location_parse_tmp}";
else
   sed -n '/'${firstMonth}'_01_/,/'${lastMonth}'_31_/p' "${location_parse}" > "${location_parse_tmp}";
fi

#remove date orientation lines
sed '/orientation_line_added_for_proper_date_operation/d' "${location_parse_tmp}" > "${location_parse}";
#remove duplicated lines
awk '!x[$0]++' "${location_parse}" > "${location_parse_tmp}";
mv "${location_parse_tmp}" "${location_parse}";

targetPath1=$(grep 'Source path 1:' ${confPath}/logAnalyzer.conf | awk -F": " '{print $2}');
targetPath2=$(grep 'Source path 2:' ${confPath}/logAnalyzer.conf | awk -F": " '{print $2}');

if [[ -f ${location_parse} ]]
then
   echo "Results in file:";
   echo "${location_parse}";
else
   echo "Error! Output file wasn't created!";
fi

}

#PROGRAM START POINT

if [ "$1" = "help" ] || [ "$1" = "Help" ] || [ "$1" = "-help" ] || [ "$1" = "-Help" ] || [ "$1" = "--help" ] || [ "$1" = "--Help" ]
then
   f_help;
   exit;
fi

#temporary location
tempPath="/tmp/logAnalyzer";

if [ -d "${tempPath}" ]
then 
   rm -rf "${tempPath}";
fi

mkdir "${tempPath}";

#.conf file location
confPath="/opt/iskratel/etc";

#global variables
messagesHwWithoutBe="unknown";

#reading information about default source file from .conf file
if [[ -f ${confPath}/logAnalyzer.conf ]]
then
   targetPath1=$(grep 'Source path 1:' ${confPath}/logAnalyzer.conf | awk -F": " '{print $2}');
   targetPath2=$(grep 'Source path 2:' ${confPath}/logAnalyzer.conf | awk -F": " '{print $2}');
   productType=$(grep 'Product:' ${confPath}/logAnalyzer.conf | awk -F": " '{print $2}');
   nodeNr=$(grep 'nodeNr:' ${confPath}/logAnalyzer.conf | awk -F": " '{print $2}');
else 
   echo;
   echo "Error: logAnalyzer.conf file is missing!";
   echo;
   exit;
fi

flagChangeSource=1; #closes the flag for the change source file function
flagChangeNodes=1; #closes the flag for the nodes number change
flagProductType=1; #closes the flag for the product type menu function
flagMainMenu=0; #opens the flag for the main menu function
flagFileExistance=1; #file existance flag (closed before checking)
busybox_flag=0; #flag for busybox product identification
flagOversize=0; #flag for messages file size check
flagCheckSizeForGrep=0; #flag for messages file size check
date_busybox="";

#displays program title
echo;
echo "##LOG ANALYZER version 2.0.6##";
echo;

#PROGRAM MAIN LOOP
while true
do    

   if [ $flagProductType == 0 ]
   then
      productTypeMenu;
      echo;
   fi

   if [ $flagChangeNodes == 0 ]
   then
      changeNodes;
      echo;
   fi 
   
   if [ $flagChangeSource == 0 ]
   then
      changeSource;
      echo;
   fi 
   
   if [ $flagProductType == 1 ] && [ $flagChangeNodes == 1 ] && [ $flagChangeSource == 1 ] && [ $flagMainMenu == 0 ] 
   then
      mainMenu;
      echo;
   fi 
   
done