#!/bin/sh
###########################################################################
#                                                                         #
#                                                                         #
#              Copyright (c) 2008 IskraTEL                                #
#                                                                         #
#                                                                         #
#                                                                         #
#   Name        : pppAlarm.sh                                             #
#                                                                         #
#   Description : Utility for catching alarms in syslog-ng report file    #
#                                                                         #
#                                                                         #
#                                                                         #
#   Position    : IT_UTILS, /opt/iskratel/sbin/                           #
#                                                                         #
#   Code        : QMSA                                                    #
#                                                                         #
#   Date        : oct 2008                                                #
#                                                                         #
#   Author      : Jure Buble, Metalab                                     #
#                                                                         #
#   Translation : * None                                                  #
#                                                                         #
#   Remarks     : No Input arguments                                      #
#                                                                         #
#   Revisions   :                                                         #
###########################################################################

#################################################
#                                               #
#System parameterts, path to comands and files  #
#                                               #
#################################################
SED=/bin/sed
AWK=/bin/awk
GREP=/bin/grep
CAT=/bin/cat
ECHO=/bin/echo
PROC=/bin/ps
KILL=/bin/kill
XARGS=/usr/bin/xargs
RM=/bin/rm
TOUCH=/bin/touch
WC=/usr/bin/wc
SYSERPROG=/opt/iskratel/sbin/extModRepSend
SOLID_USER=`$CAT /opt/solid/solid??srv/solidnet.cfg | $GREP " SOLID_DB_USERNAME" | $AWK -F "=" '{print $2}' | $SED 1q`
SOLID_PASS=`$CAT /opt/solid/solid??srv/solidnet.cfg | $GREP " SOLID_DB_PASSWORD" | $AWK -F "=" '{print $2}' | $SED 1q`
SOLID_PORT=`$CAT /opt/solid/solid??srv/solidnet.cfg | $GREP " SOLID_CONNECTION_STRING" | $AWK -F "=" '{print $2}' | $SED 1q | $SED 's/"//g' | $AWK '{print $2}'`
SOLID_UPIPE_TYP=`$CAT /opt/solid/solid??srv/solidnet.cfg | $GREP " UPIPE_SOLID_CONNECTION_STRING" | $AWK -F "=" '{print $2}' | $SED 1q | $SED 's/"//g' | $AWK '{print $1}'`
SOLID_UPIPE_SRV=`$CAT /opt/solid/solid??srv/solidnet.cfg | $GREP " UPIPE_SOLID_CONNECTION_STRING" | $AWK -F "=" '{print $2}' | $SED 1q | $SED 's/"//g' | $AWK '{print $2}'`
SOLSQL=/opt/solid/bin/solsql
CATALOG=`$CAT /opt/si2000/neroot/active/db/*/bin/catalog.cfg | $GREP SOLID_DB_CATALOG | $AWK -F "=" '{print $2}'`
SNPS=/opt/si2000/neroot/active/bin/snps.sh
ISSH=/opt/si2000/neroot/active/bin/is.sh
REBOOT_CMD=/sbin/reboot
COUNTFILE=/etc/sysconfig/reboot_counter #counts the number of reboots
HEAD=/usr/bin/head
TAIL=/usr/bin/tail
ETCHOSTS="/etc/hosts"
GRP_FILE=/etc/group
USR_FILE=/etc/passwd
MSGFILE=/var/log/messages
VARFILE=/var/run/PPPalarms.skript
VARFILE_1=/var/run/PPPalarms.skript_1
LOGGER="/usr/bin/logger -p user.alert -t pppAlarm.sh --"

#################################################
# Variables                                     #
#################################################
RESET=0
MN_SET=0
VOIP_SET=0
INT_SET=0
ETHGBTYPE=13 #Port type for GB ether port in database
ETHPRTNMBR=35 #Port number for network port on master node
NMBR_MNIPS=2 #number of MN ips in HSB mode of CS product, not counting the MN_FLOAT IP address (e.g. MN1_IP and MN2_IP)
CURLINE=""


##################################################
#	Functions				 #
##################################################

write_varfile ()
{
        if [ -s /var/run/PPPalarms.skript_1 ]
                then
                mv /var/run/PPPalarms.skript_1 /var/run/PPPalarms.skript
                else
                $ECHO "Unable to write $VARFILE !"  | $LOGGER
        fi
}

report_error ()
{
$ECHO "$TEKST" | $LOGGER
}


check_update_pidfile_parameters () {
  GETDVICEPID=`$ECHO $CURLINE | $AWK '{print $5}' | $AWK -F "[" '{print $2}' | $AWK -F "]" '{print $1}'`

  DVICENMBR=`$CAT $MSGFILE | $GREP "pppd\[$GETDVICEPID\].* Connect:" | $TAIL -n 1 | $AWK -F "Connect" '{print $2}' | $AWK '{print $4}'`
  if [ -z "$DVICENMBR" ]
  then 
    DVICENMBR=`$CAT $MSGFILE | $GREP "pppd\[$GETDVICEPID\].* unrecognized" | $TAIL -n 1 | $AWK -F "unrecognized" '{print $2}' | $AWK -F "'" '{print $2}' | $AWK -F "'" '{print $1}'`
  fi

  FINDPPP=`$GREP "PPP$PPPID" $VARFILE`
  if [ -n "$FINDPPP" ]
  then
    $SED "s/PPP$PPPID=.*/PPP$PPPID=$GETDVICEPID/g" $VARFILE > $VARFILE_1
    write_varfile
  else
    $ECHO "PPP$PPPID=$GETDVICEPID" >> $VARFILE
  fi
}


get_pppid ()
{
  GETDVICEPID=`$ECHO $CURLINE | $AWK '{print $5}' | $AWK -F "[" '{print $2}' | $AWK -F "]" '{print $1}'`
  DVICENMBR=`$CAT $MSGFILE | $GREP "pppd\[$GETDVICEPID\].* Connect:" | $TAIL -n 1 | $AWK -F "Connect" '{print $2}' | $AWK '{print $4}'`
  if [ -z "$DVICENMBR" ]
  then 
    DVICENMBR=`$CAT $MSGFILE | $GREP "pppd\[$GETDVICEPID\].* unrecognized" | $TAIL -n 1 | $AWK -F "unrecognized" '{print $2}' | $AWK -F "'" '{print $2}' | $AWK -F "'" '{print $1}'`
  fi
  if [ -z "$DVICENMBR" ]
  then 
    DVICENMBR=`$CAT $MSGFILE | $GREP "pppd\[$GETDVICEPID\].* locked" | $TAIL -n 1 | $AWK -F "Device" '{print $2}' | $AWK '{print $1}'`
    if [ ! -z "$DVICENMBR" ]
    then
      DVICENMBR="/dev/""$DVICENMBR"
    fi  
  fi
  if [ -z "$DVICENMBR" ]
  then 
    DVICENMBR=`$CAT $MSGFILE | $GREP "pppd\[$GETDVICEPID\].* stale" | $TAIL -n 1 | $AWK -F "Removed stale lock on" '{print $2}' | $AWK '{print $1}'`
    if [ ! -z "$DVICENMBR" ]
    then
      DVICENMBR="/dev/""$DVICENMBR"
    fi
  fi

  PPPID=`$ECHO $DVICENMBR	| $AWK -F "ttyPPP" '{print $2}'`
  if [ -z "$DVICENMBR" ]
  then
    # if messages log rotate
    PPPID=`$GREP $GETDVICEPID $VARFILE | $AWK -F "=" '{print $1}' | $AWK -F "PPP" '{print $2}'` 
  fi
}

#############################################
# 	Main			            #	
#############################################

while read CURLINE; do

	RIZN=`echo $@ | awk '{print $1}'`

  if [ "$RIZN" != "DELETEDFROMDB" ]
  then  
  get_pppid 
  fi
  
TEKST="pppAlarm RIZN=$RIZN !"
report_error
  
  case $RIZN in 

  NODEV)
    # ttyPPP driver not available
    $SYSERPROG announce 1700200 1.1/79.4/91.$PPPID/end/
  ;;

  TERM)
    $SYSERPROG announce 1700190 1.1/79.4/91.$PPPID/end/
  ;;

  LCPTERM)
    # set ppp inactive or lcp expires after 32767 retries
    $SYSERPROG announce 1700360 1.1/79.4/91.$PPPID/end/
  ;;

  RMTIP)
    $SYSERPROG announce 1700370 1.1/79.4/91.$PPPID/end/
  ;;
  
  LOCIP)
    $SYSERPROG announce 1700380 1.1/79.4/91.$PPPID/end/
  ;;

  SGFLT)
    $SYSERPROG announce 1700390 1.1/79.4/91.$PPPID/end/
  ;;
	
  NOCARR)
    # no response to echo req
    $SYSERPROG announce 1700190 1.1/79.4/91.$PPPID/end/
  ;;

  START)
    # write ppp process id to varfile; needed for PPPID, if messages log rotate
    check_update_pidfile_parameters
    $SYSERPROG announce 1700190 1.1/79.4/91.$PPPID/end/
  ;;	

  STARTCHECK)
    $SYSERPROG retreate 1700390 1.1/79.4/91.$PPPID/end/
    $SYSERPROG retreate 1700380 1.1/79.4/91.$PPPID/end/
    $SYSERPROG retreate 1700370 1.1/79.4/91.$PPPID/end/
    $SYSERPROG retreate 1700360 1.1/79.4/91.$PPPID/end/
    $SYSERPROG retreate 1700200 1.1/79.4/91.$PPPID/end/
    $SYSERPROG retreate 1700190 1.1/79.4/91.$PPPID/end/
  ;;
		
  DELETEDFROMDB)
    PPPID=`$ECHO $CURLINE | $AWK '{print $6}' | $AWK -F "PPP" '{print $2}'`	
    $SYSERPROG retreate 1700390 1.1/79.4/91.$PPPID/end/
    $SYSERPROG retreate 1700380 1.1/79.4/91.$PPPID/end/
    $SYSERPROG retreate 1700370 1.1/79.4/91.$PPPID/end/
    $SYSERPROG retreate 1700360 1.1/79.4/91.$PPPID/end/
    $SYSERPROG retreate 1700200 1.1/79.4/91.$PPPID/end/
    $SYSERPROG retreate 1700190 1.1/79.4/91.$PPPID/end/
  ;;

  esac	
done
