#!/bin/bash
#
# NAME
#   ram_usage_2b.sh - physical/virtual process memory snapshot on Linux
#
# SYNOPSIS
#   ram_usage_2b.sh [-d] [PID]
#
# OPTIONS
#
# AUTHOR
#   Robert Kodric, ITRD S4, Iskratel, Ltd., Kranj
#
# HISTORY
#   00,06Dec2008   Initial verion 1a
#   01,16Dec2008   Version 1b
#   02,08Jul2009   Version 1c, released in IT_UTILS
#   03,04Aug2009   Version 1d, on MVL50 CGE there are RO file sharings (r--s-), too.
#   04,27Sep2009   Version 1e, output from 'pmap -d <pid>' varies through Linuix versions.
#                              parsing of /proc/<pid>/maps is introduced instead. 
#   05,27oct2009   Version 2a, output from 'pmap -d <pid>' varies through Linuix versions.
#                              parsing of /proc/<pid>/smaps form 2.6.14 is introduced instead. 
#   06,18mar2009   Version 2b, so far, script was primary written for:
#                              - MontaVista CGE/PRO 4.x (2.6.10, which has SMAPS backported form 2.6.14)
#                              - MontaVista CGE 5.x (2.6.21)
#                              - MontaVista PRO 5.x (2.6.18)
#                              added support for RedHat Enterprise Linux Enterprise Server 4.6 (2.6.9, backported SMAPS)
#   07,23Mar2010   Version 2c, released in IT_CONFIG_LINUX
#   08,04Jul2012   Version 2d, added support for Wind River Linux release 4.1
#   09,11Apr2014   Version 2e, added support for Wind River Linux release 5.0.1, revisted 11Jun2015
#
# DESCRIPTION
#   This script is written for Linux processes memory resources snapshot.
#   If script is called without options, physical and virtual
#   memory of each process is displayed. Invoking with option -d 
#   displays more details about each processes memory. If process ID
#   option is provided, detailed memory consumption of that
#   process is displayed.
#
# WARNING
#
#
# OBSOLATE
#   PIDS=` ls /proc/*/stat | sed -e 's/\/stat//' -e 's/\/proc\///' | sort -n` ;
#
#   			printf "|  PRIVATE| PRIVATE| SHARED | SHARED |        | \n"
#
# ERROR
#   does not work !
#   while ["$ARRAY_INDEX" -lt 100 ]; do
#     RSS_SHARED_CLEAN +=  $SMAPS[$ARRAY_INDEX];
#     RSS_SHARED_DIRTY +=  $SMAPS[$(($ARRAY_INDEX+1))];
#     RSS_PRIVATE_CLEAN += $SMAPS[$(($ARRAY_INDEX+2))];
#     RSS_PRIVATE_DIRTY += $SMAPS[$(($ARRAY_INDEX+3))];
#     VM += $SMAPS[$(($ARRAY_INDEX+4))];
#     ARRAY_INDEX=$(($ARRAY_INDEX+5));
#   done
#


# get command name
SELF=`basename $0`

# option -d 
DETAILED=0

# usage of command
USAGE=\
"Usage:\t`basename $SELF` [-h]\t\thelp\n \
\t`basename $SELF` [-d]\t\tdetailed memory view\n \
\t`basename $SELF` [PID]\t\tdetailed memory view of process with PID\n"

# get some targets info
MACHINE_NAME=`uname -m`
KERNEL_RELEASE=`uname -r`

# parse ONLY the first line from /cat/issue to array LINUX_DISTRO[]
LINUX_DISTRO=(` awk 'FNR==1 {printf ("%s %s %s %s %s %s %s\n", $1, $2, $3, $4, $5, $6, $7)}' /etc/issue `)

# decide upon distro and act
# MontaVista ?
if [ ${LINUX_DISTRO[0]} == 'MontaVista(R)' ]; then
	# MontaVista CGE
	if [ ${LINUX_DISTRO[2]} == Carrier ]; then
		LINUX_VERSION=( ` awk '																\
														{															\
															split ( $6, VERSION, "." );	\
															print VERSION[1];						\
														}															\
													' /etc/issue										\
										` )
	# MontaVista PRO
	else
		LINUX_VERSION=( ` awk '																\
														{															\
															split ( $5, VERSION, "." );	\
															print VERSION[1];						\
														}															\
													' /etc/issue										\
										` )
	fi
# RedHat Enterprise Linux ?
elif [ ${LINUX_DISTRO[0]} == Red ]; then
	LINUX_VERSION=( ` awk '																\
													{															\
														split ( $7, VERSION, "." );	\
														print VERSION[1];						\
													}															\
												' /etc/issue										\
									` )
fi

# read options and parse them
while getopts dh OPTIONS
do
	case "$OPTIONS" in
		d)
			DETAILED=1 ;;
		h)
			printf "$USAGE" ;
			exit 1 ;;
		\?)
			printf "$USAGE" ;
			exit 1 ;;
	esac
done

# get rid of options, we have already parsed them
shift $(( OPTIND - 1 ))

# check for presence of PID parameter
if [ -z $1 ]; then
	#PIDS=` ps -eo pid= | sort -n`
	PIDS=` top -b -n 1 | awk '{print $1}' | sort -g`
else
	PIDS=$1
fi

# check for presence of SMAPS,otherwise use MAPS
if [ -e /proc/self/smaps ]; then
	MAPS_SMAPS=smaps
	NON_EXISTENT_CHAR=0
else	
	MAPS_SMAPS=maps
	NON_EXISTENT_CHAR=x
fi

# print appropriate header
printf "\n"
printf "Kernel release:     %-s \n" $KERNEL_RELEASE
printf "Linux distribution: %-s \n" "`awk 'FNR==1 {print $0;}' /etc/issue`"
printf "Parsing file:       /proc/PID/%-s \n" $MAPS_SMAPS
if !( [ -e /proc/self/smaps ] ) ; then
	printf "Warning:            Clean and Dirty detailed memory usage can not be calculated! \n"
fi

# check for presence of PID parameter and options
if [ -z $1 ]; then
	if [ $DETAILED -eq 0 ]; then
		printf "\n"
		printf " ------------------------------------------------------------------------------------------ \n"
		printf "  PID   |    PHYSICAL MEMORY       |    VIRTUAL MEMORY        |  PROCESS NAME               \n"
		printf "        |--------------------------|--------------------------|                             \n"
		printf "        | TOTAL  |PRIVATE |SHARED  | TOTAL  |MAPPED  | ANON   |                             \n"
		printf " -------|--------|--------|--------|--------|--------|--------|---------------------------- \n"
	fi
	if [ $DETAILED -eq 1 ]; then
		printf "\n"
		printf " ------------------------------------------------------------------------------------------ \n"
		printf "  PID   |       PHYSICAL MEMORY             |VIRTUAL MEMORY   |  PROCESS NAME               \n"
		printf "        |-----------------|-----------------------------------|                             \n"
		printf "        |PRIVATE |PRIVATE |SHARED  |SHARED  |MAPPED  | ANON   |                             \n"
		printf "        |CLEAN   |DIRTY   |CLEAN   |DIRTY   |        |        |                             \n"
		printf " -------|--------|--------|--------|--------|--------|--------|---------------------------- \n"
	fi
fi

# MAIN LOOP
# parse and display process memory details
for PID in $PIDS; do

	# check if PID statistics exists in /proc
	if ( [ -e /proc/$PID/maps ] && [ $PID != self ] ) ; then

		# AWK solution #0
		# parsing /proc/<PID>/statm file for physical memory stats
		RSS_TOTAL=(` awk '{print $2}' /proc/$PID/statm `)
		RSS_TOTAL=$(( $RSS_TOTAL * 4 ))
		RSS_SHARED=(` awk '{print $3}' /proc/$PID/statm `)
		RSS_SHARED=$(( $RSS_SHARED * 4 ))
		RSS_PRIVATE=$(( $RSS_TOTAL - $RSS_SHARED ))
		STATM=( $RSS_TOTAL $RSS_PRIVATE $RSS_SHARED)

		# AWK solution #1
		# parsing /proc/<PID>/status file
		STATUS=( ` awk '																	\
										BEGIN { 													\
														VM_TOTAL=0;								\
														VM_TEXT_EXE=0;						\
														VM_TEXT_LIB=0;						\
														NR_THREADS=0xFFFF;				\
													}														\
										$1 ~ /VmExe/											\
											{ VM_TEXT_EXE = $2;}						\
										$1 ~ /VmSize/											\
											{ VM_TOTAL = $2;}								\
										$1 ~ /VmLib/											\
											{ VM_TEXT_LIB = $2;}						\
										$1 ~ /Threads/										\
											{ NR_THREADS = $2;}							\
										$1~ /Name/												\
											{ PNAME = $2;}									\
																											\
										END {															\
													print	PNAME ,								\
																NR_THREADS ,					\
																VM_TEXT_EXE ,					\
																VM_TEXT_LIB ,					\
																VM_TOTAL ;						\
												}															\
										' /proc/$PID/status								\
							` )

		# AWK solution #3
		# parsing /proc/<PID>/smaps or /proc/<PID>/maps
		# file for each and every currently mapped memory region
		# ---p_map  INDEX=1	
		# ---s_map  INDEX=2	
		# r--p_map  INDEX=3	
		# r--s_map  INDEX=4	
		# r-xp_map  INDEX=5	
		# r-xs_map  INDEX=6	
		# rw-p_map  INDEX=7	
		# rw-s_map  INDEX=8	
		# rwxp_map  INDEX=9	
		# rwxs_map  INDEX=10
		# ---p_anon INDEX=11
		# ---s_anon INDEX=12
		# r--p_anon INDEX=13
		# r--s_anon INDEX=14
		# r-xp_anon INDEX=15
		# r-xs_anon INDEX=16
		# rw-p_anon INDEX=17
		# rw-s_anon INDEX=18
		# rwxp_anon INDEX=19
		# rwxs_anon INDEX=20
		SMAPS=( ` awk '																																																							\
									BEGIN {																																																				\
													for (i=1; i<=20; i++)																																									\
													{																																																			\
														RSS_SHARED_CLEAN[i]=0;																																							\
														RSS_SHARED_DIRTY[i]=0;																																							\
														RSS_PRIVATE_CLEAN[i]=0;																																							\
														RSS_PRIVATE_DIRTY[i]=0;																																							\
														VM[i]=0;																																														\
													}																																																			\
													INDEX=1;																																															\
													RSS_SHARED_CLEAN_SUM=0;																																								\
													RSS_SHARED_DIRTY_SUM=0;																																								\
													RSS_PRIVATE_CLEAN_SUM=0;																																							\
													RSS_PRIVATE_DIRTY_SUM=0;																																							\
													VM_SUM=0;																																															\
												}																																																				\
																																																																\
									$2 ~ /(-|r)(-|w)(-|x)(p|s)/																																										\
										{																																																						\
											split ( $1, VM_AREA, "-" );																																								\
											VM_AREA_START = strtonum ( sprintf ( "0x%s", VM_AREA[1] ) );																							\
											VM_AREA_STOP =  strtonum ( sprintf ( "0x%s", VM_AREA[2] ) );																							\
											VM_SIZE = ( VM_AREA_STOP - VM_AREA_START ) / 1024;																												\
											INDEX=1;																																																	\
										}																																																						\
									$2 ~ /...s/  { INDEX+=1; }																																										\
									$2 ~ /r.../  { INDEX+=2; }																																										\
									$2 ~ /..x./  { INDEX+=2; }																																										\
									$2 ~ /.w../  { INDEX+=4; }																																										\
									$4 ~ /00:00/ { INDEX+=10; }																																										\
																																																																\
									$2 ~ /(-|r)(-|w)(-|x)(p|s)/  { VM[INDEX]+=VM_SIZE; VM_SUM+=VM_SIZE;}																					\
									$1 ~ /Shared_Clean:/  { RSS_SHARED_CLEAN[INDEX]+=$2; RSS_SHARED_CLEAN_SUM+=$2; next;}													\
									$1 ~ /Shared_Dirty:/  { RSS_SHARED_DIRTY[INDEX]+=$2; RSS_SHARED_DIRTY_SUM+=$2; next;}													\
									$1 ~ /Private_Clean:/ { RSS_PRIVATE_CLEAN[INDEX]+=$2; RSS_PRIVATE_CLEAN_SUM+=$2; next;}												\
									$1 ~ /Private_Dirty:/ { RSS_PRIVATE_DIRTY[INDEX]+=$2; RSS_PRIVATE_DIRTY_SUM+=$2; next;}												\
																																																																\
									END {																																																					\
												for (i=1; i<=10; i++)																																										\
													{																																																			\
														VM_MAPPED+=VM[i];																																										\
													}																																																			\
												for (j=11; j<=20; j++)																																									\
													{																																																			\
														VM_ANON+=VM[j];																																											\
													}																																																			\
												if (ERASE_CHAR != 0)																																										\
												{																																																				\
													for (i=1; i<=20; i++)																																									\
													{																																																			\
														RSS_SHARED_CLEAN[i]=ERASE_CHAR;																																			\
														RSS_SHARED_DIRTY[i]=ERASE_CHAR;																																			\
														RSS_PRIVATE_CLEAN[i]=ERASE_CHAR;																																		\
														RSS_PRIVATE_DIRTY[i]=ERASE_CHAR;																																		\
													}																																																			\
													RSS_SHARED_CLEAN_SUM=ERASE_CHAR;																																			\
													RSS_SHARED_DIRTY_SUM=ERASE_CHAR;																																			\
													RSS_PRIVATE_CLEAN_SUM=ERASE_CHAR;																																			\
													RSS_PRIVATE_DIRTY_SUM=ERASE_CHAR;																																			\
												}									
												print	RSS_PRIVATE_CLEAN[1] , RSS_PRIVATE_DIRTY[1] , RSS_SHARED_CLEAN[1] , RSS_SHARED_DIRTY[1] , VM[1] ,\
															RSS_PRIVATE_CLEAN[2] , RSS_PRIVATE_DIRTY[2] , RSS_SHARED_CLEAN[2] , RSS_SHARED_DIRTY[2] , VM[2] ,\
															RSS_PRIVATE_CLEAN[3] , RSS_PRIVATE_DIRTY[3] , RSS_SHARED_CLEAN[3] , RSS_SHARED_DIRTY[3] , VM[3] ,\
															RSS_PRIVATE_CLEAN[4] , RSS_PRIVATE_DIRTY[4] , RSS_SHARED_CLEAN[4] , RSS_SHARED_DIRTY[4] , VM[4] ,\
															RSS_PRIVATE_CLEAN[5] , RSS_PRIVATE_DIRTY[5] , RSS_SHARED_CLEAN[5] , RSS_SHARED_DIRTY[5] , VM[5] ,\
															RSS_PRIVATE_CLEAN[6] , RSS_PRIVATE_DIRTY[6] , RSS_SHARED_CLEAN[6] , RSS_SHARED_DIRTY[6] , VM[6] ,\
															RSS_PRIVATE_CLEAN[7] , RSS_PRIVATE_DIRTY[7] , RSS_SHARED_CLEAN[7] , RSS_SHARED_DIRTY[7] , VM[7] ,\
															RSS_PRIVATE_CLEAN[8] , RSS_PRIVATE_DIRTY[8] , RSS_SHARED_CLEAN[8] , RSS_SHARED_DIRTY[8] , VM[8] ,\
															RSS_PRIVATE_CLEAN[9] , RSS_PRIVATE_DIRTY[9] , RSS_SHARED_CLEAN[9] , RSS_SHARED_DIRTY[9] , VM[9] ,\
															RSS_PRIVATE_CLEAN[10], RSS_PRIVATE_DIRTY[10], RSS_SHARED_CLEAN[10], RSS_SHARED_DIRTY[10], VM[10],\
															RSS_PRIVATE_CLEAN[11], RSS_PRIVATE_DIRTY[11], RSS_SHARED_CLEAN[11], RSS_SHARED_DIRTY[11], VM[11],\
															RSS_PRIVATE_CLEAN[12], RSS_PRIVATE_DIRTY[12], RSS_SHARED_CLEAN[12], RSS_SHARED_DIRTY[12], VM[12],\
															RSS_PRIVATE_CLEAN[13], RSS_PRIVATE_DIRTY[13], RSS_SHARED_CLEAN[13], RSS_SHARED_DIRTY[13], VM[13],\
															RSS_PRIVATE_CLEAN[14], RSS_PRIVATE_DIRTY[14], RSS_SHARED_CLEAN[14], RSS_SHARED_DIRTY[14], VM[14],\
															RSS_PRIVATE_CLEAN[15], RSS_PRIVATE_DIRTY[15], RSS_SHARED_CLEAN[15], RSS_SHARED_DIRTY[15], VM[15],\
															RSS_PRIVATE_CLEAN[16], RSS_PRIVATE_DIRTY[16], RSS_SHARED_CLEAN[16], RSS_SHARED_DIRTY[16], VM[16],\
															RSS_PRIVATE_CLEAN[17], RSS_PRIVATE_DIRTY[17], RSS_SHARED_CLEAN[17], RSS_SHARED_DIRTY[17], VM[17],\
															RSS_PRIVATE_CLEAN[18], RSS_PRIVATE_DIRTY[18], RSS_SHARED_CLEAN[18], RSS_SHARED_DIRTY[18], VM[18],\
															RSS_PRIVATE_CLEAN[19], RSS_PRIVATE_DIRTY[19], RSS_SHARED_CLEAN[19], RSS_SHARED_DIRTY[19], VM[19],\
															RSS_PRIVATE_CLEAN[20], RSS_PRIVATE_DIRTY[20], RSS_SHARED_CLEAN[20], RSS_SHARED_DIRTY[20], VM[20],\
															RSS_PRIVATE_CLEAN_SUM, RSS_PRIVATE_DIRTY_SUM, RSS_SHARED_CLEAN_SUM, RSS_SHARED_DIRTY_SUM, VM_SUM,\
															VM_MAPPED, VM_ANON;																																								\
											}																																																					\
									'	/proc/$PID/$MAPS_SMAPS	ERASE_CHAR=$NON_EXISTENT_CHAR																												\
						` )

		# get process command instead of name for SDL processes
		PCMD=`cat /proc/$PID/cmdline | tr -d '\0'`

		# get process name instead of command for kernel threads
		if [ -z "$PCMD" ] ; then
			PCMD=[${STATUS[0]}];
		fi

		# check for presence of PID parameter
		if [ -z $1 ]; then

			printf "%8s|" $PID
			if [ $DETAILED -eq 0 ] ; then
				if [ -e /proc/self/smaps ] ; then
					printf "%8s|%8s|%8s|%8s|%8s|%8s|" ${STATM[0]}  $(( ${SMAPS[100]} + ${SMAPS[101]} ))  $(( ${SMAPS[102]} + ${SMAPS[103]} ))  ${STATUS[4]} ${SMAPS[105]} ${SMAPS[106]}
				else
					printf "%8s|%8s|%8s|%8s|%8s|%8s|" ${STATM[0]}  $RSS_PRIVATE  $RSS_SHARED  ${STATUS[4]} ${SMAPS[105]} ${SMAPS[106]}
				fi
			fi
			if [ $DETAILED -eq 1 ] ; then
				printf "%8s|%8s|%8s|%8s|%8s|%8s|" ${SMAPS[100]} ${SMAPS[101]} ${SMAPS[102]} ${SMAPS[103]} ${SMAPS[105]} ${SMAPS[106]}
			fi
			printf "%s " $PCMD
			printf "\n"

		else

			# Wind River Linux?
			if [ ${LINUX_DISTRO[0]} == Wind ] ; then

				printf "\n"
				printf "Process ID:   %-s  \n" $PID
				printf "Process name: %-s  \n" ${STATUS[0]}
				printf "Command line: %.95s  \n" $PCMD
				printf "Thread(s):    %-s  \n" ${STATUS[1]}
				printf "\n"
				printf " -------------------------------------------- \n"
				printf "|             PHYSICAL              | VIRTUAL| \n"
				printf "|              %8s              |%8s| \n" ${STATM[0]} ${STATUS[4]}
				printf "|-----------------------------------|        | \n"
				printf "|    PRIVATE      |     SHARED      |        | \n"
				if [ -e "/proc/self/smaps" ] ; then
				printf "|   %8s      |   %8s      |        | \n" $(( ${SMAPS[100]} + ${SMAPS[101]} )) $(( ${SMAPS[102]} + ${SMAPS[103]} ))
				else
				printf "|   %8s      |   %8s      |        | \n" $RSS_PRIVATE $RSS_SHARED
				fi
				printf "|-----------------|-----------------|        | \n"
				printf "| CLEAN  | DIRTY  | CLEAN  | DIRTY  |        | \n"
				printf "|%8s|%8s|%8s|%8s|%8s| \n" ${SMAPS[100]}  ${SMAPS[101]}  ${SMAPS[102]}  ${SMAPS[103]}  ${SMAPS[104]} 
				printf "|--------|--------|--------|--------|--------|---------------------------------------------------------------- \n"
				printf "|%8s|%8s|%8s|%8s|%8s|---p| guardian segment                                          | \n" ${SMAPS[0]}  ${SMAPS[1]}  ${SMAPS[2]}  ${SMAPS[3]}  ${SMAPS[4]}  
				printf "|%8s|%8s|%8s|%8s|%8s|---s| -                                                         | \n" ${SMAPS[5]}  ${SMAPS[6]}  ${SMAPS[7]}  ${SMAPS[8]}  ${SMAPS[9]}  
				printf "|%8s|%8s|%8s|%8s|%8s|r--p| DATA-RO                                                   | \n" ${SMAPS[10]} ${SMAPS[11]} ${SMAPS[12]} ${SMAPS[13]} ${SMAPS[14]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r--s|                                                           | \n" ${SMAPS[15]} ${SMAPS[16]} ${SMAPS[17]} ${SMAPS[18]} ${SMAPS[19]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r-xp| TEXT                                                      | \n" ${SMAPS[20]} ${SMAPS[21]} ${SMAPS[22]} ${SMAPS[23]} ${SMAPS[24]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r-xs| -                                                         | \n" ${SMAPS[25]} ${SMAPS[26]} ${SMAPS[27]} ${SMAPS[28]} ${SMAPS[29]} 
				if [ "$MACHINE_NAME" != "ppc" ]; then
				printf "|%8s|%8s|%8s|%8s|%8s|rw-p| DATA-RW, mmap(file)                                       | \n" ${SMAPS[30]} ${SMAPS[31]} ${SMAPS[32]} ${SMAPS[33]} ${SMAPS[34]} 
				else
				printf "|%8s|%8s|%8s|%8s|%8s|rw-p| -                                                         | \n" ${SMAPS[30]} ${SMAPS[31]} ${SMAPS[32]} ${SMAPS[33]} ${SMAPS[34]} 
				fi
				printf "|%8s|%8s|%8s|%8s|%8s|rw-s| SHMEM = System V shared memory                            | \n" ${SMAPS[35]} ${SMAPS[36]} ${SMAPS[37]} ${SMAPS[38]} ${SMAPS[39]} 
				if [ "$MACHINE_NAME" != "ppc" ]; then
				printf "|%8s|%8s|%8s|%8s|%8s|rwxp| -                                                         | \n" ${SMAPS[40]} ${SMAPS[41]} ${SMAPS[42]} ${SMAPS[43]} ${SMAPS[44]} 
				else
				printf "|%8s|%8s|%8s|%8s|%8s|rwxp| -                                                         | \n" ${SMAPS[40]} ${SMAPS[41]} ${SMAPS[42]} ${SMAPS[43]} ${SMAPS[44]} 
				fi
				printf "|%8s|%8s|%8s|%8s|%8s|rwxs| -                                                         | \n" ${SMAPS[45]} ${SMAPS[46]} ${SMAPS[47]} ${SMAPS[48]} ${SMAPS[49]} 
				printf "|--------|--------|--------|--------|--------|----|-----------------------------------------------------------| \n"
				printf "|%8s|%8s|%8s|%8s|%8s|---p| thread stack guardian page(s)                             | \n" ${SMAPS[50]} ${SMAPS[51]} ${SMAPS[52]} ${SMAPS[53]} ${SMAPS[54]} 
				printf "|%8s|%8s|%8s|%8s|%8s|---s| -                                                         | \n" ${SMAPS[55]} ${SMAPS[56]} ${SMAPS[57]} ${SMAPS[58]} ${SMAPS[59]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r--p| -                                                         | \n" ${SMAPS[60]} ${SMAPS[61]} ${SMAPS[62]} ${SMAPS[63]} ${SMAPS[64]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r--s|                                                           | \n" ${SMAPS[65]} ${SMAPS[66]} ${SMAPS[67]} ${SMAPS[68]} ${SMAPS[69]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r-xp| [vdso]                                                    | \n" ${SMAPS[70]} ${SMAPS[71]} ${SMAPS[72]} ${SMAPS[73]} ${SMAPS[74]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r-xs| -                                                         | \n" ${SMAPS[75]} ${SMAPS[76]} ${SMAPS[77]} ${SMAPS[78]} ${SMAPS[79]} 
				if [ "$MACHINE_NAME" != "ppc" ]; then
				printf "|%8s|%8s|%8s|%8s|%8s|rw-p| [stack], thread stack, [heap], malloc(>128KiB), mmap(anon)| \n" ${SMAPS[80]} ${SMAPS[81]} ${SMAPS[82]} ${SMAPS[83]} ${SMAPS[84]} 
				else
				printf "|%8s|%8s|%8s|%8s|%8s|rw-p| -                                                         | \n" ${SMAPS[80]} ${SMAPS[81]} ${SMAPS[82]} ${SMAPS[83]} ${SMAPS[84]} 
				fi
				printf "|%8s|%8s|%8s|%8s|%8s|rw-s| -                                                         | \n" ${SMAPS[85]} ${SMAPS[86]} ${SMAPS[87]} ${SMAPS[88]} ${SMAPS[89]} 
				if [ "$MACHINE_NAME" != "ppc" ]; then
				printf "|%8s|%8s|%8s|%8s|%8s|rwxp| SDL [stack], SDL thread stack                             | \n" ${SMAPS[90]} ${SMAPS[91]} ${SMAPS[92]} ${SMAPS[93]} ${SMAPS[94]} 
				else
				printf "|%8s|%8s|%8s|%8s|%8s|rwxp| -                                                         | \n" ${SMAPS[90]} ${SMAPS[91]} ${SMAPS[92]} ${SMAPS[93]} ${SMAPS[94]} 
				fi
				printf "|%8s|%8s|%8s|%8s|%8s|rwxs| -                                                         | \n" ${SMAPS[95]} ${SMAPS[96]} ${SMAPS[97]} ${SMAPS[98]} ${SMAPS[99]} 
				printf " ------------------------------------------------------------------------------------------------------------- \n"
				printf "\n"
				exit 0

			fi # Wind River Linux?

			# RedHat Enterprise Linux?
			if [ ${LINUX_DISTRO[0]} == Red ]; then

				printf "\n"
				printf "Process ID:   %-s  \n" $PID
				printf "Process name: %-s  \n" ${STATUS[0]}
				printf "Command line: %.95s  \n" $PCMD
				printf "Thread(s):    %-s  \n" ${STATUS[1]}
				printf "\n"
				printf " -------------------------------------------- \n"
				printf "|             PHYSICAL              | VIRTUAL| \n"
				printf "|              %8s              |%8s| \n" ${STATM[0]} ${STATUS[4]}
				printf "|-----------------------------------|        | \n"
				printf "|    PRIVATE      |     SHARED      |        | \n"
				if [ -e "/proc/self/smaps" ] ; then
				printf "|   %8s      |   %8s      |        | \n" $(( ${SMAPS[100]} + ${SMAPS[101]} )) $(( ${SMAPS[102]} + ${SMAPS[103]} ))
				else
				printf "|   %8s      |   %8s      |        | \n" $RSS_PRIVATE $RSS_SHARED
				fi
				printf "|-----------------|-----------------|        | \n"
				printf "| CLEAN  | DIRTY  | CLEAN  | DIRTY  |        | \n"
				printf "|%8s|%8s|%8s|%8s|%8s| \n" ${SMAPS[100]}  ${SMAPS[101]}  ${SMAPS[102]}  ${SMAPS[103]}  ${SMAPS[104]} 
				printf "|--------|--------|--------|--------|--------|---------------------------------------------------------------- \n"
				printf "|%8s|%8s|%8s|%8s|%8s|---p|                                                           | \n" ${SMAPS[0]}  ${SMAPS[1]}  ${SMAPS[2]}  ${SMAPS[3]}  ${SMAPS[4]}  
				printf "|%8s|%8s|%8s|%8s|%8s|---s| -                                                         | \n" ${SMAPS[5]}  ${SMAPS[6]}  ${SMAPS[7]}  ${SMAPS[8]}  ${SMAPS[9]}  
				printf "|%8s|%8s|%8s|%8s|%8s|r--p| DATA-RO                                                   | \n" ${SMAPS[10]} ${SMAPS[11]} ${SMAPS[12]} ${SMAPS[13]} ${SMAPS[14]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r--s|                                                           | \n" ${SMAPS[15]} ${SMAPS[16]} ${SMAPS[17]} ${SMAPS[18]} ${SMAPS[19]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r-xp| TEXT                                                      | \n" ${SMAPS[20]} ${SMAPS[21]} ${SMAPS[22]} ${SMAPS[23]} ${SMAPS[24]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r-xs| -                                                         | \n" ${SMAPS[25]} ${SMAPS[26]} ${SMAPS[27]} ${SMAPS[28]} ${SMAPS[29]} 
				if [ "$MACHINE_NAME" != "ppc" ]; then
				printf "|%8s|%8s|%8s|%8s|%8s|rw-p| DATA-RW, mmap(file)                                       | \n" ${SMAPS[30]} ${SMAPS[31]} ${SMAPS[32]} ${SMAPS[33]} ${SMAPS[34]} 
				else
				printf "|%8s|%8s|%8s|%8s|%8s|rw-p| -                                                         | \n" ${SMAPS[30]} ${SMAPS[31]} ${SMAPS[32]} ${SMAPS[33]} ${SMAPS[34]} 
				fi
				printf "|%8s|%8s|%8s|%8s|%8s|rw-s| SHMEM = System V shared memory                            | \n" ${SMAPS[35]} ${SMAPS[36]} ${SMAPS[37]} ${SMAPS[38]} ${SMAPS[39]} 
				if [ "$MACHINE_NAME" != "ppc" ]; then
				printf "|%8s|%8s|%8s|%8s|%8s|rwxp| libs DATA-RW                                              | \n" ${SMAPS[40]} ${SMAPS[41]} ${SMAPS[42]} ${SMAPS[43]} ${SMAPS[44]} 
				else
				printf "|%8s|%8s|%8s|%8s|%8s|rwxp| ????                                                      | \n" ${SMAPS[40]} ${SMAPS[41]} ${SMAPS[42]} ${SMAPS[43]} ${SMAPS[44]} 
				fi
				printf "|%8s|%8s|%8s|%8s|%8s|rwxs| -                                                         | \n" ${SMAPS[45]} ${SMAPS[46]} ${SMAPS[47]} ${SMAPS[48]} ${SMAPS[49]} 
				printf "|--------|--------|--------|--------|--------|----|-----------------------------------------------------------| \n"
				printf "|%8s|%8s|%8s|%8s|%8s|---p| thread stack guardian page(s),                            | \n" ${SMAPS[50]} ${SMAPS[51]} ${SMAPS[52]} ${SMAPS[53]} ${SMAPS[54]} 
				printf "|%8s|%8s|%8s|%8s|%8s|---s| -                                                         | \n" ${SMAPS[55]} ${SMAPS[56]} ${SMAPS[57]} ${SMAPS[58]} ${SMAPS[59]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r--p| -                                                         | \n" ${SMAPS[60]} ${SMAPS[61]} ${SMAPS[62]} ${SMAPS[63]} ${SMAPS[64]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r--s|                                                           | \n" ${SMAPS[65]} ${SMAPS[66]} ${SMAPS[67]} ${SMAPS[68]} ${SMAPS[69]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r-xp| [vdso]                                                    | \n" ${SMAPS[70]} ${SMAPS[71]} ${SMAPS[72]} ${SMAPS[73]} ${SMAPS[74]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r-xs| -                                                         | \n" ${SMAPS[75]} ${SMAPS[76]} ${SMAPS[77]} ${SMAPS[78]} ${SMAPS[79]} 
				if [ "$MACHINE_NAME" != "ppc" ]; then
				printf "|%8s|%8s|%8s|%8s|%8s|rw-p| [stack], thread stack, [heap], malloc(>128KiB), mmap(anon)| \n" ${SMAPS[80]} ${SMAPS[81]} ${SMAPS[82]} ${SMAPS[83]} ${SMAPS[84]} 
				else
				printf "|%8s|%8s|%8s|%8s|%8s|rw-p| ?????                                                     | \n" ${SMAPS[80]} ${SMAPS[81]} ${SMAPS[82]} ${SMAPS[83]} ${SMAPS[84]} 
				fi
				printf "|%8s|%8s|%8s|%8s|%8s|rw-s| -                                                         | \n" ${SMAPS[85]} ${SMAPS[86]} ${SMAPS[87]} ${SMAPS[88]} ${SMAPS[89]} 
				if [ "$MACHINE_NAME" != "ppc" ]; then
				printf "|%8s|%8s|%8s|%8s|%8s|rwxp| libs malloc(>128KiB), libs mmap(anon)                     | \n" ${SMAPS[90]} ${SMAPS[91]} ${SMAPS[92]} ${SMAPS[93]} ${SMAPS[94]} 
				else
				printf "|%8s|%8s|%8s|%8s|%8s|rwxp| ?????                                                     | \n" ${SMAPS[90]} ${SMAPS[91]} ${SMAPS[92]} ${SMAPS[93]} ${SMAPS[94]} 
				fi
				printf "|%8s|%8s|%8s|%8s|%8s|rwxs| -                                                         | \n" ${SMAPS[95]} ${SMAPS[96]} ${SMAPS[97]} ${SMAPS[98]} ${SMAPS[99]} 
				printf " ------------------------------------------------------------------------------------------------------------- \n"
				printf "\n"
				exit 0

			fi # RedHat Enterprise Linux?
			
			
			# MontaVista CGE/PRO?
			#if [ ${LINUX_DISTRO[0]} == 'MontaVista(R)' ]; then
			if ( [ ${LINUX_DISTRO[0]} == 'MontaVista(R)' ] || [ ${LINUX_DISTRO[0]} ] ) ; then

				printf "\n"
				printf "Process ID:   %-s  \n" $PID
				printf "Process name: %-s  \n" ${STATUS[0]}
				printf "Command line: %.95s  \n" $PCMD
				printf "Thread(s):    %-s  \n" ${STATUS[1]}
				printf "\n"
				printf " -------------------------------------------- \n"
				printf "|             PHYSICAL              | VIRTUAL| \n"
				printf "|              %8s              |%8s| \n" ${STATM[0]} ${STATUS[4]}
				printf "|-----------------------------------|        | \n"
				printf "|    PRIVATE      |     SHARED      |        | \n"
				if [ -e "/proc/self/smaps" ] ; then
				printf "|   %8s      |   %8s      |        | \n" $(( ${SMAPS[100]} + ${SMAPS[101]} )) $(( ${SMAPS[102]} + ${SMAPS[103]} ))
				else
				printf "|   %8s      |   %8s      |        | \n" $RSS_PRIVATE $RSS_SHARED
				fi
				printf "|-----------------|-----------------|        | \n"
				printf "| CLEAN  | DIRTY  | CLEAN  | DIRTY  |        | \n"
				printf "|%8s|%8s|%8s|%8s|%8s| \n" ${SMAPS[100]}  ${SMAPS[101]}  ${SMAPS[102]}  ${SMAPS[103]}  ${SMAPS[104]} 
				printf "|--------|--------|--------|--------|--------|---------------------------------------------------------------- \n"
				printf "|%8s|%8s|%8s|%8s|%8s|---p| guardian segment                                          | \n" ${SMAPS[0]}  ${SMAPS[1]}  ${SMAPS[2]}  ${SMAPS[3]}  ${SMAPS[4]}  
				printf "|%8s|%8s|%8s|%8s|%8s|---s| -                                                         | \n" ${SMAPS[5]}  ${SMAPS[6]}  ${SMAPS[7]}  ${SMAPS[8]}  ${SMAPS[9]}  
				printf "|%8s|%8s|%8s|%8s|%8s|r--p| DATA-RO                                                   | \n" ${SMAPS[10]} ${SMAPS[11]} ${SMAPS[12]} ${SMAPS[13]} ${SMAPS[14]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r--s|                                                           | \n" ${SMAPS[15]} ${SMAPS[16]} ${SMAPS[17]} ${SMAPS[18]} ${SMAPS[19]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r-xp| TEXT                                                      | \n" ${SMAPS[20]} ${SMAPS[21]} ${SMAPS[22]} ${SMAPS[23]} ${SMAPS[24]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r-xs| -                                                         | \n" ${SMAPS[25]} ${SMAPS[26]} ${SMAPS[27]} ${SMAPS[28]} ${SMAPS[29]} 
				if [ "$MACHINE_NAME" != "ppc" ]; then
				printf "|%8s|%8s|%8s|%8s|%8s|rw-p| DATA-RW, mmap(file)                                       | \n" ${SMAPS[30]} ${SMAPS[31]} ${SMAPS[32]} ${SMAPS[33]} ${SMAPS[34]} 
				else
				printf "|%8s|%8s|%8s|%8s|%8s|rw-p| -                                                         | \n" ${SMAPS[30]} ${SMAPS[31]} ${SMAPS[32]} ${SMAPS[33]} ${SMAPS[34]} 
				fi
				printf "|%8s|%8s|%8s|%8s|%8s|rw-s| SHMEM = System V shared memory                            | \n" ${SMAPS[35]} ${SMAPS[36]} ${SMAPS[37]} ${SMAPS[38]} ${SMAPS[39]} 
				if [ "$MACHINE_NAME" != "ppc" ]; then
				printf "|%8s|%8s|%8s|%8s|%8s|rwxp| -                                                         | \n" ${SMAPS[40]} ${SMAPS[41]} ${SMAPS[42]} ${SMAPS[43]} ${SMAPS[44]} 
				else
				printf "|%8s|%8s|%8s|%8s|%8s|rwxp| DATA-RW, mmap(file)                                       | \n" ${SMAPS[40]} ${SMAPS[41]} ${SMAPS[42]} ${SMAPS[43]} ${SMAPS[44]} 
				fi
				printf "|%8s|%8s|%8s|%8s|%8s|rwxs| -                                                         | \n" ${SMAPS[45]} ${SMAPS[46]} ${SMAPS[47]} ${SMAPS[48]} ${SMAPS[49]} 
				printf "|--------|--------|--------|--------|--------|----|-----------------------------------------------------------| \n"
				printf "|%8s|%8s|%8s|%8s|%8s|---p| thread stack guardian page(s)                             | \n" ${SMAPS[50]} ${SMAPS[51]} ${SMAPS[52]} ${SMAPS[53]} ${SMAPS[54]} 
				printf "|%8s|%8s|%8s|%8s|%8s|---s| -                                                         | \n" ${SMAPS[55]} ${SMAPS[56]} ${SMAPS[57]} ${SMAPS[58]} ${SMAPS[59]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r--p| -                                                         | \n" ${SMAPS[60]} ${SMAPS[61]} ${SMAPS[62]} ${SMAPS[63]} ${SMAPS[64]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r--s|                                                           | \n" ${SMAPS[65]} ${SMAPS[66]} ${SMAPS[67]} ${SMAPS[68]} ${SMAPS[69]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r-xp| [vdso]                                                    | \n" ${SMAPS[70]} ${SMAPS[71]} ${SMAPS[72]} ${SMAPS[73]} ${SMAPS[74]} 
				printf "|%8s|%8s|%8s|%8s|%8s|r-xs| -                                                         | \n" ${SMAPS[75]} ${SMAPS[76]} ${SMAPS[77]} ${SMAPS[78]} ${SMAPS[79]} 
				if [ "$MACHINE_NAME" != "ppc" ]; then
				printf "|%8s|%8s|%8s|%8s|%8s|rw-p| [stack], thread stack, [heap], malloc(>128KiB), mmap(anon)| \n" ${SMAPS[80]} ${SMAPS[81]} ${SMAPS[82]} ${SMAPS[83]} ${SMAPS[84]} 
				else
				printf "|%8s|%8s|%8s|%8s|%8s|rw-p| [stack], thread stack                                     | \n" ${SMAPS[80]} ${SMAPS[81]} ${SMAPS[82]} ${SMAPS[83]} ${SMAPS[84]} 
				fi
				printf "|%8s|%8s|%8s|%8s|%8s|rw-s| -                                                         | \n" ${SMAPS[85]} ${SMAPS[86]} ${SMAPS[87]} ${SMAPS[88]} ${SMAPS[89]} 
				if [ "$MACHINE_NAME" != "ppc" ]; then
				printf "|%8s|%8s|%8s|%8s|%8s|rwxp| SDL [stack], SDL thread stack                             | \n" ${SMAPS[90]} ${SMAPS[91]} ${SMAPS[92]} ${SMAPS[93]} ${SMAPS[94]} 
				else
				printf "|%8s|%8s|%8s|%8s|%8s|rwxp| [heap], malloc(>128KiB), mmap(anon)                       | \n" ${SMAPS[90]} ${SMAPS[91]} ${SMAPS[92]} ${SMAPS[93]} ${SMAPS[94]} 
				fi
				printf "|%8s|%8s|%8s|%8s|%8s|rwxs| -                                                         | \n" ${SMAPS[95]} ${SMAPS[96]} ${SMAPS[97]} ${SMAPS[98]} ${SMAPS[99]} 
				printf " ------------------------------------------------------------------------------------------------------------- \n"
				printf "\n"
				exit 0

			fi # MontaVista CGE/PRO?

		fi # check for presence of PID parameter

	fi

done

