#!/bin/bash 
###########################################################################
#                                                                         #
#                                                                         #
#              Copyright (c) 2007 IskraTEL                                #
#                                                                         #
#                                                                         #
#                                                                         #
#   Name        : syslog.sh                                               #
#                                                                         #
#   Description : Shell script for setting config file syslog-ng.conf     #
#                                                                         #
#   Position    : $PRODUCT_DIR/bin/                                       #
#                                                                         #
#   Code        :                                                         #
#                                                                         #
#   Date        : jun 2010                                                #
#                                                                         #
#   Author      : Cvetka Milinovic                                        #
#                                                                         #
#   Translation : * None                                                  #
#                                                                         #
#   Remarks     : Based on snps.sh written by Jure Buble, Metalab         #
#                                                                         #
#   Revisions   :                                                         #
#                                                                         #
###########################################################################


###################################################
#                                                 #	
# System parameters, path to commands and files   #
#                                                 #
###################################################

################
# Executables  #
################
PATH=/bin:/usr/bin:$PATH
SED=sed
AWK=awk
GREP=grep
CAT=cat
MVE=mv
ECHO=echo
WC=wc

#####################
# DEBUGGING PURPOSE #
#####################
DEBUG=0
if [ "$DEBUG" -eq "1" ]
then
  DEBUGFILE=/tmp/debug.log
  $ECHO "syslog.sh at `date`" >> $DEBUGFILE
else
  DEBUGFILE=/dev/null
fi

#######################
# System config files #
#######################

SYSLOGCONF=/etc/syslog-ng/syslog-ng.conf
SYSLOGCONF_1=/etc/syslog-ng/syslog-ng.conf.1
SYSLOGCONF_2=/etc/syslog-ng/syslog-ng.conf.2
SYSLOGCONF_3=/etc/syslog-ng/syslog-ng.conf.3

########################
# Errors and reporting #
########################

UNSP_PORTNR_VALUES=666
E_BADARGS=65
E_NOFILE=66
UNSP_FLTR_VALUES=67
GRPNMBR_ERR=68
DB_ERROR=69
USRNMBR_ERR=70
WRONG_IP_FUNCTION=71
LOCALHOST_ERRO=72

#################################
#  Parameters read from input	  #
#################################




#################################
#   Function definitions    	  #
#################################

write_syslogconf ()
{
	if [ -s $SYSLOGCONF_1 ]
    then
      mv $SYSLOGCONF_1 $SYSLOGCONF
    else
		  $ECHO "Unable to write $SYSLOGCONF !"  | $LOGGER
  fi
}
wrong_params () {
  $ECHO "Usage: `basename $0` -action [DELETE|INSERT] -server [syslog_server_ip] -port [1...65535] -severity [0(emerg)|1(alert)|2(crit)|3(err)|4(warn)|5(notice)|6(alert)|7(debug)] -facility [0..23]"
  exit $E_BADARGS
}

check_syslog_severity () {
case $CURR_LEVEL in	
	0)
	  SEVERITY=emerg
	  ;;
	1)
	  SEVERITY=alert
	  ;;
	2)
	  SEVERITY=crit
	  ;;
	3)
	  SEVERITY=err
	  ;;
	4)
	  SEVERITY=warning
	  ;;
	5)
	  SEVERITY=notice
	  ;;
	6)
	  SEVERITY=info
	  ;;
	7)
	  SEVERITY=debug
	  ;;
	*)
	 wrong_params
	  ;;
esac 
  
}

check_syslog_facility () {
case $CURR_FACILITY_LEVEL in	
	0)
	  FACILITY=kern
	  ;;
	1)
	  FACILITY=user
	  ;;
	2)
	  FACILITY=mail
	  ;;
	3)
	  FACILITY=daemon
	  ;;
	4)
	  FACILITY=auth
	  ;;
	5)
	  FACILITY=syslog
	  ;;
	6)
	  FACILITY=lpr
	  ;;
	7)
	  FACILITY=news
	  ;;
    8)
	  FACILITY=uucp
	  ;;
	9)
	  FACILITY=cron
	  ;;
	10)
	  FACILITY=authpriv
	  ;;
	11)
	  FACILITY=ftp
	  ;;
	12)
	  FACILITY=ntp
	  ;;
	13)
	  FACILITY=security
	  ;;
	14)
	  FACILITY=console
	  ;;
	15)
	  FACILITY=solaris-cron
	  ;;  
	16)
	  FACILITY=local0
	  ;;
	17)
	  FACILITY=local1
	  ;;
	18)
	  FACILITY=local2
	  ;;
	19)
	  FACILITY=local3
	  ;;
	20)
	  FACILITY=local4
	  ;;
	21)
	  FACILITY=local5
	  ;;    
	22)
	  FACILITY=local6
	  ;;   
	23)
	  FACILITY=local7
	  ;;       
    "")
	  FACILITY="\$FACILITY"
	  ;;                 
	*)
	 wrong_params
	  ;;
esac 
  
}


#################
#  main ()			#
#################
#Check parametrs
if [ $# -lt "2" ]  
then
  wrong_params
else
        if [ $# -eq "2" ]
        then
                if [ "$1" != "-action" -o "$2" != "DELETE" ] 
	        then
	                wrong_params
	        fi
	fi
fi
#Start processing
  I=1
  SER_CURRENT=0
  PORT_CURRENT=0
  LEV_CURRENT=0
  FACILITY_LEVEL_CURRENT=0
  LAST=1
  DEF_SERVER="localhost"
  SERVER="localhost"
  DEF_PORT="514"
  PORT="514"
  LEVEL=2
  DEF_LEVEL=2
  FACILITY_LEVEL=""
  DEF_FACILITY_LEVEL=""
  ARGS=$#

   
   if [ "$1" == "-action" ]
   then
      ACTION=$2	
   fi
   if [ "$ACTION" != "DELETE" -a "$ACTION" != "INSERT" ]	
   then
         wrong_params
   fi
   #delete privious values if any
   $SED "/destination d_udp_cli/d" $SYSLOGCONF > $SYSLOGCONF_3
   $SED "/filter f_lnxadm_cli/d" $SYSLOGCONF_3 > $SYSLOGCONF_2
   $SED "/destination(d_udp_cli/d" $SYSLOGCONF_2 > $SYSLOGCONF_1
   write_syslogconf	
   if  [ "$ACTION" = "DELETE" ] 
   then 
  # If only deleting arguments requested then exit here
      exit 0
   fi
  # collect all sources for logging      
   S=`$GREP "source " $SYSLOGCONF | $AWK '{split($0,arr,"{")}{ print arr[1]}'`
   VREDNOST=`$ECHO $S | $SED "s/source /source (/g" | $SED "s/ source/); source/g"`
   shift 2
   I=$[$I + 2] 
  # start reading values 
   while [ "$I" -lt "$ARGS" ]
   do
        case $1 in
	  -port)	
	        if [ "$2" -lt 1 -o "$2" -gt 65535 ]	
                then
                      wrong_params
                fi
                PORT_OLD=$PORT
	        PORT=$2
                PORT_CURRENT=$[$PORT_CURRENT + 1]
		;;
	  -server)
                SERVER_OLD=$SERVER
		SERVER=$2
                SER_CURRENT=$[$SER_CURRENT + 1]
		;;
	  -severity)
                LEVEL_OLD=$LEVEL
		LEVEL=$2
                LEV_CURRENT=$[$LEV_CURRENT + 1]
		;;
	  -facility)
                FACILITY_LEVEL_OLD=$FACILITY_LEVEL
		FACILITY_LEVEL=$2
                FACILITY_LEVEL_CURRENT=$[$FACILITY_LEVEL_CURRENT + 1]
		;;        
	  *)
	        wrong_params		
	        ;;
        esac
	    shift 2
	    I=$[$I + 2]

        if [ $LAST -lt $SER_CURRENT ]
        then
        # insert previous server because now we are sure that all parameters are read
                CURR_SERVER=$SERVER_OLD
                # set values for port and severity
                if [ $PORT_CURRENT -lt $LAST ]
                then  
                # port was not set use default
                        CURR_PORT=$DEF_PORT
                        PORT_CURRENT=$LAST
                else                
                        if [ $PORT_CURRENT -gt $LAST ]
                        then 
                        # it can not happend but just in case
                                CURR_PORT=$PORT_OLD
                        else
                                CURR_PORT=$PORT 
                        fi
                fi
                if [ $LEV_CURRENT -lt $LAST ]
                then  
                 # severity level was not set use default
                        CURR_LEVEL=$DEF_LEVEL
                        LEV_CURRENT=$LAST
                else
                        if [ $LEV_CURRENT -gt $LAST ]
                        then  
                        # it can not happend but just in case
                                CURR_LEVEL=$LEVEL_OLD
                        else
                                CURR_LEVEL=$LEVEL
                        fi
                fi
                if [ $FACILITY_LEVEL_CURRENT -lt $LAST ]
                then  
                 # severity level was not set use default
                        CURR_FACILITY_LEVEL=$DEF_FACILITY_LEVEL
                        FACILITY_LEVEL_CURRENT=$LAST
                else
                        if [ $FACILITY_LEVEL_CURRENT -gt $LAST ]
                        then  
                        # it can not happend but just in case
                                CURR_FACILITY_LEVEL=$FACILITY_LEVEL_OLD
                        else
                                CURR_FACILITY_LEVEL=$FACILITY_LEVEL
                        fi
                fi
                LAST=$[$LAST + 1]
                # get syslog-ng severity from level 
                check_syslog_severity
                # get syslog-ng facility from level 
                check_syslog_facility
                #insert new values into SYSLOGCONF file
                CURR_SERVER_NAME=`(echo $CURR_SERVER | sed 's|:|_|g')`
                if [ "$CURR_FACILITY_LEVEL" == "" ]
                then
                   PRI="\$PRI"
                else 
                   PRI=$(($CURR_FACILITY_LEVEL*8 + $CURR_LEVEL))
                fi
		if [ "x$CURR_SERVER_NAME" == "x$CURR_SERVER" ]
		then
		   $ECHO "destination d_udp_cli_$CURR_SERVER_NAME { udp(\"$CURR_SERVER\" port($CURR_PORT) template(\"\<$PRI\>\$DATE \$HOST \$LEVEL\/$FACILITY \$MSGHDR \$MSG\n\")); };" >> $SYSLOGCONF
		else 
		   $ECHO "destination d_udp_cli_$CURR_SERVER_NAME { udp6(\"$CURR_SERVER\" port($CURR_PORT) template(\"\<$PRI\>\$DATE \$HOST \$LEVEL\/$FACILITY \$MSGHDR \$MSG\n\")); };" >> $SYSLOGCONF
		fi
		$ECHO "filter f_lnxadm_cli_$CURR_SERVER_NAME { level($SEVERITY..emerg); };" >> $SYSLOGCONF
		$ECHO "log { ${VREDNOST}); filter(f_lnxadm_cli_$CURR_SERVER_NAME); destination(d_udp_cli_$CURR_SERVER_NAME); };" >> $SYSLOGCONF
        fi
    done
# insert last server 
    if [ "$LAST" == "$SER_CURRENT" ]
    then
        # set values to insert
        CURR_SERVER=$SERVER
        if [ $PORT_CURRENT -lt $LAST ]
        then  
                CURR_PORT=$DEF_PORT
        else
                CURR_PORT=$PORT 
        fi                        
        if [ $LEV_CURRENT -lt $LAST ]
        then  
                CURR_LEVEL=$DEF_LEVEL
        else
                CURR_LEVEL=$LEVEL
        fi
        if [ $FACILITY_LEVEL_CURRENT -lt $LAST ]
        then  
                CURR_FACILITY_LEVEL=$DEF_FACILITY_LEVEL
        else
                CURR_FACILITY_LEVEL=$FACILITY_LEVEL
        fi        
        check_syslog_severity
        check_syslog_facility
        #insert new values
	CURR_SERVER_NAME=`(echo $CURR_SERVER | sed 's|:|_|g')`
        if [ "$CURR_FACILITY_LEVEL" == "" ]
        then
          PRI="\$PRI"
        else 
          PRI=$(($CURR_FACILITY_LEVEL*8 + $CURR_LEVEL))
        fi
	if [ "x$CURR_SERVER_NAME" == "x$CURR_SERVER" ]
	then 
	  $ECHO "destination d_udp_cli_$CURR_SERVER_NAME { udp(\"$CURR_SERVER\" port($CURR_PORT) template(\"\<$PRI\>\$DATE \$HOST \$LEVEL\/$FACILITY \$MSGHDR \$MSG\n\")); };" >> $SYSLOGCONF
	else
	  $ECHO "destination d_udp_cli_$CURR_SERVER_NAME { udp6(\"$CURR_SERVER\" port($CURR_PORT) template(\"\<$PRI\>\$DATE \$HOST \$LEVEL\/$FACILITY \$MSGHDR \$MSG\n\")); };" >> $SYSLOGCONF
	fi
	  $ECHO "filter f_lnxadm_cli_$CURR_SERVER_NAME { level($SEVERITY..emerg); };" >> $SYSLOGCONF
	  $ECHO "log { ${VREDNOST}); filter(f_lnxadm_cli_$CURR_SERVER_NAME); destination(d_udp_cli_$CURR_SERVER_NAME); };" >> $SYSLOGCONF
    fi

exit 0 
